(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    172992,       5785]*)
(*NotebookOutlinePosition[    173932,       5816]*)
(*  CellTagsIndexPosition[    173888,       5812]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Coil Inductance ", "Title"],

Cell["\<\
March 1999,
Pascal Elleaume, ESRF
\
\>", "Text"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell["\<\
This  notebook gives an example of the computation of the self and \
mutual inductance of coils . The case of two coils without iron is first \
described. Then a single coil with an iron yoke is considered. The \
computation makes use of the function \"\"radFldEnr[objdst,objsrc]\". If the \
object pointed to by \"objdst\" is a set of coils, \"radFldEnr\" computes the \
integral over the volume of each coil of the product of the current density \
in the coil multiplied by the vector potential created by the objects pointed \
to by  \"objsrc\". The results are expressed in Joules. If  \"objdst\" and \
\"objsrc\" points to the same coil, the results is equal to L*I*I where L is \
the self inductance and  I is the current in objdst. If  \"objdst\" and \
\"objsrc\" point to different coils, the result is equal to M*I1*I2 where M \
is the mutual inductance coefficient between the object pointed by  objdst \
and  objsrc and I1 and I2 are the total current in objdst and objsrc. The \
function radFldCmpPrc[PrcEnergy->N[10^-7]] is used to control the precision \
of the computation by subdividing all the coils in objdst into smaller coils  \
as needed to reach the required precision. It is important to start with a \
PrcEnergy coefficient which is not too small. The risk is to run out of \
memory. A value that is too large  is no risk but will give  poor precision. \
If the coil  interacts  with an iron volume, the iron pieces must be added to \
objsrc ,  subdivided as needed and the field in the iron must be solved in \
order to compute its contribution to the vector potential.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< Radia`\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Radia Version: \"\>", "\[InvisibleSpace]", 
        StyleBox["4.0940000000000003`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], "\[InvisibleSpace]", "\<\" is loaded\"\>"}],
      SequenceForm[ "Radia Version: ", 4.0940000000000003, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright 1997 \
Wolfram Research, Inc."\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coil Geometry", "Section"],

Cell[BoxData[
    \(\( (*\ Coil\ #\ 1\ \ *) \nCur = 10; 
    \ \ \ \ \ \ \ \ \ \ \ \  (*\ current\ \ [Ampere]\ *) \nNt = 25; 
    \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ Number\ of\ Turns\ *) \nrmin = 10; 
    \ \ \ \ \ \ \ \ \  (*\ Internal\ radius\ [mm]\ *) \nrmax = 15; 
    \ \ \ \ \ \ \ \  (*\ External\ radius\ [mm]\ *) \nh = 20; 
    \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ Height\ [mm]\ *) \n\n
    pt = {0, 0, 0}; phimin = 0; phimax = 2*\[Pi]; nseg = 20; \n
    j = \(-Cur\)*\(Nt/\((rmax - rmin)\)\)/h; \n
    g1 = radObjArcCur[pt, {rmin, rmax}, {phimin, phimax}, h, nseg, j]; 
    radObjDrwAtr[g1, {1, 0, 0.5}]; \n\n (*\ Coil\ #\ 2\ \ *) \nCur = 10; 
    \ \ \ \ \ \ \ \ \ \ \ \  (*\ current\ \ [Ampere]\ *) \nNt = 25; 
    \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ Number\ of\ Turns\ *) \nrmin = 16; 
    \ \ \ \ \ \ \ \ \  (*\ Internal\ radius\ [mm]\ *) \nrmax = 21; 
    \ \ \ \ \ \ \ \  (*\ External\ radius\ [mm]\ *) \nh = 20; 
    \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ Height\ [mm]\ *) \n\n\n
    pt = {0, 0, \(-h\)/4}; \n
    g2 = radObjArcCur[pt, {rmin, rmax}, {phimin, phimax}, h, nseg, j]; 
    radObjDrwAtr[g2, {0, 1, 0.5}]; \ng = radObjCnt[{g1, g2}]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"draw", "=", 
        RowBox[{
          StyleBox["radObjDrw",
            FontColor->RGBColor[1, 0, 0]], "[", "g", "]"}]}], ";", "\n", 
      RowBox[{
        StyleBox["RadPlot3DOptions",
          FontColor->RGBColor[1, 0, 0]], "[", "]"}], ";", "\n", 
      \(Show[Graphics3D[draw]]\), ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.62039 .80147 -11.9358 0 ]
[.62039 .80147 12.3142 14 ]
[.69256 .77198 -11.8212 0 ]
[.69256 .77198 12.4288 14 ]
[.77075 .74004 -4.8231 0 ]
[.77075 .74004 5.1769 14 ]
[.85573 .70531 -7.62642 0 ]
[.85573 .70531 8.37358 14 ]
[.94844 .66743 -7.52671 0 ]
[.94844 .66743 8.47329 14 ]
[.77296 .8025 -7.5361 0 ]
[.77296 .8025 8.0889 14 ]
[.39408 .11694 -11.9423 -14 ]
[.39408 .11694 12.3077 0 ]
[.53621 .15478 -12.1871 -14 ]
[.53621 .15478 12.0629 0 ]
[.67084 .19062 -5.12026 -14 ]
[.67084 .19062 4.87974 0 ]
[.79856 .22463 -8.33465 -14 ]
[.79856 .22463 7.66535 0 ]
[.91988 .25694 -8.46852 -14 ]
[.91988 .25694 7.53148 0 ]
[.66934 .12814 -8.0004 -14 ]
[.66934 .12814 7.6246 0 ]
[.96163 .35525 0 -5.25158 ]
[.96163 .35525 24.25 8.74842 ]
[.97036 .4948 0 -5.45704 ]
[.97036 .4948 10 8.54296 ]
[.97943 .63981 0 -5.67137 ]
[.97943 .63981 16 8.32863 ]
[1.02909 .4733 0 -5.40487 ]
[1.02909 .4733 14.3125 8.59513 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.6061 .79474 m
.96772 .64676 L
s
.25 Mabswid
.62019 .78897 m
.62009 .78272 L
s
gsave
.62039 .80147 -72.9358 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.69225 .75949 m
.69209 .75324 L
s
gsave
.69256 .77198 -72.8212 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.77031 .72754 m
.77008 .7213 L
s
gsave
.77075 .74004 -65.8231 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.85515 .69283 m
.85486 .68658 L
s
gsave
.85573 .70531 -68.6264 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.9477 .65495 m
.94733 .64871 L
s
gsave
.94844 .66743 -68.5267 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.63416 .78326 m
.63409 .77951 L
s
.64834 .77746 m
.64827 .77371 L
s
.66274 .77156 m
.66267 .76781 L
s
.67738 .76557 m
.67729 .76182 L
s
.70736 .7533 m
.70725 .74956 L
s
.72271 .74702 m
.7226 .74327 L
s
.73831 .74064 m
.7382 .73689 L
s
.75418 .73414 m
.75405 .7304 L
s
.7867 .72083 m
.78656 .71709 L
s
.80338 .71401 m
.80323 .71026 L
s
.82034 .70707 m
.82018 .70332 L
s
.83759 .70001 m
.83743 .69626 L
s
.87301 .68552 m
.87283 .68177 L
s
.89119 .67808 m
.89099 .67433 L
s
.90969 .67051 m
.90949 .66676 L
s
.92852 .6628 m
.92831 .65905 L
s
.60644 .7946 m
.60639 .79085 L
s
.96723 .64696 m
.967 .64322 L
s
gsave
.77296 .8025 -68.5361 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.36372 .12142 m
.94477 .27584 L
s
.25 Mabswid
.39389 .12944 m
.3938 .13569 L
s
gsave
.39408 .11694 -72.9423 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.53627 .16728 m
.5363 .17353 L
s
gsave
.53621 .15478 -73.1871 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.67114 .20312 m
.67129 .20937 L
s
gsave
.67084 .19062 -66.1203 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.79908 .23712 m
.79934 .24336 L
s
gsave
.79856 .22463 -69.3346 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.92061 .26942 m
.92097 .27566 L
s
gsave
.91988 .25694 -69.4685 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.423 .13717 m
.42296 .14092 L
s
.45178 .14482 m
.45176 .14857 L
s
.48026 .15239 m
.48024 .15614 L
s
.50842 .15987 m
.50842 .16362 L
s
.56383 .1746 m
.56386 .17835 L
s
.59109 .18184 m
.59113 .18559 L
s
.61806 .18901 m
.61812 .19276 L
s
.64474 .1961 m
.64482 .19985 L
s
.69727 .21006 m
.69737 .21381 L
s
.72312 .21693 m
.72324 .22068 L
s
.7487 .22373 m
.74883 .22748 L
s
.77402 .23046 m
.77416 .23421 L
s
.82388 .24371 m
.82405 .24746 L
s
.84843 .25023 m
.84862 .25398 L
s
.87274 .25669 m
.87293 .26044 L
s
.89679 .26309 m
.897 .26683 L
s
.36446 .12162 m
.36439 .12536 L
s
.94419 .27568 m
.94442 .27942 L
s
gsave
.66934 .12814 -69.0004 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.94477 .27584 m
.96772 .64676 L
s
.25 Mabswid
.9495 .35222 m
.94344 .35071 L
s
gsave
.96163 .35525 -61 -9.25158 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.95816 .49211 m
.95205 .49076 L
s
gsave
.97036 .4948 -61 -9.45704 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.96715 .63748 m
.96101 .63632 L
s
gsave
.97943 .63981 -61 -9.67137 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.9512 .37978 m
.94756 .37889 L
s
.95292 .40754 m
.94927 .40667 L
s
.95465 .43551 m
.951 .43466 L
s
.9564 .4637 m
.95274 .46287 L
s
.95993 .52073 m
.95626 .51995 L
s
.96171 .54958 m
.95804 .54881 L
s
.96351 .57865 m
.95983 .57791 L
s
.96532 .60795 m
.96164 .60723 L
s
.94781 .32488 m
.94417 .32395 L
s
.94613 .29774 m
.9425 .29679 L
s
gsave
1.02909 .4733 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.0891 .37107 m
.06959 .71692 L
s
.06959 .71692 m
.6061 .79474 L
s
.6061 .79474 m
.60173 .47757 L
s
.60173 .47757 m
.0891 .37107 L
s
.36372 .12142 m
.94477 .27584 L
s
.94477 .27584 m
.96772 .64676 L
s
.96772 .64676 m
.35577 .5318 L
s
.35577 .5318 m
.36372 .12142 L
s
.0891 .37107 m
.06959 .71692 L
s
.06959 .71692 m
.35577 .5318 L
s
.35577 .5318 m
.36372 .12142 L
s
.36372 .12142 m
.0891 .37107 L
s
.60173 .47757 m
.94477 .27584 L
s
.94477 .27584 m
.96772 .64676 L
s
.96772 .64676 m
.6061 .79474 L
s
.6061 .79474 m
.60173 .47757 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.52955 .44273 m .44286 .68981 L .53054 .69101 L 0 .637 .375 r
F
.52955 .44273 m .44473 .44123 L .44286 .68981 L F
.52301 .41857 m .44473 .44123 L .52955 .44273 L 0 .88 .527 r
F
.61225 .43445 m .52955 .44273 L .53054 .69101 L 0 .596 .375 r
F
.58728 .41199 m .52955 .44273 L .61225 .43445 L 0 .88 .527 r
F
.58728 .41199 m .52301 .41857 L .52955 .44273 L F
.44473 .44123 m .35923 .68088 L .44286 .68981 L 0 .677 .374 r
F
.44473 .44123 m .36388 .43002 L .35923 .68088 L F
.45696 .41738 m .36388 .43002 L .44473 .44123 L 0 .88 .527 r
F
.52301 .41857 m .45696 .41738 L .44473 .44123 L F
0 g
[ ] 0 setdash
.44473 .44123 m
.52955 .44273 L
s
.61225 .43445 m .53054 .69101 L .61607 .68441 L 0 .596 .375 r
F
.68671 .41677 m .61225 .43445 L .61607 .68441 L 0 .545 .373 r
F
.64466 .39801 m .61225 .43445 L .68671 .41677 L 0 .88 .527 r
F
.64466 .39801 m .58728 .41199 L .61225 .43445 L F
0 g
.52955 .44273 m
.61225 .43445 L
s
.36388 .43002 m .28596 .66461 L .35923 .68088 L 0 .723 .371 r
F
.36388 .43002 m .29316 .40964 L .28596 .66461 L F
.39426 .40848 m .29316 .40964 L .36388 .43002 L 0 .88 .527 r
F
.45696 .41738 m .39426 .40848 L .36388 .43002 L F
0 g
.36388 .43002 m
.44473 .44123 L
s
.52301 .41857 m .45547 .67079 L .45696 .41738 L 0 .636 .374 r
F
.52301 .41857 m .52381 .67174 L .45547 .67079 L F
.58728 .41199 m .52381 .67174 L .52301 .41857 L 0 .593 .374 r
F
.45696 .41738 m .39057 .66369 L .39426 .40848 L 0 .677 .373 r
F
.45696 .41738 m .45547 .67079 L .39057 .66369 L F
0 g
.45696 .41738 m
.52301 .41857 L
s
.68671 .41677 m .61607 .68441 L .69317 .67031 L 0 .545 .373 r
F
.74676 .39062 m .68671 .41677 L .69317 .67031 L 0 .471 .366 r
F
.69018 .37752 m .68671 .41677 L .74676 .39062 L 0 .88 .527 r
F
.69018 .37752 m .64466 .39801 L .68671 .41677 L F
0 g
.61225 .43445 m
.68671 .41677 L
s
.58728 .41199 m .59031 .66649 L .52381 .67174 L 0 .593 .374 r
F
.64466 .39801 m .59031 .66649 L .58728 .41199 L 0 .541 .371 r
F
0 g
.52301 .41857 m
.58728 .41199 L
s
.29316 .40964 m .22939 .64187 L .28596 .66461 L 0 .782 .363 r
F
.29316 .40964 m .23873 .38119 L .22939 .64187 L F
.33998 .3924 m .23873 .38119 L .29316 .40964 L 0 .88 .527 r
F
.39426 .40848 m .33998 .3924 L .29316 .40964 L F
0 g
.29316 .40964 m
.36388 .43002 L
s
.39426 .40848 m .33432 .65084 L .33998 .3924 L 0 .724 .37 r
F
.39426 .40848 m .39057 .66369 L .33432 .65084 L F
0 g
.39426 .40848 m
.45696 .41738 L
s
.51669 .67333 m .53054 .69101 L .44286 .68981 L 0 .905 .543 r
F
.44708 .67167 m .44286 .68981 L .35923 .68088 L F
.45547 .67079 m .45386 .67323 L .44708 .67167 L F
.45386 .67323 m .44286 .68981 L .44708 .67167 L F
.45547 .67079 m .35923 .68088 L .39057 .66369 L F
.39699 .66016 m .34278 .71571 L .39608 .72701 L .919 0 .37 r
F
.39962 .46645 m .35751 .65109 L .39699 .66016 L F
.38154 .66376 m .35923 .68088 L .28596 .66461 L 0 .905 .543 r
F
.39057 .66369 m .38657 .66588 L .38154 .66376 L F
.38657 .66588 m .35923 .68088 L .38154 .66376 L F
.33779 .66122 m .28596 .66461 L .32816 .65259 L F
.38154 .66376 m .28596 .66461 L .37042 .65908 L F
.33998 .3924 m .33432 .65084 L .29177 .63306 L 0 .785 .36 r
F
.32535 .65007 m .28596 .66461 L .22939 .64187 L 0 .905 .543 r
F
.33432 .65084 m .32816 .65259 L .32535 .65007 L F
.32816 .65259 m .28596 .66461 L .32535 .65007 L F
.33998 .3924 m .29902 .37018 L .23873 .38119 L 0 .88 .527 r
F
.33998 .3924 m .29177 .63306 L .29902 .37018 L 0 .785 .36 r
F
.29902 .37018 m .20651 .34651 L .23873 .38119 L 0 .88 .527 r
F
.29902 .37018 m .2758 .34343 L .20651 .34651 L F
.29902 .37018 m .26752 .61163 L .2758 .34343 L 0 .87 .323 r
F
.29902 .37018 m .29177 .63306 L .26752 .61163 L F
.30956 .43204 m .28782 .40808 L .28193 .61114 L 1 0 .321 r
F
.33432 .65084 m .28491 .64662 L .29177 .63306 L 0 .905 .543 r
F
.28491 .64662 m .22939 .64187 L .28387 .63418 L F
.28491 .64662 m .28387 .63418 L .29177 .63306 L F
.23873 .38119 m .19569 .6141 L .22939 .64187 L 0 .866 .331 r
F
.28364 .63146 m .23002 .64175 L .24679 .62418 L 0 .905 .543 r
F
.29177 .63306 m .28387 .63418 L .28364 .63146 L F
.28387 .63418 m .22939 .64187 L .28364 .63146 L F
.29177 .63306 m .19569 .6141 L .26752 .61163 L F
.28056 .59486 m .28009 .58931 L .27799 .661 L .9 0 .106 r
F
.28782 .40808 m .28009 .58931 L .28056 .59486 L F
.28193 .61114 m .27799 .661 L .2799 .68135 L F
.28782 .40808 m .28056 .59486 L .28193 .61114 L F
.28056 .59486 m .27799 .661 L .28193 .61114 L F
.28764 .61626 m .28193 .61114 L .2799 .68135 L 1 0 .321 r
F
.30956 .43204 m .28193 .61114 L .28764 .61626 L F
.30956 .43204 m .28764 .61626 L .30439 .63128 L F
.28764 .61626 m .2799 .68135 L .30439 .63128 L F
.28009 .58931 m .29858 .64104 L .27799 .661 L .177 0 .287 r
F
.28782 .40808 m .28617 .38215 L .28009 .58931 L .9 0 .106 r
F
.28617 .38215 m .29534 .57335 L .28009 .58931 L .177 0 .287 r
F
.29534 .57335 m .29858 .64104 L .28009 .58931 L F
.24679 .62418 m .22939 .64187 L .19569 .6141 L 0 .905 .543 r
F
.23002 .64175 m .22939 .64187 L .24679 .62418 L F
.30439 .63128 m .2799 .68135 L .30261 .70011 L 1 0 .321 r
F
.37042 .65908 m .33779 .66122 L .33432 .65084 L 0 .905 .543 r
F
.33779 .66122 m .32816 .65259 L .33432 .65084 L F
.39057 .66369 m .38154 .66376 L .37042 .65908 L F
.34821 .45199 m .30956 .43204 L .30439 .63128 L .99 0 .36 r
F
.31448 .63552 m .30439 .63128 L .30261 .70011 L F
.34821 .45199 m .30439 .63128 L .31448 .63552 L F
.34417 .64803 m .30261 .70011 L .34278 .71571 L F
.34821 .45199 m .31448 .63552 L .34417 .64803 L F
.31448 .63552 m .30261 .70011 L .34417 .64803 L F
.35751 .65109 m .34278 .71571 L .39699 .66016 L .919 0 .37 r
F
.52381 .67174 m .44286 .68981 L .45386 .67323 L 0 .905 .543 r
F
.48019 .67114 m .45386 .67323 L .45547 .67079 L F
.52381 .67174 m .45386 .67323 L .48019 .67114 L F
.58286 .46961 m .52185 .47554 L .52242 .66778 L .76 0 .374 r
F
.52381 .67174 m .52467 .67421 L .51669 .67333 L 0 .905 .543 r
F
.52467 .67421 m .53054 .69101 L .51669 .67333 L F
.59031 .66649 m .53054 .69101 L .52467 .67421 L F
.54776 .66985 m .52467 .67421 L .52381 .67174 L F
.59031 .66649 m .52467 .67421 L .54776 .66985 L F
.64466 .39801 m .64975 .65532 L .59031 .66649 L 0 .541 .371 r
F
.63725 .45704 m .58286 .46961 L .58503 .66281 L .694 0 .371 r
F
.59031 .66649 m .61607 .68441 L .53054 .69101 L 0 .905 .543 r
F
.64975 .65532 m .61607 .68441 L .59361 .66878 L F
.61163 .66248 m .59361 .66878 L .59031 .66649 L F
.64975 .65532 m .59361 .66878 L .61163 .66248 L F
.69018 .37752 m .64975 .65532 L .64466 .39801 L 0 .463 .365 r
F
.68027 .43863 m .63725 .45704 L .64089 .65226 L .595 0 .364 r
F
.61793 .6828 m .69317 .67031 L .61607 .68441 L 0 .905 .543 r
F
.64975 .65532 m .65529 .65723 L .61793 .6828 L F
.65529 .65723 m .69317 .67031 L .61793 .6828 L F
.69018 .37752 m .697 .63894 L .64975 .65532 L 0 .463 .365 r
F
.71923 .35194 m .69018 .37752 L .74676 .39062 L 0 .88 .527 r
F
.71923 .35194 m .697 .63894 L .69018 .37752 L 0 .308 .341 r
F
.70756 .4157 m .68027 .43863 L .68513 .63681 L .393 0 .34 r
F
.697 .63894 m .69317 .67031 L .65529 .65723 L 0 .905 .543 r
F
.66663 .64947 m .65529 .65723 L .64975 .65532 L F
.697 .63894 m .65529 .65723 L .66663 .64947 L F
.74676 .39062 m .69317 .67031 L .75551 .64942 L 0 .471 .366 r
F
.69338 .66857 m .75551 .64942 L .69317 .67031 L 0 .905 .543 r
F
.697 .63894 m .70442 .64027 L .69338 .66857 L F
.70442 .64027 m .75551 .64942 L .69338 .66857 L F
.71923 .35194 m .72727 .61846 L .697 .63894 L 0 .308 .341 r
F
.71559 .39013 m .70756 .4157 L .71328 .61755 L .1 0 .21 r
F
.71559 .39013 m .71534 .61226 L .72167 .59603 L F
.71559 .39013 m .71328 .61755 L .71534 .61226 L F
.70756 .4157 m .69205 .63207 L .71328 .61755 L .393 0 .34 r
F
.70756 .4157 m .68513 .63681 L .69205 .63207 L F
.63905 .41025 m .68027 .43863 L .70756 .4157 L .717 0 .531 r
F
.64334 .39316 m .70756 .4157 L .71559 .39013 L F
.64334 .39316 m .63905 .41025 L .70756 .4157 L F
.63345 .37615 m .64334 .39316 L .71559 .39013 L F
.63345 .37615 m .71559 .39013 L .70224 .36428 L F
.70224 .36428 m .71559 .39013 L .72167 .59603 L 1 0 .235 r
F
.72727 .61846 m .75394 .64771 L .70442 .64027 L 0 .905 .543 r
F
.75394 .64771 m .75495 .64932 L .70442 .64027 L F
.72727 .61846 m .70442 .64027 L .70778 .63164 L F
.72167 .59603 m .71526 .68732 L .72377 .66726 L .1 0 .21 r
F
.71534 .61226 m .71526 .68732 L .72167 .59603 L F
.71833 .59068 m .72167 .59603 L .72377 .66726 L 1 0 .235 r
F
.70224 .36428 m .72167 .59603 L .71833 .59068 L F
.75394 .64771 m .75551 .64942 L .75495 .64932 L 0 .905 .543 r
F
.70778 .63164 m .70442 .64027 L .697 .63894 L F
.71534 .61226 m .71328 .61755 L .71526 .68732 L .1 0 .21 r
F
.71328 .61755 m .68681 .70527 L .71526 .68732 L .393 0 .34 r
F
.69205 .63207 m .68681 .70527 L .71328 .61755 L F
.69205 .63207 m .68513 .63681 L .68681 .70527 L F
.6518 .64845 m .64089 .65226 L .64214 .71966 L .595 0 .364 r
F
.68027 .43863 m .64089 .65226 L .6518 .64845 L F
.59887 .6602 m .58503 .66281 L .58578 .72948 L .694 0 .371 r
F
.63725 .45704 m .58503 .66281 L .59887 .6602 L F
.53801 .66654 m .52242 .66778 L .52262 .73411 L .76 0 .374 r
F
.58286 .46961 m .52242 .66778 L .53801 .66654 L F
.45806 .66688 m .39608 .72701 L .4577 .73327 L .863 0 .373 r
F
.45913 .47447 m .41235 .66185 L .45806 .66688 L F
.41235 .66185 m .39608 .72701 L .45806 .66688 L F
0 g
.53247 .69086 m
.5853 .68678 L
s
.59397 .68611 m
.61607 .68441 L
s
.45794 .69002 m
.52249 .6909 L
s
.52185 .47554 m .4577 .73327 L .52262 .73411 L .813 0 .374 r
F
.52185 .47554 m .45913 .47447 L .4577 .73327 L F
.51491 .45126 m .45913 .47447 L .52185 .47554 L .717 0 .531 r
F
.55642 .44713 m .52185 .47554 L .58286 .46961 L F
.55642 .44713 m .51491 .45126 L .52185 .47554 L F
.45913 .47447 m .39962 .46645 L .39608 .72701 L .863 0 .373 r
F
.47213 .45051 m .39962 .46645 L .45913 .47447 L .717 0 .531 r
F
.51491 .45126 m .47213 .45051 L .45913 .47447 L F
0 g
.45913 .47447 m
.52185 .47554 L
s
.58728 .41199 m
.64196 .39867 L
s
.72074 .40196 m
.74637 .3908 L
s
.58286 .46961 m .52262 .73411 L .58578 .72948 L .76 0 .374 r
F
.59309 .43842 m .58286 .46961 L .63725 .45704 L .717 0 .531 r
F
.59309 .43842 m .55642 .44713 L .58286 .46961 L F
0 g
.52185 .47554 m
.58286 .46961 L
s
.61607 .68441 m
.6414 .67977 L
s
.64771 .67862 m
.68598 .67162 L
s
.39962 .46645 m .34821 .45199 L .34278 .71571 L .919 0 .37 r
F
.43172 .44494 m .34821 .45199 L .39962 .46645 L .717 0 .531 r
F
.47213 .45051 m .43172 .44494 L .39962 .46645 L F
0 g
.39962 .46645 m
.45913 .47447 L
s
.29902 .37018 m
.33998 .3924 L
s
.33998 .3924 m
.39426 .40848 L
s
.78635 .3576 m .74676 .39062 L .75551 .64942 L 0 .329 .346 r
F
.71923 .35194 m .74676 .39062 L .78635 .3576 L 0 .88 .527 r
F
0 g
.74637 .3908 m
.74676 .39062 L
s
.63725 .45704 m .58578 .72948 L .64214 .71966 L .694 0 .371 r
F
.6216 .42579 m .63725 .45704 L .68027 .43863 L .717 0 .531 r
F
.6216 .42579 m .59309 .43842 L .63725 .45704 L F
0 g
.58286 .46961 m
.63725 .45704 L
s
.23873 .38119 m .20651 .34651 L .19569 .6141 L 0 .866 .331 r
F
0 g
.23873 .38119 m
.27407 .39966 L
s
.3972 .43495 m .30956 .43204 L .34821 .45199 L .717 0 .531 r
F
.43172 .44494 m .3972 .43495 L .34821 .45199 L F
0 g
.34821 .45199 m
.39962 .46645 L
s
.72356 .66012 m
.7551 .64956 L
s
.51491 .45126 m .47113 .71456 L .47213 .45051 L .813 0 .373 r
F
.51491 .45126 m .51544 .71514 L .47113 .71456 L F
.55642 .44713 m .51544 .71514 L .51491 .45126 L .758 0 .373 r
F
.47213 .45051 m .42926 .7102 L .43172 .44494 L .864 0 .372 r
F
.47213 .45051 m .47113 .71456 L .42926 .7102 L F
0 g
.47213 .45051 m
.51491 .45126 L
s
.55642 .44713 m .55845 .71192 L .51544 .71514 L .758 0 .373 r
F
.59309 .43842 m .55845 .71192 L .55642 .44713 L .69 0 .37 r
F
0 g
.51491 .45126 m
.55642 .44713 L
s
.43172 .44494 m .39346 .70238 L .3972 .43495 L .922 0 .369 r
F
.43172 .44494 m .42926 .7102 L .39346 .70238 L F
0 g
.43172 .44494 m
.47213 .45051 L
s
.22939 .64187 m
.22976 .64202 L
s
.22976 .64202 m
.27803 .66142 L
s
.51544 .71514 m .52262 .73411 L .4577 .73327 L .66 0 .546 r
F
.55845 .71192 m .52262 .73411 L .51544 .71514 L F
.55845 .71192 m .58578 .72948 L .52262 .73411 L F
.68027 .43863 m .64214 .71966 L .68681 .70527 L .595 0 .364 r
F
.63905 .41025 m .6216 .42579 L .68027 .43863 L .717 0 .531 r
F
0 g
.63725 .45704 m
.68027 .43863 L
s
.68027 .43863 m
.70599 .41703 L
s
.59309 .43842 m .59647 .7051 L .55845 .71192 L .69 0 .37 r
F
.6216 .42579 m .59647 .7051 L .59309 .43842 L .586 0 .362 r
F
0 g
.55642 .44713 m
.59309 .43842 L
s
.47113 .71456 m .4577 .73327 L .39608 .72701 L .66 0 .546 r
F
.51544 .71514 m .4577 .73327 L .47113 .71456 L F
0 g
.4577 .73327 m
.52262 .73411 L
s
.3972 .43495 m .37179 .4213 L .30956 .43204 L .717 0 .531 r
F
.3972 .43495 m .36706 .6917 L .37179 .4213 L .996 0 .357 r
F
.3972 .43495 m .39346 .70238 L .36706 .6917 L F
0 g
.3972 .43495 m
.43172 .44494 L
s
.59647 .7051 m .58578 .72948 L .55845 .71192 L .66 0 .546 r
F
.59647 .7051 m .64214 .71966 L .58578 .72948 L F
0 g
.52262 .73411 m
.58578 .72948 L
s
.37179 .4213 m .28782 .40808 L .30956 .43204 L .717 0 .531 r
F
0 g
.30956 .43204 m
.34821 .45199 L
s
.78635 .3576 m .75551 .64942 L .7968 .62299 L 0 .329 .346 r
F
.80005 .32014 m .78635 .3576 L .7968 .62299 L 0 .1 .241 r
F
.728 .32334 m .78635 .3576 L .80005 .32014 L 0 .88 .527 r
F
.728 .32334 m .71923 .35194 L .78635 .3576 L F
0 g
.74676 .39062 m
.78635 .3576 L
s
.42926 .7102 m .39608 .72701 L .34278 .71571 L .66 0 .546 r
F
.47113 .71456 m .39608 .72701 L .42926 .7102 L F
0 g
.39608 .72701 m
.4577 .73327 L
s
.728 .32334 m .72727 .61846 L .71923 .35194 L 0 .1 .216 r
F
0 g
.70317 .36608 m
.71923 .35194 L
s
.6216 .42579 m .62606 .69522 L .59647 .7051 L .586 0 .362 r
F
.63905 .41025 m .62606 .69522 L .6216 .42579 L .366 0 .334 r
F
0 g
.59309 .43842 m
.6216 .42579 L
s
.72727 .61846 m .7968 .62299 L .75551 .64942 L 0 .905 .543 r
F
0 g
.7551 .64956 m
.75551 .64942 L
s
.20651 .34651 m .19021 .58345 L .19569 .6141 L 0 .82 .15 r
F
.20651 .34651 m .20158 .30832 L .19021 .58345 L F
.2758 .34343 m .20158 .30832 L .20651 .34651 L 0 .88 .527 r
F
0 g
.20651 .34651 m
.23873 .38119 L
s
.37179 .4213 m .35817 .40513 L .28782 .40808 L .717 0 .531 r
F
.37179 .4213 m .35286 .67903 L .35817 .40513 L 1 0 .312 r
F
.37179 .4213 m .36706 .6917 L .35286 .67903 L F
0 g
.37179 .4213 m
.3972 .43495 L
s
.62606 .69522 m .64214 .71966 L .59647 .7051 L .66 0 .546 r
F
.62606 .69522 m .68681 .70527 L .64214 .71966 L F
0 g
.58578 .72948 m
.64214 .71966 L
s
.2758 .34343 m .27377 .31441 L .20158 .30832 L 0 .88 .527 r
F
.2758 .34343 m .26519 .58834 L .27377 .31441 L 0 .773 .114 r
F
.2758 .34343 m .26752 .61163 L .26519 .58834 L F
0 g
.2758 .34343 m
.29902 .37018 L
s
.39346 .70238 m .34278 .71571 L .30261 .70011 L .66 0 .546 r
F
.42926 .7102 m .34278 .71571 L .39346 .70238 L F
0 g
.34278 .71571 m
.39608 .72701 L
s
.47113 .71456 m
.51544 .71514 L
s
.51544 .71514 m
.55845 .71192 L
s
.42926 .7102 m
.47113 .71456 L
s
.63905 .41025 m .64423 .68305 L .62606 .69522 L .366 0 .334 r
F
.64334 .39316 m .64423 .68305 L .63905 .41025 L .1 0 .181 r
F
0 g
.6216 .42579 m
.63905 .41025 L
s
.55845 .71192 m
.59647 .7051 L
s
.35817 .40513 m .28617 .38215 L .28782 .40808 L .717 0 .531 r
F
0 g
.28782 .40808 m
.30956 .43204 L
s
.35817 .40513 m .35816 .38788 L .28617 .38215 L .717 0 .531 r
F
.35817 .40513 m .35276 .6655 L .35816 .38788 L .829 0 .067 r
F
.35817 .40513 m .35286 .67903 L .35276 .6655 L F
0 g
.35817 .40513 m
.37179 .4213 L
s
.728 .32334 m .73658 .59551 L .72727 .61846 L 0 .1 .216 r
F
.71416 .29436 m .73658 .59551 L .728 .32334 L 0 .86 .23 r
F
.71416 .29436 m .728 .32334 L .80005 .32014 L 0 .88 .527 r
F
.64423 .68305 m .68681 .70527 L .62606 .69522 L .66 0 .546 r
F
.64423 .68305 m .71526 .68732 L .68681 .70527 L F
0 g
.64214 .71966 m
.68681 .70527 L
s
.59647 .7051 m
.62606 .69522 L
s
.80005 .32014 m .7968 .62299 L .81137 .59294 L 0 .1 .241 r
F
.71416 .29436 m .80005 .32014 L .78399 .2816 L 0 .88 .527 r
F
.78399 .2816 m .80005 .32014 L .81137 .59294 L 0 .845 .205 r
F
0 g
.78635 .3576 m
.78984 .34807 L
s
.39346 .70238 m .30261 .70011 L .36706 .6917 L .66 0 .546 r
F
0 g
.39346 .70238 m
.42926 .7102 L
s
.64334 .39316 m .64877 .66964 L .64423 .68305 L .1 0 .181 r
F
.63345 .37615 m .64877 .66964 L .64334 .39316 L 1 0 .256 r
F
.36706 .6917 m .30261 .70011 L .2799 .68135 L .66 0 .546 r
F
0 g
.30261 .70011 m
.34278 .71571 L
s
.73658 .59551 m .7968 .62299 L .72727 .61846 L 0 .905 .543 r
F
0 g
.72243 .62173 m
.72727 .61846 L
s
.73658 .59551 m .81137 .59294 L .7968 .62299 L 0 .905 .543 r
F
0 g
.75551 .64942 m
.7968 .62299 L
s
.35816 .38788 m .30616 .35675 L .28617 .38215 L .717 0 .531 r
F
.28617 .38215 m .30616 .35675 L .30053 .56791 L .177 0 .287 r
F
.29534 .57335 m .30053 .56791 L .29858 .64104 L F
.28617 .38215 m .30053 .56791 L .29534 .57335 L F
.27377 .31441 m .28668 .56543 L .29466 .28591 L 0 .104 .285 r
F
.27377 .31441 m .26519 .58834 L .28668 .56543 L F
.30616 .35675 m .34095 .62368 L .29858 .64104 L .527 0 .348 r
F
.35816 .38788 m .37238 .37124 L .30616 .35675 L .717 0 .531 r
F
.37238 .37124 m .34705 .33469 L .30616 .35675 L F
.30616 .35675 m .34705 .33469 L .34252 .5493 L .527 0 .348 r
F
.33187 .55402 m .34252 .5493 L .34095 .62368 L F
.30616 .35675 m .34252 .5493 L .33187 .55402 L F
.35816 .38788 m .36745 .65244 L .37238 .37124 L .224 0 .3 r
F
.35816 .38788 m .35276 .6655 L .36745 .65244 L F
.37238 .37124 m .39603 .64123 L .39994 .35699 L .541 0 .352 r
F
.37238 .37124 m .36745 .65244 L .39603 .64123 L F
.37238 .37124 m .39994 .35699 L .34705 .33469 L .717 0 .531 r
F
.39994 .35699 m .4053 .31868 L .34705 .33469 L F
.39994 .35699 m .39603 .64123 L .4359 .63318 L .673 0 .365 r
F
.34705 .33469 m .40147 .61106 L .34095 .62368 L .668 0 .363 r
F
.39994 .35699 m .4359 .63318 L .43834 .34676 L .673 0 .365 r
F
.39994 .35699 m .43834 .34676 L .4053 .31868 L .717 0 .531 r
F
.34705 .33469 m .4053 .31868 L .40246 .53577 L .668 0 .363 r
F
.38732 .53919 m .40246 .53577 L .40147 .61106 L F
.34705 .33469 m .40246 .53577 L .38732 .53919 L F
.43834 .34676 m .48293 .62927 L .48358 .34179 L .752 0 .369 r
F
.43834 .34676 m .4359 .63318 L .48293 .62927 L F
.43834 .34676 m .47472 .31084 L .4053 .31868 L .717 0 .531 r
F
.4053 .31868 m .47369 .60488 L .40147 .61106 L .75 0 .368 r
F
.43834 .34676 m .48358 .34179 L .47472 .31084 L .717 0 .531 r
F
.4053 .31868 m .47472 .31084 L .47396 .52915 L .75 0 .368 r
F
.45599 .53081 m .47396 .52915 L .47369 .60488 L F
.4053 .31868 m .47396 .52915 L .45599 .53081 L F
.53066 .34269 m .57723 .63524 L .57431 .34937 L .871 0 .368 r
F
.53066 .34269 m .53187 .62998 L .57723 .63524 L F
.48358 .34179 m .53187 .62998 L .53066 .34269 L .813 0 .37 r
F
.48358 .34179 m .48293 .62927 L .53187 .62998 L F
.60976 .36098 m .61404 .64437 L .63858 .65629 L 1 0 .343 r
F
.57431 .34937 m .61404 .64437 L .60976 .36098 L .936 0 .362 r
F
.57431 .34937 m .60976 .36098 L .66748 .3409 L .717 0 .531 r
F
.60976 .36098 m .63858 .65629 L .63345 .37615 L 1 0 .343 r
F
.60976 .36098 m .63345 .37615 L .70224 .36428 L .717 0 .531 r
F
.60976 .36098 m .70224 .36428 L .66748 .3409 L F
.57431 .34937 m .66748 .3409 L .61398 .32278 L F
.57431 .34937 m .61857 .61429 L .61398 .32278 L .466 0 .345 r
F
.57431 .34937 m .57723 .63524 L .61404 .64437 L .936 0 .362 r
F
.57431 .34937 m .57723 .63524 L .61857 .61429 L .466 0 .345 r
F
.53066 .34269 m .57431 .34937 L .61398 .32278 L .717 0 .531 r
F
.57431 .34937 m .61857 .61429 L .57723 .63524 L .466 0 .345 r
F
.57431 .34937 m .61398 .32278 L .61857 .61429 L F
.53066 .34269 m .61398 .32278 L .54717 .31228 L .717 0 .531 r
F
.54717 .31228 m .61398 .32278 L .61857 .61429 L .872 0 .367 r
F
.63345 .37615 m .63858 .65629 L .64877 .66964 L 1 0 .256 r
F
.61739 .53923 m .67412 .62857 L .61857 .61429 L .94 0 .36 r
F
.61398 .32278 m .65882 .55075 L .61739 .53923 L F
.65882 .55075 m .67412 .62857 L .61739 .53923 L F
.5486 .53036 m .61857 .61429 L .54909 .60601 L .872 0 .367 r
F
.54717 .31228 m .60031 .53703 L .5486 .53036 L F
.60031 .53703 m .61857 .61429 L .5486 .53036 L F
.55009 .23583 m .55211 .52506 L .6258 .53462 L 0 .676 .367 r
F
.48358 .34179 m .53066 .34269 L .54717 .31228 L .717 0 .531 r
F
.48358 .34179 m .54717 .31228 L .47472 .31084 L F
.47472 .31084 m .54717 .31228 L .54909 .60601 L .813 0 .369 r
F
.47316 .23421 m .55211 .52506 L .55009 .23583 L 0 .628 .369 r
F
.47472 .31084 m .54909 .60601 L .47369 .60488 L .813 0 .369 r
F
.47316 .23421 m .47207 .52375 L .55211 .52506 L 0 .628 .369 r
F
.49327 .52322 m .57027 .49768 L .55434 .5217 L 0 .905 .543 r
F
.47207 .52375 m .48034 .52156 L .49327 .52322 L F
.48034 .52156 m .57027 .49768 L .49327 .52322 L F
.61398 .32278 m .66748 .3409 L .67412 .62857 L .94 0 .36 r
F
.67242 .55453 m .71009 .64696 L .67412 .62857 L 1 0 .339 r
F
.66748 .3409 m .69929 .5694 L .67242 .55453 L F
.69929 .5694 m .71009 .64696 L .67242 .55453 L F
.62096 .24767 m .6258 .53462 L .68456 .55107 L 0 .732 .36 r
F
.71416 .29436 m .72242 .57222 L .73658 .59551 L 0 .86 .23 r
F
.70807 .57425 m .72377 .66726 L .71009 .64696 L 1 0 .235 r
F
.70224 .36428 m .71833 .59068 L .70807 .57425 L F
.71833 .59068 m .72377 .66726 L .70807 .57425 L F
.66748 .3409 m .70224 .36428 L .71009 .64696 L 1 0 .339 r
F
.67757 .26808 m .72242 .57222 L .71416 .29436 L 0 .806 .338 r
F
.67757 .26808 m .68456 .55107 L .72242 .57222 L F
.69844 .55883 m .79506 .56196 L .72242 .57222 L 0 .905 .543 r
F
.68456 .55107 m .69419 .55202 L .69844 .55883 L F
.69419 .55202 m .79506 .56196 L .69844 .55883 L F
.62096 .24767 m .68456 .55107 L .67757 .26808 L 0 .732 .36 r
F
.64727 .54063 m .74663 .53339 L .68456 .55107 L 0 .905 .543 r
F
.6258 .53462 m .63621 .53451 L .64727 .54063 L F
.63621 .53451 m .74663 .53339 L .64727 .54063 L F
.62096 .24767 m .6258 .53462 L .66907 .51088 L 0 .353 .345 r
F
.55009 .23583 m .6258 .53462 L .62096 .24767 L 0 .676 .367 r
F
.62096 .24767 m .66907 .51088 L .6258 .53462 L 0 .353 .345 r
F
.57892 .52854 m .66907 .51088 L .6258 .53462 L 0 .905 .543 r
F
.55211 .52506 m .56207 .52385 L .57892 .52854 L F
.56207 .52385 m .66907 .51088 L .57892 .52854 L F
.5232 .52459 m .55434 .5217 L .55211 .52506 L F
.47207 .52375 m .55434 .5217 L .5232 .52459 L F
.39949 .24305 m .39544 .53089 L .47207 .52375 L 0 .576 .368 r
F
.39544 .53089 m .46232 .49587 L .47088 .52033 L 0 .905 .543 r
F
.44424 .52634 m .47088 .52033 L .47207 .52375 L F
.39544 .53089 m .47088 .52033 L .44424 .52634 L F
.33779 .2611 m .33136 .54544 L .39544 .53089 L 0 .508 .363 r
F
.33136 .54544 m .3593 .50574 L .39101 .5278 L 0 .905 .543 r
F
.37206 .5362 m .39101 .5278 L .39544 .53089 L F
.33136 .54544 m .39101 .5278 L .37206 .5362 L F
.29466 .28591 m .28668 .56543 L .33136 .54544 L 0 .391 .348 r
F
.28668 .56543 m .2742 .52572 L .32431 .54301 L 0 .905 .543 r
F
.31499 .55276 m .32431 .54301 L .33136 .54544 L F
.28668 .56543 m .32431 .54301 L .31499 .55276 L F
.27377 .31441 m .22709 .27026 L .20158 .30832 L 0 .88 .527 r
F
.27377 .31441 m .29466 .28591 L .22709 .27026 L F
.20158 .30832 m .21635 .55283 L .19021 .58345 L 0 .1 .269 r
F
.20158 .30832 m .22709 .27026 L .21635 .55283 L F
.26752 .61163 m .19569 .6141 L .19021 .58345 L 0 .905 .543 r
F
0 g
.19569 .6141 m
.22939 .64187 L
s
.36706 .6917 m .2799 .68135 L .35286 .67903 L .66 0 .546 r
F
0 g
.36706 .6917 m
.39346 .70238 L
s
.26752 .61163 m .19021 .58345 L .26519 .58834 L 0 .905 .543 r
F
0 g
.26752 .61163 m
.27914 .6219 L
s
.64877 .66964 m .71526 .68732 L .64423 .68305 L .66 0 .546 r
F
0 g
.62606 .69522 m
.64423 .68305 L
s
.64877 .66964 m .72377 .66726 L .71526 .68732 L .66 0 .546 r
F
0 g
.68681 .70527 m
.71526 .68732 L
s
.67757 .26808 m .71416 .29436 L .78399 .2816 L 0 .88 .527 r
F
0 g
.71416 .29436 m
.728 .32334 L
s
.35286 .67903 m .2799 .68135 L .27799 .661 L .66 0 .546 r
F
0 g
.2799 .68135 m
.30261 .70011 L
s
.29466 .28591 m .33136 .54544 L .33779 .2611 L 0 .391 .348 r
F
.29466 .28591 m .28298 .23665 L .22709 .27026 L 0 .88 .527 r
F
.29466 .28591 m .33779 .2611 L .28298 .23665 L F
0 g
.27377 .31441 m
.29466 .28591 L
s
.35286 .67903 m .27799 .661 L .35276 .6655 L .66 0 .546 r
F
0 g
.35286 .67903 m
.36706 .6917 L
s
.78399 .2816 m .81137 .59294 L .79506 .56196 L 0 .845 .205 r
F
.67757 .26808 m .78399 .2816 L .73712 .24615 L 0 .88 .527 r
F
.73712 .24615 m .78399 .2816 L .79506 .56196 L 0 .81 .332 r
F
0 g
.78399 .2816 m
.80005 .32014 L
s
.72242 .57222 m .81137 .59294 L .73658 .59551 L 0 .905 .543 r
F
0 g
.72727 .61846 m
.73658 .59551 L
s
.72242 .57222 m .79506 .56196 L .81137 .59294 L 0 .905 .543 r
F
0 g
.7968 .62299 m
.81137 .59294 L
s
.72242 .57222 m
.73658 .59551 L
s
.63858 .65629 m .72377 .66726 L .64877 .66964 L .66 0 .546 r
F
0 g
.64423 .68305 m
.64877 .66964 L
s
.22709 .27026 m .2742 .52572 L .21635 .55283 L 0 .376 .344 r
F
.22709 .27026 m .28298 .23665 L .2742 .52572 L F
0 g
.20158 .30832 m
.22709 .27026 L
s
.26519 .58834 m .21635 .55283 L .28668 .56543 L 0 .905 .543 r
F
.26519 .58834 m .19021 .58345 L .21635 .55283 L F
0 g
.26519 .58834 m
.26752 .61163 L
s
.19021 .58345 m
.19569 .6141 L
s
.62096 .24767 m .67757 .26808 L .73712 .24615 L 0 .88 .527 r
F
0 g
.67757 .26808 m
.71416 .29436 L
s
.63858 .65629 m .71009 .64696 L .72377 .66726 L .66 0 .546 r
F
0 g
.71526 .68732 m
.72377 .66726 L
s
.35276 .6655 m .29858 .64104 L .36745 .65244 L .66 0 .546 r
F
.35276 .6655 m .27799 .661 L .29858 .64104 L F
0 g
.35276 .6655 m
.35286 .67903 L
s
.27799 .661 m
.2799 .68135 L
s
.33779 .2611 m .39544 .53089 L .39949 .24305 L 0 .508 .363 r
F
.33779 .2611 m .36488 .21192 L .28298 .23665 L 0 .88 .527 r
F
.33779 .2611 m .39949 .24305 L .36488 .21192 L F
0 g
.29466 .28591 m
.33779 .2611 L
s
.61404 .64437 m .71009 .64696 L .63858 .65629 L .66 0 .546 r
F
0 g
.63858 .65629 m
.64877 .66964 L
s
.62096 .24767 m .73712 .24615 L .66241 .21827 L 0 .88 .527 r
F
.62096 .24767 m .66907 .51088 L .66241 .21827 L 0 .353 .345 r
F
0 g
.66342 .26298 m
.67757 .26808 L
s
.55009 .23583 m .62096 .24767 L .66241 .21827 L 0 .88 .527 r
F
.62096 .24767 m .66241 .21827 L .66907 .51088 L 0 .353 .345 r
F
0 g
.62096 .24767 m
.62213 .31732 L
s
.73712 .24615 m .79506 .56196 L .74663 .53339 L 0 .81 .332 r
F
.66241 .21827 m .73712 .24615 L .74663 .53339 L 0 .733 .358 r
F
0 g
.73712 .24615 m
.78399 .2816 L
s
.36745 .65244 m .34095 .62368 L .39603 .64123 L .66 0 .546 r
F
.36745 .65244 m .29858 .64104 L .34095 .62368 L F
0 g
.35276 .6655 m
.36745 .65244 L
s
.27799 .661 m
.29858 .64104 L
s
.39949 .24305 m .47207 .52375 L .47316 .23421 L 0 .576 .368 r
F
.39949 .24305 m .46383 .19971 L .36488 .21192 L 0 .88 .527 r
F
.39949 .24305 m .47316 .23421 L .46383 .19971 L F
0 g
.33779 .2611 m
.39949 .24305 L
s
.6173 .53352 m
.61739 .53923 L
s
.28668 .56543 m .21635 .55283 L .2742 .52572 L 0 .905 .543 r
F
0 g
.28668 .56543 m
.31499 .55276 L
s
.19021 .58345 m
.21635 .55283 L
s
.26519 .58834 m
.28668 .56543 L
s
.61404 .64437 m .67412 .62857 L .71009 .64696 L .66 0 .546 r
F
0 g
.71009 .64696 m
.72377 .66726 L
s
.28298 .23665 m .3593 .50574 L .2742 .52572 L 0 .501 .361 r
F
.28298 .23665 m .36488 .21192 L .3593 .50574 L F
0 g
.22709 .27026 m
.28298 .23665 L
s
.55009 .23583 m .66241 .21827 L .56746 .20195 L 0 .88 .527 r
F
.47316 .23421 m .55009 .23583 L .56746 .20195 L F
0 g
.55009 .23583 m
.62096 .24767 L
s
.47316 .23421 m .56746 .20195 L .46383 .19971 L 0 .88 .527 r
F
0 g
.39949 .24305 m
.47316 .23421 L
s
.47316 .23421 m
.55009 .23583 L
s
.57723 .63524 m .67412 .62857 L .61404 .64437 L .66 0 .546 r
F
0 g
.61404 .64437 m
.63858 .65629 L
s
.68456 .55107 m .74663 .53339 L .79506 .56196 L 0 .905 .543 r
F
0 g
.79506 .56196 m
.81137 .59294 L
s
.68456 .55107 m
.69844 .55883 L
s
.69844 .55883 m
.72242 .57222 L
s
.39603 .64123 m .40147 .61106 L .4359 .63318 L .66 0 .546 r
F
.39603 .64123 m .34095 .62368 L .40147 .61106 L F
0 g
.36745 .65244 m
.39603 .64123 L
s
.29858 .64104 m
.34095 .62368 L
s
.53187 .62998 m .61857 .61429 L .57723 .63524 L .66 0 .546 r
F
0 g
.57697 .60933 m
.5771 .6218 L
s
.57723 .63524 m .61857 .61429 L .67412 .62857 L .66 0 .546 r
F
0 g
.57723 .63524 m
.61404 .64437 L
s
.67412 .62857 m
.71009 .64696 L
s
.64727 .54063 m
.68456 .55107 L
s
.56746 .20195 m .66241 .21827 L .66907 .51088 L 0 .676 .365 r
F
.66241 .21827 m .74663 .53339 L .66907 .51088 L 0 .733 .358 r
F
0 g
.66241 .21827 m
.73712 .24615 L
s
.4359 .63318 m .47369 .60488 L .48293 .62927 L .66 0 .546 r
F
.4359 .63318 m .40147 .61106 L .47369 .60488 L F
0 g
.39603 .64123 m
.4359 .63318 L
s
.53187 .62998 m .54909 .60601 L .61857 .61429 L .66 0 .546 r
F
0 g
.57723 .63524 m
.61857 .61429 L
s
.61739 .53923 m
.61857 .61429 L
s
.48293 .62927 m .54909 .60601 L .53187 .62998 L .66 0 .546 r
F
0 g
.53187 .62998 m
.57723 .63524 L
s
.36488 .21192 m .46232 .49587 L .3593 .50574 L 0 .572 .366 r
F
.36488 .21192 m .46383 .19971 L .46232 .49587 L F
0 g
.28298 .23665 m
.36488 .21192 L
s
.48293 .62927 m .47369 .60488 L .54909 .60601 L .66 0 .546 r
F
0 g
.4359 .63318 m
.48293 .62927 L
s
.48293 .62927 m
.53187 .62998 L
s
.33136 .54544 m .2742 .52572 L .3593 .50574 L 0 .905 .543 r
F
0 g
.33136 .54544 m
.37206 .5362 L
s
.21635 .55283 m
.2742 .52572 L
s
.31499 .55276 m
.33136 .54544 L
s
.61857 .61429 m
.67412 .62857 L
s
.34095 .62368 m
.40147 .61106 L
s
.56746 .20195 m .66907 .51088 L .57027 .49768 L 0 .676 .365 r
F
0 g
.6253 .50503 m
.62549 .51616 L
s
.46383 .19971 m .56746 .20195 L .57027 .49768 L 0 .626 .367 r
F
0 g
.56746 .20195 m
.66241 .21827 L
s
.46383 .19971 m .57027 .49768 L .46232 .49587 L 0 .626 .367 r
F
0 g
.36488 .21192 m
.46383 .19971 L
s
.46383 .19971 m
.56746 .20195 L
s
.6258 .53462 m .66907 .51088 L .74663 .53339 L 0 .905 .543 r
F
0 g
.57892 .52854 m
.6258 .53462 L
s
.74663 .53339 m
.79506 .56196 L
s
.6258 .53462 m
.64727 .54063 L
s
.39544 .53089 m .3593 .50574 L .46232 .49587 L 0 .905 .543 r
F
0 g
.39544 .53089 m
.44424 .52634 L
s
.37206 .5362 m
.39544 .53089 L
s
.54909 .60601 m
.61857 .61429 L
s
.40147 .61106 m
.47369 .60488 L
s
.2742 .52572 m
.3593 .50574 L
s
.55211 .52506 m .57027 .49768 L .66907 .51088 L 0 .905 .543 r
F
0 g
.5232 .52459 m
.55211 .52506 L
s
.66907 .51088 m
.74663 .53339 L
s
.66241 .21827 m
.66907 .51088 L
s
.6258 .53462 m
.66907 .51088 L
s
.55211 .52506 m
.57892 .52854 L
s
.47207 .52375 m .46232 .49587 L .57027 .49768 L 0 .905 .543 r
F
0 g
.47207 .52375 m
.5232 .52459 L
s
.44424 .52634 m
.47207 .52375 L
s
.47369 .60488 m
.54909 .60601 L
s
.57027 .49768 m
.66907 .51088 L
s
.3593 .50574 m
.46232 .49587 L
s
.46232 .49587 m
.57027 .49768 L
s
[ .01 .01 ] 0 setdash
.36372 .12142 m
.94477 .27584 L
s
.94477 .27584 m
.96772 .64676 L
s
.96772 .64676 m
.35577 .5318 L
s
.35577 .5318 m
.36372 .12142 L
s
.0891 .37107 m
.06959 .71692 L
s
.06959 .71692 m
.35577 .5318 L
s
.35577 .5318 m
.36372 .12142 L
s
.36372 .12142 m
.0891 .37107 L
s
.003 w
[ ] 0 setdash
.94477 .27584 m
.96772 .64676 L
s
.25 Mabswid
.9495 .35222 m
.94344 .35071 L
s
gsave
.96163 .35525 -61 -9.25158 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.95816 .49211 m
.95205 .49076 L
s
gsave
.97036 .4948 -61 -9.45704 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.96715 .63748 m
.96101 .63632 L
s
gsave
.97943 .63981 -61 -9.67137 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.9512 .37978 m
.94756 .37889 L
s
.95292 .40754 m
.94927 .40667 L
s
.95465 .43551 m
.951 .43466 L
s
.9564 .4637 m
.95274 .46287 L
s
.95993 .52073 m
.95626 .51995 L
s
.96171 .54958 m
.95804 .54881 L
s
.96351 .57865 m
.95983 .57791 L
s
.96532 .60795 m
.96164 .60723 L
s
.94781 .32488 m
.94417 .32395 L
s
.94613 .29774 m
.9425 .29679 L
s
gsave
1.02909 .4733 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00IWoo10000goo0`00/7oo001VOol01`00Oomoogoo001oo`0000=oo`03001oogoo
0:eoo`00Igoo00<007ooOol00Woo00D007ooOomoo`000:moo`00Ggoo1`000Woo00D007ooOomoo`00
00=oo`03001oogoo03Yoo`<0071oo`00JGoo00@007ooOol000=oo`03001oogoo03]oo`03001oogoo
06moo`00JGoo00@007ooOol000=oo`03001oogoo03]oo`03001oogoo06moo`00IWoo00@007ooOol0
009oo`05001oogooOol0000mOol00`00Oomoo`1_Ool006Moo`8000Aoo`<003eoo`03001oo`00071o
o`00[Goo00<007oo0000L7oo002/Ool01@00Oomoogoo0000Kgoo002[Ool3000017oo00000000KWoo
001OOol4000[Ool30002Ool3002:Ool005ioo`03001oo`00009oo`D002Moo`04001oogoo0003Ool0
0`00Oomoo`27Ool0061oo`03001oogoo00Aoo`H0029oo`04001oogoo0003Ool00`00Oomoo`27Ool0
05aoo`03001oogoo00Uoo`03001oo`0000<001Ioo`L000Aoo`04001oogoo0003Ool00`00Oomoo`27
Ool005]oo`03001oogoo011oo`D001aoo`04001oogoo0003Ool00`00Oomoo`27Ool005Yoo`03001o
ogoo00=oo`03001oogoo00eoo`03001oo`0000@001Qoo`04001oogoo0003Ool00`00Oomoo`27Ool0
061oo`03001oogoo01=oo`H001=oo`04001oogoo0003Ool00`00Oomoo`27Ool005Qoo`03001oogoo
00Eoo`03001oogoo01Aoo`03001oo`0000<0015oo`8000=oo`<008Yoo`00Egoo00<007ooOol01Woo
00<007ooOol06Woo1000Wgoo001FOol00`00Oomoo`0VOol00`00Ool00004000YOol3001^Ool005Ao
o`03001oogoo00Uoo`03001oogoo029oo`<002Ioo`05001oogooOol0001]Ool005=oo`03001oogoo
00Yoo`03001oogoo02=oo`03001oo`0000<0029oo`05001oogooOol0001]Ool0059oo`03001oogoo
00]oo`03001oogoo02Uoo`D001eoo`05001oogooOol0001]Ool0061oo`03001oogoo02]oo`03001o
o`0000D001Qoo`05001oogooOol0001]Ool0051oo`03001oogoo045oo`<001Moo`05001oogooOol0
001]Ool004moo`03001oogoo04=oo`03001oo`0000@0019oo`05001oogooOol0001]Ool004ioo`03
001oogoo00moo`03001oogoo03Qoo`D000moo`<006ioo`00H7oo00<007ooOol0>Goo00<007ooOol0
1P00Ngoo001;Ool2000COol00`00Oomoo`10Ool3000YOol30002Ool30019Ool004Yoo`03001oogoo
05Ioo`03001oogoo00D002Eoo`04001oogoo0003Ool00`00Oomoo`16Ool007Mooa80025oo`D0025o
o`04001oogoo0003Ool00`00Oomoo`16Ool004Qoo`03001oogoo01Aoo`03001oogoo00ioo`L000<2
B`l2Ra4001Aoo`H001aoo`04001oogoo0003Ool00`00Oomoo`16Ool004Moo`03001oogoo01Eoo`03
001oogoo00Qoo`H000X2Ba`2R`@2Z`H0015oo`D001Yoo`04001oogoo0003Ool00`00Oomoo`16Ool0
04Ioo`03001oogoo01Ioo`04001oogooOol7000@0T/L0X/:0Z/7000:Ool00`00Oomoo`02Ool4000F
Ool01000Oomoo`000goo00<007ooOol0AWoo001NOol5000G0T/L0X/A0Z/6000;Ool7000AOol01000
Oomoo`000goo00<007ooOol0AWoo0013Ool2000EOol400020P/J0T/L0X/G0Z/4000<Ool4000>Ool2
0003Ool30019Ool0049oo`03001oogoo019oo`<000D22`030002B`9;01P2Ba`2RaT2Z`030002j`00
008000]oo`03001oo`0000<005]oo`00Dgoo1000208;00<0009;0T/0609;70:;6@:[00<000;[0^/0
0P;[0P003goo100097oo10000goo0`00:Goo0011Ool00`00Oomoo`0;Ool4000<0P/00`000T/2B`0H
0T/L0X/I0Z/00`000^/2j`040^/3000=Ool00`00Ool00005000OOol01`00Oomoogoo001oo`0000=o
o`03001oogoo02Ioo`00@7oo00<007ooOol02Goo0`00408;00<0009;0T/0609;70:;6@:[00<000;[
0^/01`;[0P004Goo10007Woo00<007ooOol00Woo00D007ooOomoo`0002Qoo`00?goo00<007ooOol0
1goo0`00508;6P9;70:;6@:[00<000;[0^/02@;[0`003goo00<007ooOol010006goo00D007ooOomo
o`0000=oo`03001oogoo02Ioo`00B7oo00<0006;0P/05@8;6P9;70:;6@:[00<000;[0^/030;[0P00
4goo1@0067oo00@007ooOol000=oo`03001oogoo02Ioo`00?Goo00<007ooOol01Woo0P000P6;5@8;
00<0009;0T/0609;70:;6@:[00<000;[0^/03P;[0`0047oo00@007ooOomoo`H001=oo`04001oogoo
0003Ool00`00Oomoo`0VOol003aoo`03001oogoo00Ioo`030001R`6;0081RaD22`030002B`9;01P2
Ba`2RaT2Z`030002j`;[0142j`8001Eoo`D000ioo`04001oogoo0002Ool01@00Oomoogoo0000:7oo
000kOol00`00Oomoo`05Ool200050H/E0P/00`000T/2B`0H0T/L0X/I0Z/00`000^/2j`0A0^/20bX0
0`00Oomoo`0GOol4000;Ool20004Ool3000YOol003Uoo`03001oogoo00Eoo`8000L1RaH22aX2Ba`2
RaT2Z`030002j`;[0142j`<3:P03001oogoo01Moo`03001oogoo00D003Qoo`00>7oo00<007ooOol0
1Goo00<0006;0H/01`6;5P8;6P9;70:;6@:[00<000;[0^/04@;[10<Z0P007Goo1`00<goo000gOol0
0`00Oomoo`04Ool2000:0H/E0P/00`000T/2B`0H0T/L0X/I0Z/00`000^/2j`0A0^/60bX00`00Oomo
o`0KOol00`00Oomoo`04000bOol003eoo`030001R`6;00X1RaD22`030002B`9;01P2Ba`2RaT2Z`03
0002j`;[0142j`L3:P03001oogoo021oo`D002ioo`00=Goo00<007ooOol017oo00<0006;0H/02`6;
5@8;00<0009;0T/0609;70:;6@:[00<000;[0^/04@;[20<Z0P009Goo1@00:Goo000dOol00`00Oomo
o`05Ool00`000H/1R`0;0H/E0P/00`000T/2B`0H0T/L0X/I0Z/00`000^/2j`0A0^/:0bX00`00Oomo
o`0SOol00`00Ool00003000WOol003=oo`03001oogoo00Eoo`030001R`6;00`1RaH22aX2Ba`2RaT2
Z`030002j`;[0142j`/3:P03001oogoo02=oo`03001oogoo009oo`8002Eoo`00<Goo00<007ooOol0
1Woo00<0001X0H/03@6;5@8;00<0009;0T/0609;70:;6@:[00<000;[0^/04@;[30<Z00<007ooOol0
9Goo0P0000=oo`00Ool097oo000`Ool00`00Oomoo`07Ool00`0006P1R`0=0H/E0P/00`000T/2B`0H
0T/L0X/I0Z/00`000^/2j`0A0^/<0bX00`00Oomoo`0TOol01@00Oomoogoo00009Goo000_Ool00`00
Oomoo`07Ool00`0006P0J00>0H/E0P/00`000T/2B`0H0T/L0X/I0Z/00`000^/2j`0A0^/<0bX00`=V
001oo`0QOol00`00Oomoo`04Ool00`00Oomoo`0SOol003Qoo`040000J01X06P>0H/E0P/00`000T/2
B`0H0T/L0X/J0Z/00`000^/2j`0@0^/<0bX00`=V001oo`0POol00`00Oomoo`05Ool00`00Oomoo`0S
Ool002eoo`03001oogoo00Moo`030000J01X0080J0h1RaH22aX2Ba`2RaX2Z`030002j`;[0102j``3
:P030fH007oo01moo`03001oogoo00Eoo`8002Eoo`00;7oo00<007ooOol027oo00<0001X06P00P1X
3P6;5P8;6P9;70:;6P:[00<000;[0^/040;[30<Z0P=V00<007ooOol06Woo0P002Woo00<007ooOol0
8goo000[Ool00`00Oomoo`08Ool00`0006P0J00306P>0H/E0P/00`000T/2B`0H0T/L0X/J0Z/00`00
0^/2j`0@0^/<0bX20fH00`00Oomoo`0IOol00`00Oomoo`0:Ool00`00Oomoo`0SOol003Eoo`030000
J01X00@0J0h1RaD22`030002B`9;01P2Ba`2RaX2Z`030002j`;[0102j``3:P<3IP03001oogoo02Eo
o`03001oogoo02=oo`00:7oo0P002goo1`1X3P6;5@8;00<0009;0T/0609;70:;6P:[00<000;[0^/0
40;[30<Z0`=V00<007ooOol057oo0P0047oo00<007ooOol08Woo000WOol00`00Oomoo`0;Ool706P=
0H/G0P/J0T/L0X/J0Z/00`000^/2j`0@0^/<0bX30fH00`00Oomoo`0COol00`00Oomoo`0?Ool2000T
Ool003Eoo`L0J0d1RaL22aX2Ba`2RaX2Z`030002j`;[0102j``3:P@3IP03001oogoo00moo`8001=o
o`8002Aoo`009Goo00<007ooOol03Goo1P1X3P6;5P8;00<0009;0T/0609;70:;6P:[00<000;[0^/0
4@;[2`<Z10=V4Goo00<007ooOol04goo0P0097oo000TOol00`00Oomoo`0>Ool606P>0H/F0P/00`00
0T/2B`0H0T/L0X/J0Z/00`000^/2j`0A0^/;0bX40fH@Ool00`00Oomoo`0EOol00`00Oomoo`0ROol0
02=oo`03001oogoo00moo`H0J0h1RaH22`030002B`9;01P2Ba`2RaX2Z`030002j`;[0142j``3:P<3
IPeoo`8001Uoo`03001oogoo029oo`00=Goo1P1X3P6;5`8;6P9;70:;6P:[00<000;[0^/04@;[30<Z
0`=V37oo00<007ooOol06Goo00<007ooOol08Woo000QOol00`00Oomoo`0AOol606P>0H/G0P/J0T/L
0X/J0Z/00`000^/2j`0A0^/<0bX30fHXOol00`00Oomoo`0ROol0021oo`03001oogoo019oo`H0J0h1
RaH22`030002B`9;01P2Ba`2RaX2Z`030002j`;[0142j``3:P<3IPUoo`8001eoo`03001oogoo029o
o`007goo00<007ooOol04goo1P1X3P6;5P8;00<0009;0T/0609;70:;6P:[00<000;[0^/04@;[30<Z
0`=V1goo0P007goo00<007ooOol08Woo000MOol00`00Oomoo`0EOol606P>0H/F0P/00`000T/2B`0H
0T/L0X/J0Z/00`000^/2j`0A0^/<0bX00`=V0003IP05Ool00`00Oomoo`0NOol3000TOol001aoo`03
001oogoo01Ioo`H0J0h1RaH22`030002B`9;01P2Bad2RaT2Z`030002j`;[0142j``3:P030fH000=V
00Aoo`03001oogoo025oo`03001oogoo00eoo`<0009oo`<000eoo`006goo00<007ooOol05goo1P1X
3P6;5`8;6P9;7@:;6@:[00<000;[0^/04@;[30<Z0`=V0goo00<007ooOol08Woo00<007ooOol03Woo
00@007ooOol000=oo`03001oogoo00Yoo`00=7oo1`1X3P6;5P8;00<0009;0T/0609;7@:;6@:[00<0
00;[0^/04@;[30<Z0`=V00<007ooOol09Goo00<007ooOol03Woo00@007ooOol000=oo`03001oogoo
00Yoo`006Goo00<007ooOol067oo1`1X3P6;5P8;00<0009;0T/0609;7@:;6@:[00<000;[0^/04@;[
30<Z0`=V:7oo00<007ooOol00goo1`0017oo00@007ooOol000=oo`03001oogoo00Yoo`0067oo00<0
07ooOol06Goo1`1X3P6;5P8;00<0009;0T/0609;7@:;6@:[00<000;[0^/04@;[30<Z10=V9goo00<0
07ooOol03Woo00@007ooOol000=oo`03001oogoo00Yoo`005goo0P006goo1`1X3P6;5P8;00<0009;
0T/0609;7@:;6@:[00<000;[0^/04@;[30<Z10=V:7oo00<007ooOol03Goo00@007ooOol000=oo`03
001oogoo00Yoo`005goo00@007ooOomoo`<001Ioo`L0J0h1RaH22a/2Bad2RaT2Z`030002j`;[0142
j``3:P@3IRMoo`8000moo`04001oogoo0003Ool00`00Oomoo`0:Ool001Moo`03001oogoo00Ioo`<0
015oo`L0J0h1RaH22a/2Bad2RaT2Z`030002j`;[0142j``3:P@3IRMoo`8000ioo`8000=oo`<000eo
o`005goo00<007ooOol02goo10002goo1`1X3P6;5P8;00<0009;0T/0609;7@:;6@:[00<000;[0^/0
4@;[30<Z10=V:7oo00<007ooOol08Goo000ZOol40006Ool706P>0H/F0P/00`000T/2B`0H0T/M0X/I
0Z/00`000^/2j`0A0^/<0bX40fHXOol00`00Oomoo`0QOol001Moo`03001oogoo01Eoo`@00003Ool0
J01X00D0J0h1RaD22`030002B`9;01T2Bad2RaT2Z`030002j`;[0142j``3:P@3IRQoo`03001oogoo
025oo`005goo00<007ooOol06Woo1`1X3P6;5P8;6`9;7@:;6@:[00<000;[0^/04@;[30<Z10=V:7oo
00<007ooOol08Goo000GOol00`00Oomoo`0JOol706P>0H/F0P/K0T/M0X/I0Z/00`000^/2j`0A0^/<
0bX40fHXOol00`00Oomoo`0QOol001Moo`03001oogoo01Yoo`L0J0h1RaD22`030002B`9;01T2Bad2
RaT2Z`030002j`;[0142j``3:P@3IRQoo`03001oogoo025oo`00=7oo1`1X3P6;5@8;00<0009;0T/0
6@9;7@:;6@:[00<000;[0^/04@;[30<Z10=V9goo0P008goo000FOol00`00Oomoo`0KOol706P>0H/E
0P/00`000T/2B`0I0T/M0X/I0Z/00`000^/2j`0A0^/<0bX40fHXOol00`00Oomoo`0QOol001Ioo`03
001oogoo01]oo`L0J0h1RaD22`030002B`9;01T2Bad2RaT2Z`030002j`;[0142j``3:P@3IRQoo`03
001oogoo025oo`005Woo00<007ooOol06goo1P1X3`6;5P8;6`9;7@:;6@:[00<000;[0^/04@;[30<Z
10=V:7oo00<007ooOol08Goo000FOol00`00Oomoo`0KOol606P?0H/E0P/00`000T/2B`0I0T/M0X/I
0Z/00`000^/2j`0A0^/<0bX40fHXOol00`00Oomoo`0QOol003Aoo`H0J0l1RaD22`030002B`9;01T2
Bad2RaT2Z`030002j`;[0142j`d3:P<3IRQoo`03001oogoo025oo`00=7oo1P1X3`6;5@8;00<0009;
0T/06@9;7@:;6@:[00<000;[0^/04@;[3@<Z0`=V:7oo00<007ooOol08Goo000FOol00`00Oomoo`0K
Ool606P?0H/E0P/00`000T/2B`0I0T/M0X/I0Z/00`000^/2j`0A0^/=0bX30fHXOol00`00Oomoo`0Q
Ool001Ioo`03001oogoo01]oo`H0J0l1RaH22a/2Bad2RaT2Z`030002j`;[0142j`d3:P<3IRMoo`<0
029oo`005Woo00<007ooOol06goo1P1X3`6;5P8;6`9;7@:;6P:[00<000;[0^/040;[3@<Z0`=V:7oo
0P008Woo000dOol606P?0H/E0P/00`000T/2B`0I0T/M0X/J0Z/00`000^/2j`0@0^/=0bX30fHYOol0
0`00Oomoo`0POol003Aoo`H0J0l1RaD22`030002B`9;01T2Bad2RaX2Z`030002j`;[0102j`d3:P<3
IRUoo`03001oogoo021oo`005Woo00<007ooOol06Woo1`1X3`6;5@8;00<0009;0T/06@9;7@:;6P:[
00<000;[0^/040;[3@<Z0`=V:Goo00<007ooOol087oo000FOol00`00Oomoo`0JOol706P?0H/F0P/K
0T/M0X/J0Z/00`000^/2j`0@0^/=0bX30fHYOol00`00Oomoo`0POol001Ioo`03001oogoo01Yoo`L0
J0l1RaH22a/2Bad2RaX2Z`030002j`;[0102j`d3:P@3IRQoo`03001oogoo021oo`005Woo00<007oo
Ool06Woo1`1X3P6;5P8;00<0009;0T/06@9;7@:;6P:[00<000;[0^/040;[3@<Z10=V9goo0P008Woo
000cOol706P>0H/F0P/00`000T/2B`0I0T/M0X/J0Z/00`000^/2j`0A0^/<0bX40fHXOol00`00Oomo
o`0POol001Ioo`03001oogoo01Yoo`L0J0h1RaH22`030002B`9;01T2Bad2RaX2Z`030002j`;[0142
j``3:P@3IRQoo`03001oogoo021oo`005Woo00<007ooOol06Woo1`1X3P6;5P8;00<0009;0T/06@9;
7@:;6P:[00<000;[0^/04@;[30<Z10=V:7oo00<007ooOol04Woo1P0027oo000EOol00`00Oomoo`0K
Ool706P>0H/G0P/K0T/M0X/J0Z/00`000^/2j`0A0^/<0bX40fHXOol00`00Oomoo`0COol01@00Oomo
ogoo000027oo000EOol00`00Oomoo`0KOol706P>0H/F0P/00`000T/2B`0I0T/M0X/J0Z/00`000^/2
j`0A0^/<0bX40fHXOol00`00Oomoo`0COol00`00Oomoo`0:Ool003=oo`L0J0h1RaH22`030002B`9;
01T2Bad2RaX2Z`030002j`;[0142j``3:P@3IRQoo`03001oogoo01Aoo`03001oogoo00Uoo`00<goo
1`1X3P6;5P8;00<0009;0T/06@9;7@:;6P:[00<000;[0^/04@;[30<Z10=V:7oo00<007ooOol05Goo
00<007ooOol027oo000EOol00`00Oomoo`0KOol706P>0H/F0P/00`000T/2B`0I0T/M0X/J0Z/00`00
0^/2j`0A0^/<0bX40fHWOol20006Ool3000?Ool00`00Oomoo`07Ool001Eoo`03001oogoo01]oo`L0
J0h1RaL22aL2BbD001H2Z`030002j`;[0142j``3:P@3IRQoo`8000Aoo`05001oogooOol0000:Ool0
1@00Oomoogoo00002Goo000EOol00`00Oomoo`0KOol706P>0H/F0P/00`000T/2B`0<0T/9000U0i47
000?0Z/00`000^/2j`0A0^/<0bX40fHXOol20004Ool01@00Oomoogoo00002Woo1P0027oo000cOol7
06P>0H/F0P/00`000T/2B`030T/9000T0i400`:;0i43T@0>0i4600090Z/00`000^/2j`0A0^/<0bX4
0fHYOol00`00Oomoo`02Ool01@00Oomoogoo000067oo000cOol706P>0H/E0P/700140i4700020Z/0
0`000^/2j`0A0^/<0bX40fHYOol00`00Oomoo`02Ool01@00Oomoogoo000067oo000EOol00`00Oomo
o`0KOol606P?0H/@0P/500000`>A0003T@0K0i400`9;0i43T@0<0i400`:;0i43T@0R0i45000A0^/<
0bX40fHYOol00`00Oomoo`02Ool01@00Oomoogoo000067oo000EOol00`00Oomoo`0KOol606P?0H/;
0P/5000^0i420X/<0i400`:[0i43T@0G0i4200040i43000>0^/<0bX40fHYOol00`00Oomoo`02Ool0
1@00Oomoogoo000067oo000EOol00`00Oomoo`0KOol606P?0H/70P/4000`0i400`:;0i43T@0V0i42
00090i43000;0^/=0bX30fHXOol20005Ool3000IOol001Eoo`03001oogoo01]oo`H0J0l1R`822`D0
00l3T@030003T@>A01P3T@`000h3T@030Z/3T@>A01@3T@8000h3T@@000L2j`d3:P<3IRUoo`03001o
ogoo01moo`00<goo1P1X3P6;0`0050>A00<000>A0i403P>A2P0015`;26P;4P004@>A0P0050>A0`00
10;[3@<Z0`=V:Goo00<007ooOol07goo000EOol00`00Oomoo`0KOol606P<0H/2000G0i400`000i43
T@060i48000>G0/DJ0/6K0/900060i42000I0i4300000`;[0bX3:P0;0bX30fHYOol00`00Oomoo`0O
Ool001Eoo`03001oogoo01]oo`H0J0X1R`8001T3T@030003T@>A00H000=D2a=L2aAX2`m/2`P001`3
T@<000/3:P<3IRUoo`03001oogoo01moo`005Goo00<007ooOol06goo1P1X1`6;0`005`>A0P000`>A
1P0000ED2`00000005@;01=L2aAX2a9/2`03001h2gP;009h2`<001`3T@8000T3:P<3IRUoo`03001o
ogoo01moo`005Goo00<007ooOol06goo1P1X1@6;0P006@>A1P002U@;00<005`;00000P003e`;56P;
4V`;00<007P;N0/01GP;0`006`>A0P001`<Z0`=V:Goo00<007ooOol07goo000bOol706P30H/2000H
0i44000@E0/4G0/00`00G0]L2`030009G0/DJ0/BK0/00`00N0]h2`08N0/3000J0i4200050bX30fHY
Ool00`00Oomoo`0OOol001Aoo`03001oogoo01]oo`L0J0030H/0000001P3T@@000902a1D2`aL2`<0
00AL2aAX2a9/2`03001h2gP;00]h2`<001T3T@030003:P<Z0083:P<3IRQoo`80025oo`0057oo00<0
07ooOol06goo1`1X00<000>A0i405P>A0P0000=02`00@0/00d0;45@;4E`;10004VP;4V`;00<007P;
N0/02gP;00=<2g`:O0X00`005`>A0P000P<Z10=V:7oo00<007ooOol07goo000DOol00`00Oomoo`0K
Ool706P00`000i43T@0C0i430008@0/@E0/CG0/3J0/4000=J0/BK0/00`00N0]h2`0;N0/00d`;O0Yl
2P03O0X2000G0i4200040fHXOol2000POol001Aoo`03001oogoo01]oo`H0J0030003T@>A0143T@<0
0004O0Y02`000007@0/@E0/CG0/8J0/40008J0/BK0/00`00N0]h2`0<N0/7O0X2000G0i4010000fH3
IP=V:7oo0P0087oo000bOol506P00`000i43T@0A0i401P0050TD2A@9O0X000U02a1D2a=L2`iX2`<0
00=X2a9/2`03001h2gP;00ah2`Ul2P8001D3T@040003IP=V0fHYOol00`00Oomoo`0NOol0039oo`@0
J0030003T@>A0183T@05000D2A@950Ul2P0:@0/@E0/CG0/CJ0/4000?K0/00`00N0]h2`0<N0/9O0X2
O0L2000D0i400`000fH3IP0YOol00`00Oomoo`0NOol001Aoo`03001oogoo01]oo`<0J0030003T@>A
0183T@03000D2A@900800003O0Y02d0;00Q02a1D2a=L2aAX2`A/2`@000Y/2`03001h2gP;00ah2`Ul
2PAl1`030003T@>A0143T@030003IP=V02Uoo`03001oogoo01ioo`0057oo00<007ooOol06goo0P1X
00<000>A0i404P>A00@001@950T0008D2@]02a1D2a=L2aAX2`U/2`@000E/2`03001h2gP;00ah2`Ul
2PAl1`030003T@>A0183T@030003IWoo02Qoo`03001oogoo01ioo`0057oo00<007ooOol06goo00<0
J0000i404`>A00<000=Z50T011@92d0;45@;4e`;56P;3f`;10003WP;2W`:0g`700<1:P000i404P>A
00<000=VOol09goo0P0087oo000bOol00`000i43T@0B0i4010000fX0000011@92d0;45@;4e`;56P;
4V`;00<007P;00000P002WP;2W`:0g`700<1:P1V00004P>A00<000=VOol0:7oo00<007ooOol07Woo
000bOol00`000i43T@0A0i4300000`=Z50TD2@0350T;@0/@E0/CG0/DJ0/BK0/00`00N0]h2`04N0/4
0004N0/:O0X3O0L00`4Z06H0000C0i400`00Oomoo`0WOol00`00Oomoo`0NOol001Aoo`03001oogoo
01]oo`030003T@>A0103T@8000<3JPDD2@]02a1D2a=L2aAX2a9/2`03001h2gP;00Uh2`@000Ul2P=l
1`040BX0IP1V000B0i400`00Oomoo`0WOol00`00Oomoo`0NOol001Aoo`03001oogoo01]oo`030003
T@>A00l3T@030003T@0000<3JPDD2@]02a1D2a=L2aAX2a9/2`03001h2gP;00ah2`9l2P@000Al2P=l
1`050BX0IP1V06H0000B0i400`00Oomoo`0VOol00`00Oomoo`0NOol001Aoo`03001oogoo01]oo`03
0003T@>A00h3T@040003T@>A00030fX550T;@0/@E0/CG0/DJ0/BK0/00`00N0]h2`0<N0/8O0X30002
O0L01@4Z06H0IP1V00004P>A00<007ooOol09Woo00<007ooOol07Woo000DOol00`00Oomoo`0LOol0
0`000i43T@0:0i4200040i4010000fX3JP=Z1A@92d0;45@;4e`;56P;4V`;00<007P;N0/037P;2W`:
0g`710004P>A00<007ooOol09goo00<007ooOol07Woo000cOol00`000i43T@090i400`000i43T@04
0i4010000fX3JP=Z1A@92d0;45@;2U`;8`0036`;00<007P;N0/037P;2W`:0g`700D1:P1V06H000>A
00@000d3T@03001oogoo02Ioo`80021oo`0057oo00<007ooOol077oo00<000>A0i4020>A00<000>A
0i401@>A00@000=Z0fX3JPDD2@]02`iD2``002=D4@T000=/2`03001h2gP;00ah2`Yl2P=l1`030BX0
IP0000L3T@@000P3T@03001oogoo02Moo`03001oogoo01ioo`0057oo00<007ooOol077oo0P001`>A
00<000>A0i401`>A0P000P=Z1A@92d0;2U@;1000>5@A1P0037P;2W`:0g`700<1:P1V000030>A1000
0P>A00<007ooOol0:7oo00<007ooOol07Woo000COol00`00Oomoo`0OOol00`000fX3T@030i400`00
0i43T@0:0i400`000fXD2@0450T;@0/6E0/4000lE1420004E1440008N0/:O0X3O0L00`4Z0003T@0B
0i43000XOol00`00Oomoo`0NOol001=oo`03001oogoo021oo`060003T@>A0i4000=Z3@>A00<001@9
50T00a@92d0;0U@;1000?U@A0P002U@A0`001GP;2W`:0g`700<000>A0i404P>A00<007ooOol00Woo
0`008goo0P007goo000gOol200070i400`<[0i43T@070i4550T:@0/30011E1400`00E15D4@0=E144
00000gP;O0Yl2P08O0X3O0LC0i42000:Ool4000NOol00`00Oomoo`0MOol003Ioo`03001oo`0000`3
T@030b/3T@>A0083T@DD2@M02`<0021D4AL000]D4@8001AD4@<000Ql2P=l1a83T@03001oogoo00mo
o`@001Uoo`03001oogoo01eoo`004goo00<007ooOol08goo00<000>A0i403@>A1Q@9140;0`006U@A
2@000f`;36P;260;1P000e@A0P006E@A0P001W`:0g`740>A0P005goo100057oo00<007ooOol07Goo
000COol00`00Oomoo`0LOol20006Ool00`000i43T@0<0i4650T0140;0000000065@A1@0000=d2f`;
K0/02F`;36P;2f0;0eP;1P006U@A0P0017`:0g`73P>A0P007goo0`000Woo0P002Goo0`001Woo0`00
0Woo0`004Goo000COol00`00Oomoo`0KOol00`00Oomoo`07Ool00`000i43T@0;0i4650T00`00E15D
4@0EE1440006M0/;K0/<J0/;H0/9F0/5000GE1420002O0X3O0L=0i400`00Oomoo`0VOol00`00Oomo
o`030005Ool00`00Oomoo`05Ool01000Oomoo`000goo00<007ooOol03Woo000lOol2000;0i4550T0
0`00E15D4@0CE14300000g`;M0]d2`07M0/;K0/<J0/;H0/;F0/3B0/3000FE1420003O0L;0i42000_
Ool00`00Ool000030007Ool01000Oomoo`000goo00<007ooOol03Woo000^Ool2000>Ool300030i40
0`<[0i43T@020i4450T00`00E15D4@0BE1420004O0/9M0/;K0/<J0/;H0/;F0/6B0/3000EE1400`00
O0Ml1`0:0i400`00Oomoo`0_Ool01000Oomoogoo0P001goo00@007ooOol000=oo`03001oogoo00io
o`004goo00<007ooOol05goo00<007ooOol04Goo0`001@>A0a@900<005@AE1404U@A00<007`;O0/0
17`;2G@;2f`;36P;2f0;2eP;1dP;0R`:0P004e@A00<007`7O0L01`>A0`00<Woo10002Goo00@007oo
Ool000=oo`03001oogoo00ioo`004goo00<007ooOol0;Goo00<3T@0000000`>A0Q@900<005@AE140
4U@A00<007`;O0/01G`;2G@;2f`;36P;2f0;2eP;1dP;12`:00<005@AE1404E@A00@007`70i43T@D0
03Aoo`8000aoo`04001oogoo0003Ool00`00Oomoo`0>Ool001=oo`03001oogoo01=oo`8001]oo`<0
000350T005@A01=D4@03001l2G`;00Il2`Ud2`]/2`aX2`]P2`]H2`M82`@/2P03001D4E@A019D4@<0
0083TC9oo`03001oo`00008000ioo`04001oogoo0003Ool00`00Oomoo`0>Ool001=oo`03001oogoo
019oo`03001oogoo01eoo`030i4005@A01=D4@03001l2G`900Ml2`Ud2`]/2`aX2`]P2`]H2`M82`D/
2P03001D4E@A015D4@03001oogoo03Aoo`80011oo`8000=oo`<0015oo`00BGoo00<005@AE1404E@A
00@007`9O0Ul2@Ml2`Ud2`]/2`aX2`]P2`]H2`M82`D/2P03001D4E@A019D4@03001oogoo02ioo`03
001oo`00008002]oo`004goo00<007ooOol03goo0P008Woo00<005@AE1404E@A00@007`9O0Ul2@Ml
2`Ud2`]/2`aX2`]P2`]H2`M82`D/2P0330D005@A019D4@03001oogoo02ioo`8002ioo`004goo00<0
07ooOol03Woo00<007ooOol08goo00<005@AE14045@A00@007`9O0Ul2@Ml2`Ud2`]/2`aX2`]P2`]H
2`M82`D/2P0330D005@A015D4@03001oogoo02]oo`04001oo`00000`Ool0019oo`03001oogoo00ao
o`8002Moo`03001D4E@A011D4@04001l2G`9O0T7O0/9M0/;K0/<J0/;H0/;F0/7B0/5;0X00``5001D
4@0AE1400`00Oomoo`0ZOol3000bOol0019oo`03001oogoo00]oo`03001oogoo02Moo`80019D4@03
001l2G`900Ml2`Ud2`]/2`aX2`]P2`]H2`M82`D/2P03001D4E@A015D4@03001oogoo02Ioo`04001o
o`00000eOol001moo`03001oogoo02Yoo`03001D4E@A011D4@03001l2G`;00Il2`Ud2`]/2`aX2`]P
2`]H2`M82`@/2P80019D4@03001oogoo029oo`04001oogooOol3000<Ool40003Ool3000QOol001eo
o`03001oogoo02eoo`03001D4E@A011D4@03001l2g`;00El2`Ud2`]/2`aX2`]P2`]H2`M82`8/2P80
01=D4@8002Aoo`04001oo`00000?Ool01`00Oomoogoo001oo`0000=oo`03001oogoo01ioo`004Woo
00<007ooOol01goo00<007ooOol0;goo00<005@AE14045@A0P001G`;2G@;2f`;36P;2f0;2eP;1dP;
00</2P00E1404U@A0P009Goo0`004Woo00<007ooOol00Woo00D007ooOomoo`00021oo`004Woo00<0
07ooOol01Woo00<007ooOol0<Goo00<005@AE1404E@A0`000W`;2G@;2f`;36P;2f0;2eP;1DP;0`00
4U@A0P008goo00@007oo000001Ioo`05001oogooOol00003Ool00`00Oomoo`0NOol0019oo`03001o
ogoo00=oo`8003Ioo`8001AD4@8000Ud2`]/2`aX2`]P2`]H2`982`<001=D4@8002Aoo`<001Uoo`04
001oogoo0003Ool00`00Oomoo`0NOol001Moo`03001oogoo03Qoo`<001=D4@<000Id2`]/2`aX2`]P
2`QH2`D001AD4@8002=oo`@001]oo`04001oogoo0003Ool00`00Oomoo`0NOol001Ioo`03001oogoo
03aoo`8001AD4@D00003M0]/2f`;00U/2`aX2`]P2`=H2`D001ID4@<002=oo`<001]oo`04001oogoo
0002Ool01@00Oomoogoo000087oo000BOol30012Ool3000FE1480004K0/<J0/6H0/8000HE143000S
Ool4000NOol20004Ool3000QOol0019oo`<004Eoo`<001]D4AH001eD4@<002Aoo`<004]oo`005Goo
00<007oo00000P00@goo1@00AU@A0`009Goo0`00CGoo000JOol00`00Ool000030012Ool5000lE145
000TOol00`00Ool00002000>Ool30002Ool3000iOol0029oo`<0049oo`H0035D4@D002Qoo`<0019o
o`04001oogoo0003Ool00`00Oomoo`0fOol002Moo`@00004Ool00000000nOol9000ME14;0002Ool0
0`00Oomoo`0TOol01000Ool000005Goo00@007ooOol000=oo`03001oogoo03Ioo`00;goo00<007oo
00000`00@Goo7@003Goo00<007ooOol08goo0`005goo00@007ooOol000=oo`03001oogoo03Ioo`00
=goo0`00RGoo0`006Woo00@007ooOol000=oo`03001oogoo03Ioo`00?7oo100000Aoo`00000007]o
o`03001oo`00008001aoo`04001oogoo0003Ool00`00Oomoo`0fOol004Aoo`03001oo`0000<005Io
o`03001oogoo01aoo`8001moo`04001oogoo0003Ool00`00Oomoo`0fOol004aoo`<0055oo`03001o
ogoo01Qoo`@0021oo`8000=oo`<003Uoo`00DGoo0`000Woo0`00Agoo00<007ooOol057oo00<007oo
Ool00P00I7oo001IOol00`00Ool000020012Ool00`00Oomoo`0DOol3001VOol005ioo`03001oogoo
00<004moo`03001oo`000080019oo`<005=oo`00IWoo0`000Woo0`00<Woo00<007ooOol03goo0`00
57oo00D007ooOomoo`00059oo`00KWoo00<007oo00000P00;Goo00<007ooOol037oo0`005goo00D0
07ooOomoo`00059oo`00Lgoo00<007ooOol00`009goo00<007ooOol02goo0P006Goo00D007ooOomo
o`00059oo`00Ngoo0`000Woo0`007Goo00<007ooOol027oo0`006goo00D007ooOomoo`00059oo`00
Pgoo00<007oo00000P0087oo10007Goo00D007ooOomoo`00059oo`00R7oo00<007ooOol00`004Woo
00H007ooOomoo`00Ool3000POol01@00Oomoogoo0000DWoo002@Ool3000=Ool01000Oomoogoo0`00
8goo0`00Dgoo002EOol4000017oo000000000goo1@004Woo0`000Woo0`00HGoo002MOol00`00Oomo
o`02000FOol01000Oomoo`000goo00<007ooOol0GWoo002hOol01000Oomoo`000goo00<007ooOol0
GWoo002^Ool70003Ool01000Oomoo`000goo00<007ooOol0GWoo002hOol01000Oomoo`000goo00<0
07ooOol0GWoo002hOol01000Oomoo`000goo00<007ooOol0GWoo002hOol01000Oomoo`000goo00<0
07ooOol0GWoo002gOol20003Ool3001QOol00:9oo`@000=oo`<001]oo`<0009oo`<0055oo`00XWoo
00L007ooOomoo`00Ool00003Ool00`00Oomoo`0JOol01000Oomoo`00Dgoo002SOol00`00Oomoo`02
Ool01@00Oomoogoo000077oo00@007ooOol005=oo`00Vgoo1`000Woo00D007ooOomoo`0000=oo`03
001oogoo01]oo`8005Aoo`00YGoo00@007ooOol000=oo`03001oogoo01]oo`8005Aoo`00YGoo00@0
07ooOol000=oo`03001oogoo01Yoo`04001oogoo001COol00:9oo`04001oogoo0002Ool01@00Oomo
ogoo000077oo00@007ooOol005=oo`00Xgoo0P0017oo0`006goo0`000Woo0`00DGoo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.1455*^-6, -0.0415572, 
  0.00377392, 0.00377392}}]
}, Open  ]],

Cell[BoxData[
    \(\(radObjDrwQD3D[g]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Self Inductance and Energy", "Section"],

Cell["\<\
This computes the internal energy of a single  coil and its \
inductance. The option \"PrcEnergy\"  in the call of the function \
\"radFldCmpPrc\" must not be  too small to avoid running out of memory during \
the computation which, depending on the operating system, may not always be \
handled gracefully. It is recommended to start the computation with a large \
value of PrcEnergy  and reduce it until either the result  of the computation \
is stable or the CPU time becomes too long. Another way consists in forcing \
the segmentation  of the coil by using \"radFldEnr[g1,g1],{kx,ky,kz}]\"  \
without calling \"radFldCmpPrc\". It allows a better follow-up of the actual \
segmentation in the coil used to compute the interaction energy but it is \
likely to become inefficient ( for CPU time) for complicated coil geometries. \
Refer to the documentation for further information on the  function \
\"radFldEnr\". \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(radFldCmpPrc[PrcEnergy -> N[10^\(-7\)]]; \n
    e1 = Abs[radFldEnr[g1, g1]/Cur^2]; \ne2 = Abs[radFldEnr[g2, g2]/Cur^2]; \n
    e = Abs[radFldEnr[g, g]/Cur^2]; \nm = Abs[radFldEnr[g1, g2]/Cur^2]; \n
    Print["\<Coil # 1 : Energy : \>", N[10^6*e1/2*Cur^2, 3], 
      "\< \[Mu]J  Self : \>", \ N[10^6*e1, 3], "\< \[Mu]H\>"]; \n
    Print["\<Coil # 2 : Energy : \>", N[10^6*e2/2*Cur^2, 3], 
      "\< \[Mu]J  Self : \>", \ N[10^6*e2, 3], "\< \[Mu]H\>"]; \n
    Print["\<Coil System : Energy : \>", N[10^6*e/2*Cur^2, 3], 
      "\< \[Mu]J  Self : \>", \ N[10^6*e, 3], "\< \[Mu]H\>"]; \n
    Print["\<Mutual Inductance : \>", \ N[10^6*m, 3], "\< \[Mu]H\>"]; \n
    \)\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Coil # 1 : Energy : \"\>", "\[InvisibleSpace]", 
        StyleBox["544.963706384597479`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", 
        "\<\" \[Mu]J  Self : \"\>", "\[InvisibleSpace]", 
        StyleBox["10.8992741276919492`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", "\<\" \[Mu]H\"\>"}],
      SequenceForm[ 
      "Coil # 1 : Energy : ", 544.96370638459746, " \[Mu]J  Self : ", 
        10.89927412769195, " \[Mu]H"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Coil # 2 : Energy : \"\>", "\[InvisibleSpace]", 
        StyleBox["1098.37628305005896`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", 
        "\<\" \[Mu]J  Self : \"\>", "\[InvisibleSpace]", 
        StyleBox["21.9675256610011748`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", "\<\" \[Mu]H\"\>"}],
      SequenceForm[ 
      "Coil # 2 : Energy : ", 1098.3762830500589, " \[Mu]J  Self : ", 
        21.967525661001176, " \[Mu]H"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Coil System : Energy : \"\>", "\[InvisibleSpace]", 
        StyleBox["2524.28449245353769`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", 
        "\<\" \[Mu]J  Self : \"\>", "\[InvisibleSpace]", 
        StyleBox["50.4856898490707539`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", "\<\" \[Mu]H\"\>"}],
      SequenceForm[ 
      "Coil System : Energy : ", 2524.2844924535375, " \[Mu]J  Self : ", 
        50.485689849070752, " \[Mu]H"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Mutual Inductance : \"\>", "\[InvisibleSpace]", 
        StyleBox["8.80891292197443398`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", "\<\" \[Mu]H\"\>"}],
      SequenceForm[ "Mutual Inductance : ", 8.808912921974434, " \[Mu]H"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coil with Iron ", "Section"],

Cell["\<\
The precision of this computation is determined by the choice of \
PrcEnergy and of the segmentation parameters nx,ny and nz. The user is \
responsible for  checking  the stability of the computed inductance as a \
function of PrcEnergy and segmentation. More complicated examples of coils \
and iron volumes can easily be done. Note that if the iron saturates, the \
real inductance depends on the current in the coils while the computed \
inductance  represents an average value.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\( (*\ Create\ the\ coil\ *) \n\nCur = 100; Nt = 25; \trmin = 10; 
    rmax = 11; \ h = 20; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \npt = {0, 0, 0}; 
    phimin = 0; phimax = 2*\[Pi]; nseg = 20; \n
    j = \(-Cur\)*\(Nt/\((rmax - rmin)\)\)/h; \n
    g1 = radObjArcCur[pt, {rmin, rmax}, {phimin, phimax}, h, nseg, j]; 
    radObjDrwAtr[g1, {1, 0, 0.5}]; \n\n (*\ Create\ the\ iron\ *) \n\n
    m = radObjRecMag[pt, {rmin*1.4, rmin*1.4, h*1.1}, {0, 0, 0}]; \n
    radObjDrwAtr[m, {0, 0.5, 0}]; \nradMatApl[m, RadMatSteel42[]]; \nnx = 3; 
    ny = 3; nz = 3; \nradObjDivMag[m, {nx, ny, nz}]; \n
    \n (*\ Solve\ for\ the\ magnetization\ in\ the\ iron\ *) \n\n
    t = radObjCnt[{g1, m}]; \ntt = RadSolve[t, 0.0001, 200]; \n
    \n (*\ Compute\ the\ Inductance\ *) \n\n
    radFldCmpPrc[PrcEnergy -> N[10^\(-7\)]]; \n
    l1 = Abs[radFldEnr[g1, t, {2, 2, 2}]/Cur^2]; \n
    Print["\<Self Indcutance : \>", \ N[10^6*l1, 3], "\< \[Mu]H\>"]; \)\)], 
  "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Self : \"\>", "\[InvisibleSpace]", 
        StyleBox["27.1991426132834446`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", "\<\" \[Mu]H\"\>"}],
      SequenceForm[ "Self : ", 27.199142613283446, " \[Mu]H"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\( (*\ display\ the\ geometry\ *) \), "\n", 
      RowBox[{
        RowBox[{"draw", "=", 
          RowBox[{
            StyleBox["radObjDrw",
              FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}]}], ";", "\n", 
        RowBox[{
          StyleBox["RadPlot3DOptions",
            FontColor->RGBColor[1, 0, 0]], "[", "]"}], ";", "\n", 
        \(Show[Graphics3D[draw]]\), ";"}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.61344 .86676 -11.9258 0 ]
[.61344 .86676 12.3242 14 ]
[.67555 .84537 -8.89224 0 ]
[.67555 .84537 9.35776 14 ]
[.74268 .82224 -4.8231 0 ]
[.74268 .82224 5.1769 14 ]
[.81545 .79717 -4.76921 0 ]
[.81545 .79717 5.23079 14 ]
[.89463 .76989 -7.53619 0 ]
[.89463 .76989 8.46381 14 ]
[.74489 .8847 -7.5361 0 ]
[.74489 .8847 8.0889 14 ]
[.41979 .05043 -11.9652 -14 ]
[.41979 .05043 12.2848 0 ]
[.53679 .08447 -9.17984 -14 ]
[.53679 .08447 9.07016 0 ]
[.64801 .11684 -5.12026 -14 ]
[.64801 .11684 4.87974 0 ]
[.75385 .14764 -5.20523 -14 ]
[.75385 .14764 4.79477 0 ]
[.85472 .177 -8.45667 -14 ]
[.85472 .177 7.54333 0 ]
[.6465 .05436 -8.0004 -14 ]
[.6465 .05436 7.6246 0 ]
[.89994 .2358 0 -5.02383 ]
[.89994 .2358 24.25 8.97617 ]
[.90699 .34812 0 -5.2106 ]
[.90699 .34812 18.25 8.7894 ]
[.91429 .46453 0 -5.40487 ]
[.91429 .46453 10 8.59513 ]
[.92185 .58528 0 -5.60709 ]
[.92185 .58528 10 8.39291 ]
[.92969 .71061 0 -5.81777 ]
[.92969 .71061 16 8.18223 ]
[.97522 .47842 0 -5.40487 ]
[.97522 .47842 14.3125 8.59513 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.59495 .86057 m
.91984 .74846 L
s
.25 Mabswid
.61324 .85426 m
.61314 .84801 L
s
gsave
.61344 .86676 -72.9258 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.67523 .83287 m
.67507 .82662 L
s
gsave
.67555 .84537 -69.8922 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.74223 .80975 m
.74201 .8035 L
s
gsave
.74268 .82224 -65.8231 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81488 .78468 m
.81459 .77844 L
s
gsave
.81545 .79717 -65.7692 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.89391 .75741 m
.89355 .75117 L
s
gsave
.89463 .76989 -68.5362 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.62526 .85011 m
.6252 .84636 L
s
.63747 .8459 m
.6374 .84215 L
s
.64987 .84162 m
.64978 .83788 L
s
.66245 .83728 m
.66236 .83353 L
s
.68821 .82839 m
.68811 .82464 L
s
.7014 .82384 m
.70129 .82009 L
s
.71479 .81922 m
.71468 .81547 L
s
.7284 .81452 m
.72828 .81077 L
s
.75629 .8049 m
.75615 .80115 L
s
.77058 .79997 m
.77043 .79622 L
s
.7851 .79496 m
.78494 .79121 L
s
.79986 .78986 m
.7997 .78612 L
s
.83015 .77941 m
.82997 .77567 L
s
.84568 .77405 m
.84549 .77031 L
s
.86148 .7686 m
.86128 .76486 L
s
.87755 .76306 m
.87734 .75931 L
s
.60139 .85835 m
.60134 .8546 L
s
.91056 .75167 m
.91033 .74792 L
s
gsave
.74489 .8847 -68.5361 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.38203 .05201 m
.8858 .1983 L
s
.25 Mabswid
.41962 .06293 m
.41954 .06918 L
s
gsave
.41979 .05043 -72.9652 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.53686 .09697 m
.5369 .10322 L
s
gsave
.53679 .08447 -70.1798 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.64831 .12933 m
.64846 .13558 L
s
gsave
.64801 .11684 -66.1203 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.75437 .16013 m
.75462 .16638 L
s
gsave
.75385 .14764 -66.2052 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.85543 .18948 m
.85578 .19572 L
s
gsave
.85472 .177 -69.4567 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.44356 .06988 m
.44352 .07363 L
s
.46724 .07676 m
.46722 .08051 L
s
.49069 .08357 m
.49068 .08732 L
s
.51389 .0903 m
.5139 .09405 L
s
.5596 .10358 m
.55964 .10733 L
s
.58211 .11011 m
.58216 .11386 L
s
.6044 .11658 m
.60446 .12033 L
s
.62646 .12299 m
.62654 .12674 L
s
.66994 .13562 m
.67004 .13936 L
s
.69135 .14183 m
.69147 .14558 L
s
.71256 .14799 m
.71269 .15174 L
s
.73357 .15409 m
.73371 .15784 L
s
.77497 .16611 m
.77513 .16986 L
s
.79537 .17204 m
.79555 .17578 L
s
.81558 .17791 m
.81577 .18165 L
s
.8356 .18372 m
.8358 .18746 L
s
.39544 .05591 m
.39537 .05966 L
s
.87507 .19518 m
.8753 .19892 L
s
gsave
.6465 .05436 -69.0004 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.8858 .1983 m
.91984 .74846 L
s
.25 Mabswid
.88791 .2324 m
.88189 .23071 L
s
gsave
.89994 .2358 -61 -9.02383 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.89488 .34502 m
.88882 .34347 L
s
gsave
.90699 .34812 -61 -9.2106 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.9021 .46176 m
.896 .46037 L
s
gsave
.91429 .46453 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.90959 .58284 m
.90346 .58162 L
s
gsave
.92185 .58528 -61 -9.60709 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.91737 .70853 m
.9112 .70748 L
s
gsave
.92969 .71061 -61 -9.81777 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.88928 .25461 m
.88567 .25361 L
s
.89066 .27697 m
.88705 .27599 L
s
.89206 .29949 m
.88843 .29853 L
s
.89346 .32217 m
.88983 .32123 L
s
.8963 .36803 m
.89266 .36712 L
s
.89773 .39121 m
.89409 .39032 L
s
.89918 .41455 m
.89553 .41368 L
s
.90063 .43807 m
.89698 .43722 L
s
.90357 .48562 m
.89991 .4848 L
s
.90506 .50965 m
.9014 .50886 L
s
.90656 .53387 m
.90289 .5331 L
s
.90807 .55826 m
.9044 .55751 L
s
.91112 .6076 m
.90744 .60689 L
s
.91267 .63255 m
.90898 .63186 L
s
.91422 .65768 m
.91053 .65702 L
s
.91579 .68301 m
.91209 .68236 L
s
.88654 .21036 m
.88294 .20932 L
s
.91896 .73424 m
.91526 .73364 L
s
gsave
.97522 .47842 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.14314 .28881 m
.1142 .8017 L
s
.1142 .8017 m
.59495 .86057 L
s
.59495 .86057 m
.58848 .39029 L
s
.58848 .39029 m
.14314 .28881 L
s
.38203 .05201 m
.8858 .1983 L
s
.8858 .1983 m
.91984 .74846 L
s
.91984 .74846 m
.37023 .66091 L
s
.37023 .66091 m
.38203 .05201 L
s
.14314 .28881 m
.1142 .8017 L
s
.1142 .8017 m
.37023 .66091 L
s
.37023 .66091 m
.38203 .05201 L
s
.38203 .05201 m
.14314 .28881 L
s
.58848 .39029 m
.8858 .1983 L
s
.8858 .1983 m
.91984 .74846 L
s
.91984 .74846 m
.59495 .86057 L
s
.59495 .86057 m
.58848 .39029 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.52578 .38044 m .4486 .80136 L .52747 .80224 L .812 0 .375 r
F
.52578 .38044 m .45178 .37904 L .4486 .80136 L F
.52363 .37193 m .45178 .37904 L .52578 .38044 L .736 0 .522 r
F
.59793 .37269 m .52578 .38044 L .52747 .80224 L .761 0 .375 r
F
[ ] 0 setdash
.73058 .22917 m .5565 .34863 L p .56384 .36373 L 0 .198 0 r
F P
0 g
s
.58971 .36477 m .56574 .37065 L .59793 .37269 L .736 0 .522 r
F
.56574 .37065 m .54659 .37534 L .57884 .37367 L F
.56574 .37065 m .57884 .37367 L .59793 .37269 L F
.5565 .34863 m .28008 .28352 L p .2927 .30754 L 0 .35 0 r
F P
0 g
s
.54659 .37534 m .52578 .38044 L .54153 .37875 L .736 0 .522 r
F
.54659 .37534 m .54153 .37875 L .59793 .37269 L F
.55667 .36855 m .5565 .34863 L p .5559 .34854 L 0 .35 0 r
F P
0 g
s
.2927 .30754 m .55608 .36841 L .5559 .34854 L 0 .35 0 r
F
.55608 .36841 m .55667 .36855 L .5559 .34854 L F
.55574 .3731 m .52363 .37193 L .52578 .38044 L .736 0 .522 r
F
.58971 .36477 m .55703 .36831 L .55574 .3731 L F
.5565 .34863 m .55667 .36855 L p .56384 .36373 L 0 .198 0 r
F P
0 g
s
.58971 .36477 m .55884 .57153 L .55703 .36831 L .761 0 .374 r
F
.55703 .36831 m .55022 .3729 L .55574 .3731 L .736 0 .522 r
F
.59793 .37269 m .52747 .80224 L .60441 .79738 L .761 0 .375 r
F
.55667 .36855 m .56044 .79478 L p .56082 .79337 L 0 .198 0 r
F P
0 g
s
.56044 .79478 m .56081 .79463 L .56082 .79337 L 0 .198 0 r
F
.5957 .7924 m .5701 .79609 L .56083 .79463 L .631 0 .549 r
F
.5701 .79609 m .54967 .79904 L .56044 .79478 L F
.5701 .79609 m .56044 .79478 L .56083 .79463 L F
.55791 .57777 m .55981 .79469 L .5252 .7969 L .761 0 .374 r
F
.55703 .36831 m .52363 .37193 L .55022 .3729 L .736 0 .522 r
F
.55791 .57777 m .5252 .7969 L .55608 .36841 L .761 0 .374 r
F
.56044 .79478 m .55667 .36855 L p .54776 .79305 L 0 .35 0 r
F P
0 g
s
.57231 .79639 m .58741 .79845 L .54426 .80118 L .631 0 .549 r
F
.54967 .79904 m .54426 .80118 L .52747 .80224 L F
.5957 .7924 m .54426 .80118 L .54967 .79904 L F
.56082 .79337 m .56081 .79463 L .56083 .79463 L 0 .198 0 r
F
.56083 .79463 m .52747 .80224 L .5252 .7969 L .631 0 .549 r
F
.54967 .79904 m .52747 .80224 L .56083 .79463 L F
.55608 .36841 m .5252 .7969 L .52363 .37193 L .761 0 .374 r
F
.45178 .37904 m .37335 .79478 L .4486 .80136 L .861 0 .374 r
F
.45178 .37904 m .38126 .36855 L .37335 .79478 L F
.52363 .37193 m .4558 .37063 L .45178 .37904 L .736 0 .522 r
F
.52363 .37193 m .45287 .79609 L .4558 .37063 L .812 0 .375 r
F
.52363 .37193 m .5252 .7969 L .45287 .79609 L F
.4558 .37063 m .38126 .36855 L .45178 .37904 L .736 0 .522 r
F
.4558 .37063 m .39126 .36095 L .38126 .36855 L F
.4558 .37063 m .38397 .79 L .39126 .36095 L .862 0 .374 r
F
.4558 .37063 m .45287 .79609 L .38397 .79 L F
.38126 .36855 m .30736 .78279 L .37335 .79478 L .915 0 .371 r
F
.38126 .36855 m .3196 .34949 L .30736 .78279 L F
.39126 .36095 m .38397 .79 L .32379 .77895 L .916 0 .371 r
F
.3196 .34949 m .25631 .76603 L .30736 .78279 L .984 0 .363 r
F
.5252 .7969 m .52747 .80224 L .4486 .80136 L .631 0 .549 r
F
.45287 .79609 m .4486 .80136 L .37335 .79478 L F
.5252 .7969 m .4486 .80136 L .45287 .79609 L F
.45287 .79609 m .37335 .79478 L .38397 .79 L F
.38397 .79 m .37335 .79478 L .30736 .78279 L F
.38397 .79 m .30736 .78279 L .32379 .77895 L F
.32379 .77895 m .30736 .78279 L .25631 .76603 L F
.26285 .77854 m .56065 .81758 L p .54776 .79305 L 0 .35 0 r
F P
0 g
s
.39126 .36095 m .3196 .34949 L .38126 .36855 L .736 0 .522 r
F
.39126 .36095 m .33505 .34339 L .3196 .34949 L F
.39126 .36095 m .32379 .77895 L .33505 .34339 L .916 0 .371 r
F
.3196 .34949 m .27218 .3229 L .25631 .76603 L .984 0 .363 r
F
.33505 .34339 m .27218 .3229 L .3196 .34949 L .736 0 .522 r
F
.33505 .34339 m .29214 .31899 L .27218 .3229 L F
.33505 .34339 m .27761 .76356 L .29214 .31899 L .986 0 .362 r
F
.33505 .34339 m .32379 .77895 L .27761 .76356 L F
.29214 .31899 m .27462 .30859 L .27218 .3229 L .736 0 .522 r
F
.28008 .28352 m .27935 .30446 L p .2927 .30754 L 0 .35 0 r
F P
0 g
s
.27935 .30446 m .28008 .28352 L p .28035 .2843 L 0 .149 0 r
F P
0 g
s
.28035 .2843 m .28559 .29902 L .27966 .30419 L 0 .149 0 r
F
.28035 .2843 m .27966 .30419 L .27935 .30446 L F
.29214 .31899 m .27966 .30419 L .27919 .3113 L .736 0 .522 r
F
.26667 .30387 m .2672 .28941 L .24418 .29051 L F
.29214 .31899 m .2726 .51859 L .28002 .30462 L 1 0 .328 r
F
.27935 .30446 m .2637 .75436 L p .26525 .73034 L 0 .35 0 r
F P
0 g
s
.27935 .30446 m .26525 .73034 L .28002 .30462 L 0 .35 0 r
F
.26525 .73034 m .2637 .75436 L .26442 .75446 L F
.32379 .77895 m .25631 .76603 L .27761 .76356 L .631 0 .549 r
F
.27218 .3229 m .22578 .74552 L .25631 .76603 L 1 0 .331 r
F
.27761 .76356 m .25631 .76603 L .24977 .76163 L .631 0 .549 r
F
.25869 .75698 m .24977 .76163 L .22578 .74552 L F
.27761 .76356 m .24977 .76163 L .25869 .75698 L F
.27935 .30446 m .27963 .3052 L .26371 .75436 L 0 .149 0 r
F
.2637 .75436 m .27935 .30446 L p .26371 .75436 L F P
0 g
s
.27761 .76356 m .25869 .75698 L .26403 .75419 L .631 0 .549 r
F
.2637 .75436 m .26285 .77854 L p .26358 .77858 L 0 .35 0 r
F P
0 g
s
.26319 .77837 m .26285 .77854 L p .26364 .76515 L 0 .149 0 r
F P
0 g
s
.2637 .75436 m .26358 .77858 L .26442 .75446 L 0 .35 0 r
F
.27963 .3052 m .26364 .76515 L .26285 .77854 L 0 .149 0 r
F
.26403 .75419 m .22578 .74552 L .25045 .74483 L .631 0 .549 r
F
.25869 .75698 m .22578 .74552 L .26403 .75419 L F
.29214 .31899 m .27761 .76356 L .26442 .75446 L 1 0 .328 r
F
.26442 .75446 m .26358 .77858 L .54776 .79305 L 0 .35 0 r
F
.26489 .74076 m .26442 .75446 L .26403 .75419 L 1 0 .328 r
F
.29214 .31899 m .26442 .75446 L .26489 .74076 L F
.29214 .31899 m .26403 .75419 L .272 .52473 L F
.2927 .30754 m .26525 .73034 L .54776 .79305 L 0 .35 0 r
F
.26525 .73034 m .26442 .75446 L .54776 .79305 L F
.42681 .69609 m .26319 .77837 L p .26403 .75419 L 0 .149 0 r
F P
0 g
s
.28002 .30462 m .26525 .73034 L .2927 .30754 L 0 .35 0 r
F
.28002 .30462 m .27925 .31618 L .27966 .30419 L 1 0 .328 r
F
.2726 .51859 m .272 .52473 L .28002 .30462 L F
.272 .52473 m .25045 .74483 L .27925 .31618 L F
.272 .52473 m .27925 .31618 L .28002 .30462 L F
.28559 .29902 m .41875 .67343 L .27963 .3052 L 0 .149 0 r
F
.41875 .67343 m .4264 .69494 L .41838 .67363 L F
.41875 .67343 m .41838 .67363 L .27963 .3052 L F
.2927 .30754 m .54776 .79305 L .55625 .38856 L 0 .35 0 r
F
.42955 .40708 m .42668 .66929 L .4279 .6692 L .748 0 .367 r
F
.55667 .36855 m .56082 .79337 L .55703 .36831 L 0 .198 0 r
F
.55884 .57153 m .56083 .79463 L .55981 .79469 L .761 0 .374 r
F
.55884 .57153 m .55981 .79469 L .55791 .57777 L F
.58971 .36477 m .56083 .79463 L .55884 .57153 L F
.55703 .36831 m .56082 .79337 L .56384 .36373 L 0 .198 0 r
F
.58971 .36477 m .5957 .7924 L .56083 .79463 L .761 0 .374 r
F
.66286 .35616 m .59793 .37269 L .60441 .79738 L .698 0 .373 r
F
.64899 .34953 m .59793 .37269 L .66286 .35616 L .736 0 .522 r
F
.64899 .34953 m .58971 .36477 L .59793 .37269 L F
.64899 .34953 m .5957 .7924 L .58971 .36477 L .697 0 .372 r
F
.66286 .35616 m .60441 .79738 L .67384 .78699 L .698 0 .373 r
F
.71519 .33172 m .66286 .35616 L .67384 .78699 L .605 0 .366 r
F
.64899 .34953 m .6591 .78282 L .5957 .7924 L .697 0 .372 r
F
.69647 .32708 m .66286 .35616 L .71519 .33172 L .736 0 .522 r
F
.69647 .32708 m .64899 .34953 L .66286 .35616 L F
.69647 .32708 m .6591 .78282 L .64899 .34953 L .602 0 .366 r
F
.71519 .33172 m .67384 .78699 L .73005 .77159 L .605 0 .366 r
F
.74963 .30087 m .71519 .33172 L .73005 .77159 L .421 0 .346 r
F
.69647 .32708 m .7101 .76866 L .6591 .78282 L .602 0 .366 r
F
.72735 .29885 m .71519 .33172 L .74963 .30087 L .736 0 .522 r
F
.72735 .29885 m .69647 .32708 L .71519 .33172 L F
.72735 .29885 m .7101 .76866 L .69647 .32708 L .413 0 .344 r
F
.74963 .30087 m .73005 .77159 L .7674 .75209 L .421 0 .346 r
F
.72735 .29885 m .74356 .75081 L .7101 .76866 L .413 0 .344 r
F
.73746 .26703 m .72735 .29885 L .74963 .30087 L .736 0 .522 r
F
.73746 .26703 m .74356 .75081 L .72735 .29885 L .1 0 .232 r
F
.73746 .26703 m .75493 .73061 L .74356 .75081 L F
.75493 .73061 m .7674 .75209 L .74356 .75081 L .631 0 .549 r
F
.56384 .36373 m .56082 .79337 L .74958 .74567 L 0 .198 0 r
F
.74958 .74567 m .42761 .69621 L p .4279 .6692 L 0 .351 0 r
F P
0 g
s
.55608 .36841 m .55625 .38856 L .55667 .36855 L 0 .35 0 r
F
.2927 .30754 m .55625 .38856 L .55608 .36841 L F
.55703 .36831 m .55791 .57777 L .55608 .36841 L .761 0 .374 r
F
.55884 .57153 m .55791 .57777 L .55703 .36831 L F
.28008 .28352 m .5565 .34863 L .73058 .22917 L p 0 .435 0 r
F P
0 g
s
.73058 .22917 m .43277 .14794 L .28008 .28352 L p 0 .435 0 r
F P
0 g
s
.43325 .17111 m .73501 .71818 L .4279 .6692 L 0 .351 0 r
F
.43349 .14929 m .447 .17479 L .43325 .17111 L F
.447 .17479 m .73501 .71818 L .43325 .17111 L F
.73094 .25124 m .75493 .73061 L .73746 .26703 L 1 0 .215 r
F
.73937 .48084 m .75493 .73061 L .73094 .25124 L F
.74938 .25576 m .73746 .26703 L .76147 .26589 L .736 0 .522 r
F
.73138 .25094 m .73058 .22917 L p .56384 .36373 L 0 .198 0 r
F P
0 g
s
.73058 .22917 m .73138 .25094 L p .73074 .25072 L 0 .351 0 r
F P
0 g
s
.43349 .14929 m .72994 .229 L .73074 .25072 L 0 .351 0 r
F
.72994 .229 m .73058 .22917 L .73074 .25072 L F
.56384 .36373 m .73911 .72413 L .73094 .25124 L 0 .198 0 r
F
.73911 .72413 m .74905 .74458 L .74817 .72055 L F
.73911 .72413 m .74817 .72055 L .73094 .25124 L F
.76147 .26589 m .74963 .30087 L .7674 .75209 L .1 0 .241 r
F
.76147 .26589 m .7674 .75209 L .78072 .72988 L F
.447 .17479 m .73074 .25077 L .74797 .72025 L 0 .351 0 r
F
.73501 .71818 m .74797 .72025 L .74885 .74429 L F
.447 .17479 m .74797 .72025 L .73501 .71818 L F
.43349 .14929 m .73138 .25094 L .447 .17479 L F
.72402 .23451 m .741 .70987 L .74797 .72025 L 1 0 .215 r
F
.73892 .47367 m .74797 .72025 L .75493 .73061 L F
.72402 .23451 m .74797 .72025 L .73892 .47367 L F
.74817 .72055 m .78072 .72988 L .75493 .73061 L .631 0 .549 r
F
.74865 .72036 m .78072 .72988 L .74817 .72055 L F
.74905 .74458 m .74958 .74567 L .74863 .72037 L 0 .198 0 r
F
.74817 .72055 m .74863 .72037 L .73094 .25124 L F
.74905 .74458 m .74863 .72037 L .74817 .72055 L F
.73074 .25077 m .73746 .26703 L .74938 .25576 L .736 0 .522 r
F
.73839 .44875 m .73138 .25094 L p .73094 .25124 L 0 .198 0 r
F P
0 g
s
.74863 .72035 m .74958 .74567 L .74865 .72036 L 0 .198 0 r
F
.73138 .25094 m .74865 .72036 L p .748 .72025 L 0 .351 0 r
F P
0 g
s
.74797 .72025 m .74865 .72036 L .74817 .72055 L .631 0 .549 r
F
.73074 .25077 m .73937 .48084 L .73094 .25124 L 1 0 .215 r
F
.73892 .47367 m .73937 .48084 L .73074 .25077 L F
.73074 .25077 m .73138 .25094 L .748 .72025 L 0 .351 0 r
F
.74797 .72025 m .748 .72025 L .74885 .74429 L F
.73074 .25077 m .748 .72025 L .74797 .72025 L F
.741 .70987 m .76622 .70695 L .76949 .71212 L .631 0 .549 r
F
.75603 .71744 m .76949 .71212 L .78072 .72988 L F
.741 .70987 m .76949 .71212 L .75603 .71744 L F
.74885 .74429 m .748 .72025 L .74958 .74567 L 0 .351 0 r
F
.74865 .72036 m .74958 .74567 L p .748 .72025 L F P
0 g
s
.75603 .71744 m .76791 .72343 L .74865 .72036 L .631 0 .549 r
F
.76791 .72343 m .78072 .72988 L .74865 .72036 L F
.741 .70987 m .75603 .71744 L .74865 .72036 L F
.741 .70987 m .74865 .72036 L .74797 .72025 L F
.72402 .23451 m .73892 .47367 L .73074 .25077 L 1 0 .215 r
F
.72402 .23451 m .73074 .25077 L .74938 .25576 L .736 0 .522 r
F
.43277 .14794 m .4335 .14814 L p .43349 .14929 L 0 .351 0 r
F P
0 g
s
.4335 .14814 m .73058 .22917 L p .43349 .14929 L 0 .351 0 r
F P
0 g
s
.43325 .17111 m .46938 .66596 L .47166 .16609 L .748 0 .367 r
F
.43213 .17126 m .43311 .18428 L .43325 .17111 L F
.43311 .18428 m .46938 .66596 L .43325 .17111 L F
.28008 .28352 m .43238 .14829 L p .43213 .1712 L 0 .149 0 r
F P
0 g
s
.42955 .40708 m .46938 .66596 L .43213 .17126 L .748 0 .367 r
F
.42668 .66929 m .42732 .66911 L .4279 .6692 L .631 0 .549 r
F
.42955 .40708 m .4279 .6692 L .43064 .41414 L .748 0 .367 r
F
.43064 .41414 m .4279 .6692 L .46938 .66596 L F
.42711 .66907 m .42732 .66911 L .42668 .66929 L .631 0 .549 r
F
.42761 .69621 m .42681 .69609 L p .42714 .66908 L 0 .351 0 r
F P
0 g
s
.43349 .14929 m .43325 .17111 L .43322 .1711 L 0 .351 0 r
F
.43277 .14794 m .43252 .17092 L p .43213 .1712 L 0 .149 0 r
F P
0 g
s
.43238 .14829 m .43277 .14794 L p .43213 .1712 L 0 .149 0 r
F P
0 g
s
.28008 .28352 m .43252 .17092 L .28559 .29902 L 0 .149 0 r
F
.39404 .17623 m .43325 .17111 L .42138 .16793 L .736 0 .522 r
F
.43277 .14794 m .43349 .14929 L .42714 .66908 L 0 .351 0 r
F
.42711 .66907 m .43277 .14794 L p .42714 .66908 L F P
0 g
s
.42138 .16793 m .47166 .16609 L .46852 .15363 L .736 0 .522 r
F
.43325 .17111 m .47166 .16609 L .42138 .16793 L F
.43322 .1711 m .4279 .6692 L .42714 .66908 L 0 .351 0 r
F
.43325 .17111 m .4279 .6692 L .43322 .1711 L F
.4279 .6692 m .42761 .69621 L .42714 .66908 L F
.43252 .17092 m .42711 .66907 L p .28559 .29902 L 0 .149 0 r
F P
0 g
s
.42711 .66907 m .42681 .69609 L p .41875 .67343 L 0 .149 0 r
F P
0 g
s
.28559 .29902 m .42711 .66907 L .41875 .67343 L 0 .149 0 r
F
.4264 .69494 m .4264 .695 L .41836 .67364 L F
.41838 .67363 m .41836 .67364 L .27963 .3052 L F
.4264 .69494 m .41836 .67364 L .41838 .67363 L F
.27963 .3052 m .41836 .67364 L .26403 .75419 L F
.39404 .17623 m .38571 .66424 L .42614 .66106 L .748 0 .367 r
F
.42631 .66367 m .38557 .67249 L .42668 .66929 L F
.39404 .17623 m .42668 .66929 L .42955 .40708 L F
.32946 .19683 m .38557 .67249 L .39404 .17623 L .663 0 .362 r
F
.32946 .19683 m .31608 .68574 L .38557 .67249 L F
.38557 .67249 m .37289 .66525 L .44536 .65954 L .631 0 .549 r
F
.43916 .66278 m .44536 .65954 L .46595 .65792 L F
.38557 .67249 m .44536 .65954 L .43916 .66278 L F
.38557 .67249 m .41506 .66715 L .42668 .66929 L F
.41506 .66715 m .43916 .66278 L .42711 .66907 L F
.41506 .66715 m .42711 .66907 L .42668 .66929 L F
.43916 .66278 m .46595 .65792 L .42732 .66911 L F
.43916 .66278 m .42732 .66911 L .42711 .66907 L F
.42681 .69609 m .42711 .66907 L p .42714 .66908 L 0 .351 0 r
F P
0 g
s
.39404 .17623 m .42955 .40708 L .43213 .17126 L .748 0 .367 r
F
.42138 .16793 m .44372 .16115 L .40115 .16252 L .736 0 .522 r
F
.44372 .16115 m .46852 .15363 L .44947 .15614 L F
.44372 .16115 m .44947 .15614 L .40115 .16252 L F
.39404 .17623 m .42138 .16793 L .38237 .16499 L F
.42138 .16793 m .40115 .16252 L .38237 .16499 L F
.73501 .71818 m .74958 .74567 L .4279 .6692 L 0 .351 0 r
F
.4279 .6692 m .46595 .65792 L .46938 .66596 L .631 0 .549 r
F
.42732 .66911 m .46595 .65792 L .4279 .6692 L F
.4264 .69494 m .42681 .69609 L .4264 .695 L 0 .149 0 r
F
.27966 .30419 m .27963 .3052 L .27935 .30446 L F
.28559 .29902 m .27963 .3052 L .27966 .30419 L F
.41836 .67364 m .42681 .69609 L .26403 .75419 L F
.26285 .77854 m .2637 .75436 L p .26371 .75436 L F P
0 g
s
.272 .52473 m .26403 .75419 L .25045 .74483 L 1 0 .328 r
F
.27462 .30859 m .26023 .30004 L .2678 .31453 L .736 0 .522 r
F
.27462 .30859 m .2678 .31453 L .27218 .3229 L F
.26023 .30004 m .25047 .29779 L .27218 .3229 L F
.27218 .3229 m .24418 .29051 L .22578 .74552 L 1 0 .331 r
F
.27966 .30419 m .25045 .74483 L .2672 .28941 L 1 0 .328 r
F
.27925 .31618 m .25045 .74483 L .27966 .30419 L F
.26023 .30004 m .24418 .29051 L .25047 .29779 L .736 0 .522 r
F
.5957 .7924 m .60441 .79738 L .58741 .79845 L .631 0 .549 r
F
.5957 .7924 m .58741 .79845 L .57231 .79639 L F
.56081 .79463 m .56065 .81758 L .56083 .79463 L 0 .198 0 r
F
.56065 .81758 m .56103 .81744 L p .56083 .79463 L F P
0 g
s
.56065 .81758 m .56044 .79478 L p .54776 .79305 L 0 .35 0 r
F P
0 g
s
.56044 .79478 m .56065 .81758 L p .56081 .79463 L 0 .198 0 r
F P
0 g
s
.6591 .78282 m .60441 .79738 L .5957 .7924 L .631 0 .549 r
F
.6591 .78282 m .67384 .78699 L .60441 .79738 L F
.56103 .81744 m .74958 .74567 L p .56082 .79337 L 0 .198 0 r
F P
0 g
s
0 0 0 r
.63568 .20329 m
.63568 .20329 L
s
.63568 .20329 m
.63568 .20329 L
s
.32718 .2417 m
.32718 .2417 L
s
.32718 .2417 m
.32718 .2417 L
s
.53651 .17624 m
.53651 .17624 L
s
.53651 .17624 m
.53651 .17624 L
s
0 g
.25047 .29779 m
.26617 .31595 L
s
.26617 .31595 m
.26623 .31601 L
s
.37335 .79478 m
.41345 .79828 L
s
.55981 .79469 m
.56083 .79463 L
s
.73746 .26703 m .74963 .30087 L .76147 .26589 L .736 0 .522 r
F
0 g
.74963 .30087 m
.75045 .29844 L
s
.73909 .3103 m
.74963 .30087 L
s
.74958 .74567 m .56065 .81758 L .26285 .77854 L p 0 .458 0 r
F P
0 g
s
.33869 .78848 m
.37335 .79478 L
s
0 0 0 r
.36642 .79212 m
.36642 .79212 L
s
.36642 .79212 m
.36642 .79212 L
s
.61887 .79542 m
.61887 .79542 L
s
.61887 .79542 m
.61887 .79542 L
s
.46559 .80512 m
.46559 .80512 L
s
.46559 .80512 m
.46559 .80512 L
s
.24418 .29051 m .22063 .72286 L .22578 .74552 L .97 0 .15 r
F
.24418 .29051 m .23997 .25486 L .22063 .72286 L F
.2672 .28941 m .23997 .25486 L .24418 .29051 L .736 0 .522 r
F
0 g
.24418 .29051 m
.25047 .29779 L
s
.2672 .28941 m .26406 .25704 L .23997 .25486 L .736 0 .522 r
F
.2672 .28941 m .24655 .72424 L .26406 .25704 L .95 0 .137 r
F
.2672 .28941 m .25045 .74483 L .24655 .72424 L F
0 g
.2672 .28941 m
.27966 .30419 L
s
.7101 .76866 m .67384 .78699 L .6591 .78282 L .631 0 .549 r
F
0 g
.6473 .7846 m
.6591 .78282 L
s
.7101 .76866 m .73005 .77159 L .67384 .78699 L .631 0 .549 r
F
0 g
.61977 .79508 m
.67384 .78699 L
s
.25631 .76603 m
.26321 .76829 L
s
0 0 0 r
.46559 .80512 m
.46559 .80512 L
s
.32718 .2417 m
.32718 .2417 L
s
.72402 .23451 m .76147 .26589 L .74739 .22994 L .736 0 .522 r
F
.74739 .22994 m .76147 .26589 L .78072 .72988 L 1 0 .205 r
F
0 g
.75056 .23803 m
.76147 .26589 L
s
.75045 .29844 m
.75171 .29472 L
s
.73144 .25245 m
.73746 .26703 L
s
.74356 .75081 m .73005 .77159 L .7101 .76866 L .631 0 .549 r
F
0 g
.6591 .78282 m
.7101 .76866 L
s
.74356 .75081 m .7674 .75209 L .73005 .77159 L .631 0 .549 r
F
0 g
.67384 .78699 m
.73005 .77159 L
s
.26406 .25704 m .26848 .70378 L .28492 .22498 L .133 0 .275 r
F
0 0 0 r
.2776 .43805 m
.32383 .4026 L
s
.26406 .25704 m .24655 .72424 L .26848 .70378 L .133 0 .275 r
F
.26406 .25704 m .26229 .21936 L .23997 .25486 L .736 0 .522 r
F
.26406 .25704 m .28492 .22498 L .26229 .21936 L F
.23997 .25486 m .24402 .70018 L .22063 .72286 L .112 0 .269 r
F
.23997 .25486 m .26229 .21936 L .24402 .70018 L F
0 0 0 r
.61887 .79542 m
.61887 .79542 L
s
.36642 .79212 m
.36642 .79212 L
s
.68649 .20478 m .741 .70987 L .72402 .23451 L 1 0 .334 r
F
.68649 .20478 m .72402 .23451 L .74739 .22994 L .736 0 .522 r
F
0 g
.72402 .23451 m
.73074 .25077 L
s
.74739 .22994 m .78072 .72988 L .76622 .70695 L 1 0 .205 r
F
.68649 .20478 m .74739 .22994 L .70648 .19689 L .736 0 .522 r
F
.70648 .19689 m .74739 .22994 L .76622 .70695 L 1 0 .332 r
F
0 g
.74739 .22994 m
.75056 .23803 L
s
0 0 0 r
.63568 .20329 m
.63568 .20329 L
s
.28492 .22498 m .31608 .68574 L .32946 .19683 L .514 0 .345 r
F
.28492 .22498 m .26848 .70378 L .31608 .68574 L F
.28492 .22498 m .31104 .18803 L .26229 .21936 L .736 0 .522 r
F
.28492 .22498 m .32946 .19683 L .31104 .18803 L F
0 g
.26406 .25704 m
.28492 .22498 L
s
.75493 .73061 m .78072 .72988 L .7674 .75209 L .631 0 .549 r
F
0 g
.7674 .75209 m
.78072 .72988 L
s
.73005 .77159 m
.7674 .75209 L
s
.26285 .77854 m .42681 .69609 L .74958 .74567 L p 0 .458 0 r
F P
0 g
s
0 0 0 r
.36757 .72588 m
.36757 .72588 L
s
.36757 .72588 m
.36808 .69988 L
s
.3131 .75327 m
.31495 .68617 L
s
.64713 .72993 m
.64713 .72993 L
s
.36642 .79212 m
.53967 .71342 L
s
.53967 .71342 m
.53967 .71342 L
s
0 g
.7101 .76866 m
.74356 .75081 L
s
0 0 0 r
.3131 .75327 m
.61887 .79542 L
s
.3131 .75327 m
.3131 .75327 L
s
.3131 .75327 m
.3131 .75327 L
s
.46559 .80512 m
.64713 .72993 L
s
.64713 .72993 m
.64713 .72993 L
s
.68167 .77152 m
.68167 .77152 L
s
.68167 .77152 m
.68167 .77152 L
s
0 g
.74356 .75081 m
.7456 .74719 L
s
.74939 .74045 m
.75493 .73061 L
s
.26229 .21936 m .2961 .68009 L .24402 .70018 L .508 0 .344 r
F
.26229 .21936 m .31104 .18803 L .2961 .68009 L F
0 g
.23997 .25486 m
.26229 .21936 L
s
.25045 .74483 m .22578 .74552 L .22063 .72286 L .631 0 .549 r
F
0 g
.22578 .74552 m
.25631 .76603 L
s
.25045 .74483 m .22063 .72286 L .24655 .72424 L .631 0 .549 r
F
0 g
.25045 .74483 m
.26403 .75419 L
s
0 0 0 r
.36757 .72588 m
.36757 .72588 L
s
.36757 .72588 m
.68167 .77152 L
s
.68167 .77152 m
.68167 .77152 L
s
.68649 .20478 m .70101 .69084 L .741 .70987 L 1 0 .334 r
F
.62743 .18152 m .70101 .69084 L .68649 .20478 L .944 0 .359 r
F
.62743 .18152 m .68649 .20478 L .70648 .19689 L .736 0 .522 r
F
0 g
.68649 .20478 m
.70955 .22304 L
s
0 0 0 r
.53967 .71342 m
.53967 .71342 L
s
.53651 .17624 m
.53651 .17624 L
s
.70648 .19689 m .76622 .70695 L .72268 .68578 L 1 0 .332 r
F
.62743 .18152 m .70648 .19689 L .64138 .17092 L .736 0 .522 r
F
.64138 .17092 m .70648 .19689 L .72268 .68578 L .946 0 .358 r
F
0 g
.70648 .19689 m
.74739 .22994 L
s
.32946 .19683 m .38237 .16499 L .31104 .18803 L .736 0 .522 r
F
.32946 .19683 m .39404 .17623 L .38237 .16499 L F
0 g
.3104 .20888 m
.32946 .19683 L
s
.31104 .18803 m .37289 .66525 L .2961 .68009 L .661 0 .361 r
F
0 0 0 r
.36808 .69988 m
.36855 .67574 L
s
.31104 .18803 m .38237 .16499 L .37289 .66525 L .661 0 .361 r
F
0 g
.26229 .21936 m
.31104 .18803 L
s
.38209 .18004 m
.39404 .17623 L
s
.74869 .72132 m
.75493 .73061 L
s
.62743 .18152 m .63756 .6759 L .70101 .69084 L .944 0 .359 r
F
.62743 .18152 m .65273 .66907 L .64138 .17092 L .466 0 .345 r
F
0 0 0 r
.58898 .35765 m
.63124 .36759 L
s
0 g
.64175 .18716 m
.64409 .18808 L
s
.62743 .18152 m .63756 .6759 L .65273 .66907 L .466 0 .345 r
F
.55286 .16795 m .63756 .6759 L .62743 .18152 L .874 0 .366 r
F
.55286 .16795 m .62743 .18152 L .64138 .17092 L .736 0 .522 r
F
.62743 .18152 m .65273 .66907 L .63756 .6759 L .466 0 .345 r
F
.62743 .18152 m .64138 .17092 L .65273 .66907 L F
0 g
.39404 .17623 m
.43213 .17126 L
s
.24655 .72424 m .24402 .70018 L .26848 .70378 L .631 0 .549 r
F
.24655 .72424 m .22063 .72286 L .24402 .70018 L F
0 g
.24655 .72424 m
.25045 .74483 L
s
.22063 .72286 m
.22578 .74552 L
s
.55286 .16795 m .64138 .17092 L .55872 .15571 L .736 0 .522 r
F
.55872 .15571 m .64138 .17092 L .65273 .66907 L .875 0 .365 r
F
.64138 .17092 m .72268 .68578 L .65273 .66907 L .946 0 .358 r
F
0 g
.64138 .17092 m
.70648 .19689 L
s
0 0 0 r
.646 .67789 m
.64713 .72993 L
s
.55286 .16795 m .55711 .66716 L .63756 .6759 L .874 0 .366 r
F
.47166 .16609 m .55711 .66716 L .55286 .16795 L .813 0 .368 r
F
.47166 .16609 m .55286 .16795 L .55872 .15571 L .736 0 .522 r
F
0 g
.55286 .16795 m
.56124 .16948 L
s
.47166 .16609 m .46938 .66596 L .55711 .66716 L .813 0 .368 r
F
0 0 0 r
.53939 .66692 m
.53967 .71342 L
s
.47166 .16609 m .55872 .15571 L .46852 .15363 L .736 0 .522 r
F
0 g
.43325 .17111 m
.47166 .16609 L
s
.47166 .16609 m
.55286 .16795 L
s
.38237 .16499 m .46595 .65792 L .37289 .66525 L .748 0 .366 r
F
.38237 .16499 m .46852 .15363 L .46595 .65792 L F
0 g
.31104 .18803 m
.38237 .16499 L
s
.38237 .16499 m
.40115 .16252 L
s
.55872 .15571 m .65273 .66907 L .5635 .65927 L .875 0 .365 r
F
.46852 .15363 m .55872 .15571 L .5635 .65927 L .813 0 .367 r
F
0 g
.55872 .15571 m
.64138 .17092 L
s
.46852 .15363 m .5635 .65927 L .46595 .65792 L .813 0 .367 r
F
0 g
.40115 .16252 m
.46852 .15363 L
s
.46852 .15363 m
.55872 .15571 L
s
.70101 .69084 m .76622 .70695 L .741 .70987 L .631 0 .549 r
F
0 g
.741 .70987 m
.74797 .72025 L
s
.70101 .69084 m .72268 .68578 L .76622 .70695 L .631 0 .549 r
F
0 g
.76622 .70695 m
.78072 .72988 L
s
.26848 .70378 m .2961 .68009 L .31608 .68574 L .631 0 .549 r
F
.26848 .70378 m .24402 .70018 L .2961 .68009 L F
0 g
.24655 .72424 m
.26848 .70378 L
s
.22063 .72286 m
.24402 .70018 L
s
.63756 .6759 m .72268 .68578 L .70101 .69084 L .631 0 .549 r
F
0 g
.70101 .69084 m
.741 .70987 L
s
.63756 .6759 m .65273 .66907 L .72268 .68578 L .631 0 .549 r
F
0 g
.72268 .68578 m
.76622 .70695 L
s
.31608 .68574 m .37289 .66525 L .38557 .67249 L .631 0 .549 r
F
.31608 .68574 m .2961 .68009 L .37289 .66525 L F
0 g
.26848 .70378 m
.31608 .68574 L
s
.31608 .68574 m
.38557 .67249 L
s
.24402 .70018 m
.2961 .68009 L
s
.2961 .68009 m
.37289 .66525 L
s
.55711 .66716 m .65273 .66907 L .63756 .6759 L .631 0 .549 r
F
0 g
.63756 .6759 m
.70101 .69084 L
s
.63738 .66738 m
.63741 .66876 L
s
.38557 .67249 m
.42668 .66929 L
s
.55711 .66716 m .5635 .65927 L .65273 .66907 L .631 0 .549 r
F
0 g
.65273 .66907 m
.72268 .68578 L
s
.64138 .17092 m
.65273 .66907 L
s
.63756 .6759 m
.65273 .66907 L
s
.46938 .66596 m .5635 .65927 L .55711 .66716 L .631 0 .549 r
F
0 g
.55711 .66716 m
.63756 .6759 L
s
.46938 .66596 m .46595 .65792 L .5635 .65927 L .631 0 .549 r
F
0 g
.4279 .6692 m
.46938 .66596 L
s
.5635 .65927 m
.65273 .66907 L
s
.46938 .66596 m
.55711 .66716 L
s
.37289 .66525 m
.46595 .65792 L
s
.46595 .65792 m
.5635 .65927 L
s
[ .01 .01 ] 0 setdash
.38203 .05201 m
.8858 .1983 L
s
.8858 .1983 m
.91984 .74846 L
s
.91984 .74846 m
.37023 .66091 L
s
.37023 .66091 m
.38203 .05201 L
s
.14314 .28881 m
.1142 .8017 L
s
.1142 .8017 m
.37023 .66091 L
s
.37023 .66091 m
.38203 .05201 L
s
.38203 .05201 m
.14314 .28881 L
s
.003 w
[ ] 0 setdash
.8858 .1983 m
.91984 .74846 L
s
.25 Mabswid
.88791 .2324 m
.88189 .23071 L
s
gsave
.89994 .2358 -61 -9.02383 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.89488 .34502 m
.88882 .34347 L
s
gsave
.90699 .34812 -61 -9.2106 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.9021 .46176 m
.896 .46037 L
s
gsave
.91429 .46453 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.90959 .58284 m
.90346 .58162 L
s
gsave
.92185 .58528 -61 -9.60709 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.91737 .70853 m
.9112 .70748 L
s
gsave
.92969 .71061 -61 -9.81777 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.88928 .25461 m
.88567 .25361 L
s
.89066 .27697 m
.88705 .27599 L
s
.89206 .29949 m
.88843 .29853 L
s
.89346 .32217 m
.88983 .32123 L
s
.8963 .36803 m
.89266 .36712 L
s
.89773 .39121 m
.89409 .39032 L
s
.89918 .41455 m
.89553 .41368 L
s
.90063 .43807 m
.89698 .43722 L
s
.90357 .48562 m
.89991 .4848 L
s
.90506 .50965 m
.9014 .50886 L
s
.90656 .53387 m
.90289 .5331 L
s
.90807 .55826 m
.9044 .55751 L
s
.91112 .6076 m
.90744 .60689 L
s
.91267 .63255 m
.90898 .63186 L
s
.91422 .65768 m
.91053 .65702 L
s
.91579 .68301 m
.91209 .68236 L
s
.88654 .21036 m
.88294 .20932 L
s
.91896 .73424 m
.91526 .73364 L
s
gsave
.97522 .47842 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{289.562, 289.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Y0001JA000`40O003h00OogooJWoo003oOomZ
Ool00?moofYoo`00ogooJWoo003oOomZOol00?moofYoo`00ogooJWoo003oOomZOol00?moofYoo`00
ogooJWoo002COol30005Ool3003;Ool009Aoo`03001oogoo00=oo`05001oogooOol0003:Ool009Ao
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo03aoo`<008Qoo`00R7oo200017oo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol0?Goo00<007ooOol0Qgoo002DOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`0mOol00`00Oomoo`27Ool009Aoo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo03eoo`03001oogoo08Moo`00U7oo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol0?Goo00<007ooOol0Qgoo002DOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0l
Ool00`00Ool00028Ool009=oo`8000Eoo`05001oogooOol0000oOol00`00Ool00028Ool009Aoo`03
001oogoo00Aoo`<003moo`05001oogooOol00027Ool00=aoo`03001oogoo00=oo`03001oogoo08Ao
o`00fgoo0`000goo0`00QGoo0026Ool3000eOol5002VOol008Eoo`80009oo`<003Moo`03001oogoo
0:=oo`00Q7oo00<007oo000017oo1@00=7oo00<007ooOol0XWoo0023Ool01000Oomoo`0017oo00<0
07ooOol00Woo0`008Goo200027oo00<007ooOol0XWoo0026Ool00`00Oomoo`0:Ool3000^Ool00`00
Oomoo`2ROol0085oo`03001oogoo00moo`03001oogoo00@002Uoo`03001oogoo0:=oo`00P7oo00<0
07ooOol047oo00<007ooOol017oo0`008Woo1000YWoo001oOol00`00Oomoo`04Ool00`00Oomoo`0C
Ool5000NOol00`00Oomoo`2WOol007ioo`03001oogoo00Eoo`03001oogoo01=oo`03001oogoo009o
o`<001aoo`03001oogoo0:Ioo`00QWoo00<007ooOol06goo0`006Goo1@00Y7oo001lOol00`00Oomo
o`07Ool00`00Oomoo`0KOol00`00Oomoo`04002nOol007]oo`03001oogoo00Qoo`03001oogoo029o
o`<00;]oo`00NWoo00<007ooOol0;goo00<007oo00000`00<7oo0`00Q7oo001iOol00`00Oomoo`0`
Ool00`00Oomoo`02Ool4000/Ool01@00Oomoogoo0000Pgoo0026Ool00`00Oomoo`0[Ool4000XOol0
0`00Oomoo`03Ool00`00Oomoo`20Ool007Moo`03001oogoo00aoo`03001oogoo02]oo`04001oogoo
Ool4000TOol00`00Oomoo`03Ool00`00Oomoo`20Ool007Ioo`03001oogoo00eoo`03001oogoo03=o
o`<0025oo`03001oogoo00=oo`03001oogoo081oo`00MGoo00<007ooOol03Woo00<007ooOol0<goo
00<007ooOol010007Goo00<007ooOol00goo00<007ooOol0P7oo001dOol00`00Oomoo`0?Ool00`00
Oomoo`0cOol00`00Oomoo`04Ool3000JOol00`00Oomoo`03Ool00`00Oomoo`20Ool00<Aoo`03001o
o`00008001Moo`03001oogoo00=oo`03001oogoo081oo`00LWoo00<007ooOol0Cgoo00<007ooOol0
0Woo100057oo00D007ooOomoo`0008=oo`00LGoo00<007ooOol04Goo00<007ooOol0A7oo10004Woo
0`00Q7oo001`Ool00`00Oomoo`0BOol00`00Oomoo`14Ool01000Oomoogoo1000UGoo001_Ool00`00
Oomoo`0COol00`00Oomoo`1;Ool4000^Ool5001OOol008Eoo`03001oogoo04aoo`03001oogoo00<0
031oo`03001oogoo05aoo`00KGoo00<007ooOol05Goo00<007ooOol0DWoo1000;Goo00<007ooOol0
Fgoo001/Ool00`00Oomoo`1]Ool00`00Ool00002000ZOol00`00Oomoo`1KOol006]oo`03001oogoo
06ioo`03001oogoo009oo`@002Ioo`03001oogoo05]oo`00JWoo00<007ooOol067oo00<007ooOol0
G7oo10008Woo00<007ooOol0G7oo0025Ool00`00Oomoo`1LOol00`00Oomoo`04000KOol4001OOol0
06Qoo`03001oogoo01Yoo`03001oogoo05aoo`03001oogoo00Aoo`@001Moo`03001oogoo061oo`00
Igoo00<007ooOol06goo00<007ooOol0Hgoo00<007ooOol010005Goo00<007ooOol0Ggoo001VOol0
0`00Oomoo`0LOol00`00Oomoo`1ZOol4000AOol5001MOol006Eoo`03001oogoo08]oo`03001oo`00
00<002eoo`<000Eoo`<003Qoo`00Ugoo1000GWoo0`00:goo00<007ooOol00goo00D007ooOomoo`00
03Moo`00Hgoo00<007ooOol07goo00<007ooOol03Woo00<0002000000P5P0`00G7oo00<007oo0000
0`009goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0=7oo001ROol00`00Oomoo`0POol0
0`00Oomoo`0=Ool010000800P0001@5P5`00AGoo00<007ooOol00Woo100097oo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol0=7oo001QOol00`00Oomoo`0QOol00`00Oomoo`0<Ool010000800
P020200015`;4FP;4`00>Woo1@0087oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0=7oo
001POol00`00Oomoo`0ROol00`00Oomoo`09Ool8000;G0/PJ0/4K0/6000dOol01000Oomoogoo1000
7Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0=7oo0025Ool00`00Oomoo`02Ool7000C
G0/PJ0/:K0/6000eOol4000JOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0dOol005io
o`03001oogoo02=oo`H001YL2b1X2a1/2`D0031oo`04001oogooOol4000FOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`0dOol005eoo`03001oogoo025oo`<0009D2aiL2b1X2aE/2`H002Yo
o`03001oogoo00Aoo`@0019oo`8000Eoo`05001oogooOol0000gOol005aoo`03001oogoo01moo`<0
00AD2`03001L2e`;01aL2b1X2`03K0/006`;01Q/2`@002eoo`04001oogooOol4000?Ool00`00Oomo
o`04Ool3000hOol005]oo`03001oogoo01eoo`<000MD2`03001L2e`;01aL2b1X2ae/2`03001h2`00
0080035oo`@004ioo`00N7oo0`002U@;00<005`;G0/075`;86P;7F`;00<007P;N0/00WP;0P00;goo
00@007ooOomoo`<004]oo`00FGoo00<007ooOol06Goo0`003E@;00<005`;G0/075`;86P;7F`;00<0
07P;N0/017P;0`00<goo1000Agoo001HOol00`00Oomoo`0GOol3000@E0/00`00G0]L2`0LG0/PJ0/M
K0/00`00N0]h2`07N0/3000`Ool00`00Oomoo`040014Ool005Moo`03001oogoo01Eoo`<001AD2aiL
2b1X2ae/2`03001h2gP;00Yh2`8003Aoo`D0041oo`00EWoo00<007ooOol04goo0`005e@;7U`;86P;
7F`;0P003GP;0`00<goo00<007oo00000`00?Goo001[Ool00`00@0]D2`0GE0/00`00G0]L2`0LG0/P
J0/MK0/00`00N0]h2`0?N0/2000fOol4000jOol005=oo`8001Aoo`8000902aQD2`03001L2e`;01aL
2b1X2ae/2`03001h2gP;015h2`<003Aoo`03001oogoo00@003Ioo`00DWoo00<007ooOol04goo00<0
040;@0/00T0;65@;00<005`;G0/075`;86P;7F`;00<007P;N0/057P;0P00<goo00<007ooOol00Woo
1@00<Woo001AOol00`00Oomoo`0BOol20005@0/HE0/00`00G0]L2`0LG0/PJ0/MK0/00`00N0]h2`0D
N0/2O0X00`00Oomoo`0fOol00`00Oomoo`02000aOol006Aoo`8000M02aQD2`03001L2e`;01aL2b1X
2ae/2`03001h2gP;01Ah2`=l2P03001oogoo03Moo`<0035oo`00Hgoo00<0040;@0/01d0;6E@;7U`;
86P;7F`;00<007P;N0/057P;17`:00<007ooOol0=Goo00@007ooOol0035oo`00CWoo0P004Goo0P00
2T0;6E@;7U`;86P;7F`;00<007P;N0/057P;1G`:00<007ooOol0<goo00D007ooOomoo`00035oo`00
CGoo00<007ooOol047oo00<0040;@0/02T0;65@;00<005`;G0/075`;86P;7F`;00<007P;N0/057P;
1W`:00<007ooOol0;Woo0P001Goo0P00<Goo001<Ool00`00Oomoo`0?Ool2000=@0/HE0/00`00G0]L
2`0LG0/PJ0/MK0/00`00N0]h2`0DN0/7O0X2000]Ool00`00Oomoo`06Ool00`00Oomoo`0_Ool005eo
o`0300102d0;00e02aQD2`03001L2e`;01aL2b1X2ae/2`03001h2gP;01Ah2`Ul2P03001oogoo02Uo
o`03001oogoo00Moo`03001oogoo02moo`00G7oo00<0040;@0/03T0;65@;00<005`;G0/075`;86P;
7F`;00<007P;N0/057P;2W`:00<007ooOol0<Woo00<007ooOol0;goo0019Ool2000AOol00`00@0]0
2`0>@0/HE0/00`00G0]L2`0LG0/PJ0/MK0/00`00N0]h2`0DN0/;O0X00`00Oomoo`0SOol2000<Ool0
0`00Oomoo`0_Ool004Qoo`03001oogoo011oo`0300102d0;00m02aUD2aiL2b1X2ae/2`03001h2gP;
01Ah2`03O0X007`:00Ul2P03001oogoo025oo`03001oogoo00eoo`03001oogoo02ioo`00Agoo00<0
07ooOol047oo00<000`8@0/0440;6E@;7U`;86P;7F`;00<007P;N0/057P;3G`:00<007ooOol07goo
00<007ooOol03Woo00<007ooOol0;Woo001JOol00`0030Q02`0@@0/HE0/00`00G0]L2`0LG0/PJ0/M
K0/00`00N0]h2`0DN0/>O0X00`00Oomoo`0]Ool3000`Ool005Uoo`03000<20`801502aQD2`03001L
2e`;01aL2b1X2ae/2`03001h2gP;01Ah2`il2P03001oogoo01Yoo`8001=oo`03001oogoo02ioo`00
A7oo0P004goo00<000`830P04D0;65@;00<005`;G0/075`;86P;7V`;00<007P;N0/04gP;3W`:00=l
1P00Ool06Goo00<007ooOol04goo00<007ooOol047oo0`001Goo0`004goo0013Ool00`00Oomoo`0B
Ool0100030P<20`84D0;65@;00<005`;G0/075`;86P;7V`;00<007P;N0/057P;3G`:00=l1Woo0000
67oo00<007ooOol057oo00<007ooOol04Goo00<007ooOol00goo00D007ooOomoo`00019oo`00@Woo
00<007ooOol04Woo00<000`830P00P`8440;6E@;00<005`;G0/075`;86P;7V`;00<007P;N0/057P;
3G`:00=l1Woo0000;goo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
3goo001GOol00`0030P<200230P@@0/JE0/NG0/PJ0/NK0/00`00N0]h2`0DN0/=O0X2O0H00`00Oomo
o`0BOol2000IOol00`00Oomoo`05Ool80004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`0?Ool005Ioo`03000<20`800<<21102aYD2aiL2b1X2ai/2`03001h2gP;01Ah2`el2P9l1P03Ool0
07oo015oo`03001oogoo01Uoo`03001oogoo015oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo00moo`00?goo0P005Goo00<000`830P00``8440;6E@;00<005`;G0/075`;86P;7V`;00<007P;
N0/057P;3G`:0g`600<007ooOol03goo00<007ooOol06Woo00<007ooOol04Goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol03goo000nOol00`00Oomoo`0DOol00`0030P<200430P@@0/IE0/0
0`00G0]L2`0LG0/PJ0/NK0/00`00N0]h2`0DN0/=O0X3O0H00`00Oomoo`0[Ool2000COol00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool003eoo`03001oogoo01Aoo`03000<20`800D<2110
2aUD2`03001L2e`;01aL2b1X2ai/2`03001h2gP;01Ah2`el2P=l1P03Ool007oo00]oo`8001moo`03
001oogoo015oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00moo`00E7oo1``84D0;65@;
00<005`;G0/07E`;86P;7V`;00<007P;N0/057P;3G`:17`600<007ooOol02Goo00<007ooOol07goo
00<007ooOol047oo0P001Goo00D007ooOomoo`00019oo`00E7oo1``84D0;65@;00<005`;G0/07E`;
86P;7V`;00<007P;N0/057P;3G`:17`600<007ooOol027oo00<007ooOol087oo00<007ooOol04Goo
00<007ooOol017oo0`004goo000jOol2000HOol730PA@0/IE0/OG0/PJ0/NK0/00`00N0]h2`0DN0/=
O0X4O0H00goo001oo`0[Ool00`00Oomoo`0^Ool003Uoo`03001oogoo01Qoo`L<21502aUD2amL2b1X
2ai/2`03001h2gP;01Ah2`il2PAl1P03001oogoo00=oo`8002Eoo`8002moo`00>7oo00<007ooOol0
6Goo1``84D0;6E@;7e`;86P;7V`;00<007P;N0/057P;3W`:17`61Goo00<007ooOol09Woo00<007oo
Ool0;Goo001DOol730PA@0/HE0/00`00G0]L2`0MG0/PJ0/NK0/00`00N0]h2`0DN0/>O0X4O0H^Ool0
0`00Oomoo`0]Ool005Aoo`L<21502aQD2`03001L2e`;01eL2b1X2ai/2`03001h2gP;01Ah2`il2PAl
1P03Ool0000002Yoo`8002moo`00=Goo0P007Goo1``84D0;65@;00<005`;G0/07E`;86P;7V`;00<0
07P;N0/057P;3W`:17`600<007ooOol0:goo00<007ooOol0;Goo000dOol00`00Oomoo`0MOol730PA
@0/HE0/00`00G0]L2`0MG0/PJ0/NK0/00`00N0]h2`0DN0/>O0X4O0H^Ool00`00Oomoo`0]Ool003=o
o`03001oogoo01ioo`L<21502aUD2amL2b5X2ae/2`03001h2gP;01Ah2`il2PAl1Rioo`03001oogoo
02eoo`00E7oo1``84D0;6E@;7e`;8FP;7F`;00<007P;N0/057P;3W`:17`6;Woo00<007ooOol0;Goo
000bOol00`00Ool00002000MOol730PA@0/IE0/OG0/QJ0/MK0/00`00N0]h2`0DN0/>O0X4O0H^Ool0
0`00Oomoo`0]Ool0039oo`03001oogoo009oo`8001]oo`L<21502aQD2`03001L2e`;01eL2b5X2ae/
2`03001h2gP;01Ah2`il2PAl1Rioo`03001oogoo02eoo`00<Woo00<007ooOol01Woo0`005Goo20`8
4D0;65@;00<005`;G0/07E`;8FP;7F`;00<007P;N0/057P;3W`:00Al1P00O0Il1Rioo`03001oogoo
02eoo`00<Woo00<007ooOol02Goo00@007ooOomoo`<000ioo`P<21502aQD2`03001L2e`;01eL2b5X
2ae/2`03001h2gP;01Ah2`il2PAl1Reoo`8002moo`00AGoo00<007ooOol02goo20`84D0;65@;00<0
05`;G0/07E`;8FP;7F`;00<007P;N0/057P;3W`:17`6;Woo00<007ooOol0;Goo0019Ool30007Ool8
30PA@0/IE0/OG0/QJ0/MK0/00`00N0]h2`0DN0/>O0X5O0H]Ool00`00Oomoo`0]Ool004aoo`03001o
ogoo00Aoo`P<21502aUD2amL2b5X2ae/2`03001h2gP;01Ah2`il2PEl1Reoo`03001oogoo02eoo`00
<Goo00<007ooOol077oo0`0020`84D0;6E@;7e`;8FP;7F`;00<007P;N0/057P;3W`:1G`6;Goo00<0
07ooOol0;Goo000aOol00`00Oomoo`0OOol830PA@0/HE0/00`00G0]L2`0MG0/QJ0/MK0/00`00N0]h
2`0DN0/>O0X5O0H]Ool00`00Oomoo`0]Ool0035oo`03001oogoo01moo`P<21502aQD2`03001L2e`;
01eL2b5X2ae/2`03001h2gP;01Ah2`il2PEl1Rioo`03001oogoo02aoo`00<Goo00<007ooOol07goo
20`84D0;65@;00<005`;G0/07E`;8FP;7F`;00<007P;N0/057P;3W`:1G`6;Woo00<007ooOol0;7oo
001COol830PA@0/HE0/00`00G0]L2`0MG0/QJ0/MK0/00`00N0]h2`0EN0/=O0X5O0H]Ool2000^Ool0
05=oo`P<21502aUD2amL2b5X2ae/2`03001h2gP;01Eh2`el2PEl1Rioo`03001oogoo02aoo`00Dgoo
1``84T0;6E@;7e`;8FP;7F`;00<007P;N0/05GP;3G`:1G`6;Woo00<007ooOol0;7oo000aOol00`00
Oomoo`0OOol730PB@0/IE0/OG0/QJ0/MK0/00`00N0]h2`0EN0/=O0X5O0H^Ool00`00Oomoo`0/Ool0
035oo`03001oogoo01moo`L<21902aQD2`03001L2e`;01eL2b5X2ae/2`03001h2gP;01Eh2`el2PEl
1Rioo`03001oogoo02aoo`00<Goo00<007ooOol07goo1``84T0;65@;00<005`;G0/07E`;8FP;7F`;
00<007P;N0/05GP;3W`:17`6;Woo00<007ooOol0;7oo000aOol00`00Oomoo`0OOol730PB@0/HE0/0
0`00G0]L2`0MG0/QJ0/MK0/00`00N0]h2`0EN0/>O0X4O0H^Ool00`00Oomoo`0/Ool005=oo`L<2150
2aUD2`03001L2e`;01eL2b5X2ae/2`03001h2gP;01Eh2`il2PAl1Rioo`03001oogoo02aoo`00Dgoo
1``84D0;6U@;7e`;8FP;7F`;00<007P;N0/05GP;3W`:17`6;7oo0`00;Woo001COol730PA@0/JE0/O
G0/QJ0/MK0/00`00N0]h2`0EN0/>O0X4O0H^Ool00`00Oomoo`0>Ool5000IOol0035oo`03001oogoo
01moo`L<21502aYD2amL2b5X2ae/2`03001h2gP;01Eh2`il2PAl1Rioo`03001oogoo01=oo`03001o
ogoo01Ioo`00<Goo00<007ooOol07goo1``84D0;6E@;00<005`;G0/07E`;8FP;7F`;00<007P;N0/0
5GP;3W`:17`6;Woo00<007ooOol057oo00<007ooOol05Goo000`Ool00`00Oomoo`0POol730PA@0/I
E0/00`00G0]L2`0MG0/QJ0/MK0/00`00N0]h2`0EN0/>O0X4O0H^Ool00`00Oomoo`05Ool80007Ool0
0`00Oomoo`0EOol0031oo`03001oogoo021oo`L<21502aUD2`03001L2e`;01eL2b5X2ae/2`03001h
2gP;01Eh2`il2PAl1Rioo`8001Eoo`03001oogoo01Eoo`00DWoo20`84D0;6E@;00<005`;G0/07E`;
8FP;7V`;00<007P;N0/057P;3W`:17`6;goo00<007ooOol04Woo00<007ooOol05Woo001BOol830PA
@0/JE0/OG0/QJ0/NK0/00`00N0]h2`0DN0/>O0X4O0H_Ool00`00Oomoo`0>Ool4000IOol0059oo`P<
21502aYD2amL2b5X2ai/2`03001h2gP;01Ah2`il2PAl1Rioo`80011oo`03001oogoo01Yoo`00<7oo
00<007ooOol07goo20`84D0;6U@;7e`;8FP;7V`;00<007P;N0/057P;3W`:1G`6;Woo00<007ooOol0
3goo00<007ooOol06Goo000`Ool00`00Oomoo`0OOol830PA@0/IE0/00`00G0]L2`0MG0/QJ0/NK0/0
0`00N0]h2`0DN0/>O0X5O0H^Ool00`00Oomoo`0?Ool5000GOol0031oo`03001oogoo01moo`P<2150
2aUD2`03001L2e`;01eL2b5X2ai/2`03001h2gP;01Ah2`il2PEl1Rioo`03001oogoo02]oo`00<7oo
00<007ooOol07goo20`84D0;6E@;00<005`;G0/07E`;8FP;7V`;00<007P;N0/057P;3W`:1G`6;Woo
00<007ooOol0:goo001BOol830PA@0/IE0/00`00G0]L2`0MG0/QJ0/NK0/00`00N0]h2`0DN0/>O0X5
O0H^Ool00`00Oomoo`0[Ool0059oo`P<21502aYD2amL2b5X2ai/2`03001h2gP;01Ah2`il2PEl1Rio
o`03001oogoo02]oo`00DWoo20`84D0;6U@;7e`;8FP;7V`;00<007P;N0/057P;3W`:1G`6;Woo00<0
07ooOol0:goo000`Ool00`00Oomoo`0OOol830PA@0/JE0/OG0/QJ0/NK0/00`00N0]h2`0DN0/>O0X5
O0H]Ool2000]Ool0031oo`03001oogoo01moo`P<21502aUD2`03001L2e`;01eL2b5X2ai/2`03001h
2gP;01Ah2`il2PEl1Rioo`03001oogoo02]oo`00<7oo00<007ooOol07goo1``84T0;6E@;00<005`;
G0/07E`;8FP;7V`;00<007P;N0/057P;3W`:1G`6;Woo00<007ooOol0:goo000`Ool00`00Oomoo`0O
Ool730PB@0/HE0/00`00E0]L2`0NG0/QJ0/NK0/00`00N0]h2`0DN0/>O0X5O0H^Ool00`00Oomoo`0[
Ool0059oo`L<21902aQD2`03001D2e`;01iL2b5X2ai/2`03001h2gP;01Ah2`il2PEl1Rioo`03001o
ogoo02]oo`00DWoo1``84T0;6U@;7e`;8FP;7V`;00<007P;N0/05GP;3W`:17`6;Woo00<007ooOol0
:goo001BOol730PB@0/JE0/OG0/QJ0/NK0/00`00N0]h2`0EN0/>O0X4O0H_Ool00`00Oomoo`0ZOol0
02moo`03001oogoo021oo`L<21902aYD2amL2b5X2ai/2`03001h2gP;01Eh2`il2PAl1Rmoo`03001o
ogoo02Yoo`00;goo00<007ooOol087oo1``84T0;65@;00<005@;G0/07E`;8VP;7V`;00<007P;N0/0
5GP;3W`:17`6;goo00<007ooOol0:Woo000_Ool00`00Oomoo`0POol730PB@0/HE0/00`00E0]L2`0M
G0/RJ0/NK0/00`00N0]h2`0EN0/>O0X4O0H^Ool2000/Ool002moo`03001oogoo021oo`L<21902aQD
2`03001D2e`;01eL2b9X2ai/2`03001h2gP;01Eh2`il2PAl1Rmoo`03001oogoo02Yoo`00DWoo1``8
4T0;65@;00<005`;G0/07E`;8VP;7V`;00<007P;N0/05GP;3W`:17`6;goo00<007ooOol0:Woo001B
Ool730PB@0/IE0/OG0/RJ0/NK0/00`00N0]h2`0EN0/>O0X4O0H_Ool00`00Oomoo`0ZOol0059oo`L<
21902aUD2amL2b9X2ai/2`03001h2gP;01Eh2`il2PAl1Rmoo`03001oogoo02Yoo`00;goo00<007oo
Ool07goo20`84T0;6E@;7e`;8VP;7V`;00<007P;N0/05GP;3W`:17`6;goo00<007ooOol0:Woo000_
Ool00`00Oomoo`0OOol830PB@0/HE0/00`00G0]L2`0MG0/RJ0/NK0/00`00N0]h2`0EN0/>O0X4O0H_
Ool00`00Oomoo`0ZOol002moo`03001oogoo01moo`P<21902aQD2`03001L2e`;01eL2b9X2ai/2`03
001h2gP;01Eh2`il2PEl1Rioo`03001oogoo02Yoo`00;goo00<007ooOol07goo20`84D0;6E@;00<0
05`;G0/07E`;8VP;7V`;00<007P;N0/05GP;3W`:1G`6;Goo0P00;7oo001AOol830PA@0/IE0/00`00
G0]L2`0MG0/RJ0/NK0/00`00N0]h2`0EN0/>O0X5O0H^Ool00`00Oomoo`0ZOol0055oo`P<21502aYD
2amL2b9X2ai/2`03001h2gP;01Eh2`il2PEl1Rioo`03001oogoo02Yoo`00DGoo20`84D0;6U@;7e`;
8VP;7V`;00<007P;N0/05GP;3W`:1G`6;Woo0P00:goo000_Ool00`00Oomoo`0OOol830PA@0/JE0/O
G0/RJ0/NK0/00`00N0]h2`0EN0/>O0X5O0H^Ool2000[Ool002moo`03001oogoo01moo`P<21502aUD
2`03001L2e`;01eL2b9X2ai/2`03001h2gP;01Eh2`il2PEl1Rmoo`03001oogoo02Uoo`00;Woo00<0
07ooOol087oo20`84D0;6E@;00<005`;G0/07E`;8VP;7V`;00<007P;N0/05GP;3W`:1G`6;goo00<0
07ooOol0:Goo000^Ool00`00Oomoo`0POol830PA@0/IE0/00`00G0]L2`0MG0/RJ0/NK0/00`00N0]h
2`0EN0/>O0X5O0H_Ool00`00Oomoo`0YOol0055oo`P<21502aUD2`03001L2e`;01eL2b9X2ai/2`03
001h2gP;01Eh2`il2PEl1Reoo`<002]oo`00DGoo1``84T0;6U@;7e`;8VP;7V`;00<007P;N0/05GP;
3W`:1G`6;goo00<007ooOol01Woo0`0087oo001AOol730PB@0/JE0/OG0/RJ0/NK0/00`00N0]h2`0E
N0/>O0X5O0H_Ool00`00Oomoo`05Ool01@00Oomoogoo00007goo000^Ool00`00Oomoo`0POol730PB
@0/JE0/OG0/RJ0/NK0/00`00N0]h2`0EN0/>O0X5O0H_Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`0LOol002ioo`03001oogoo021oo`L<21902aUD2`03001L2e`;01eL2b9X2ai/2`03001h
2gP;01Eh2`ml2PAl1Rmoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo01aoo`00;Woo00<0
07ooOol087oo1``84T0;6E@;00<005`;G0/07E`;8VP;7V`;00<007P;N0/05GP;3g`:17`6;goo00<0
07ooOol017oo00<007ooOol00goo00<007ooOol077oo000^Ool00`00Oomoo`0POol730PB@0/IE0/0
0`00G0]L2`0MG0/RJ0/NK0/00`00N0]h2`0EN0/?O0X4O0H_Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool00`00Oomoo`0<Ool80008Ool0055oo`L<21902aUD2`03001L2e`;01eL2b9X2ai/2`03001h2gP;
01Eh2`ml2PAl1Rmoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00=o
o`03001oogoo00Ioo`00DGoo1``84T0;6U@;7e`;8VP;7V`;00<007P;N0/05WP;3W`:17`6;goo00<0
07ooOol017oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol01Woo001A
Ool730PB@0/JE0/OG0/RJ0/OK0/00`00N0]h2`0EN0/>O0X4O0H^Ool20007Ool01@00Oomoogoo0000
4Goo00<007ooOol02goo000^Ool00`00Oomoo`0POol730PB@0/JE0/OG0/RJ0/OK0/00`00N0]h2`0E
N0/>O0X4O0H_Ool00`00Oomoo`06Ool3000COol00`00Oomoo`0:Ool002ioo`03001oogoo021oo`L<
21902aUD2`03001L2e`;01eL2b9X2am/2`03001h2gP;01Eh2`il2PAl1Rmoo`03001oogoo01eoo`03
001oogoo00Uoo`00;Woo00<007ooOol07goo20`84T0;6E@;00<005`;G0/07E`;8VP;7f`;00<007P;
N0/05GP;3W`:17`6;goo00<007ooOol07Woo00<007ooOol027oo000^Ool00`00Oomoo`0OOol830PB
@0/IE0/00`00G0]L2`0MG0/RJ0/OK0/00`00N0]h2`0EN0/>O0X4O0H_Ool2000JOol00`00Oomoo`02
Ool00`00Oomoo`08Ool002ioo`03001oogoo01moo`P<21902aUD2`03001L2e`;01eL2b9X2am/2`03
001h2gP;01Eh2`il2PEl1Rmoo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo00Moo`00D7oo
20`84T0;6U@;7e`;8VP;7f`;00<007P;N0/05GP;3W`:1G`6;goo00<007ooOol067oo200027oo001@
Ool830PB@0/JE0/OG0/RJ0/OK0/00`00N0]h2`0EN0/>O0X5O0H_Ool00`00Oomoo`0XOol002eoo`03
001oogoo021oo`P<21902aYD2amL2b9X2am/2`03001h2gP;01Eh2`il2PEl1Rioo`8002Yoo`00;Goo
00<007ooOol087oo20`84T0;6E@;00<005`;G0/07E`;8VP;7f`;00<007P;N0/05GP;3W`:1G`6;goo
00<007ooOol0:7oo000]Ool00`00Oomoo`0POol830PB@0/IE0/00`00G0]L2`0MG0/RJ0/OK0/00`00
N0]h2`0EN0/>O0X5O0H_Ool00`00Oomoo`0XOol002eoo`03001oogoo021oo`P<21902aUD2`03001L
2e`;01eL2b9X2am/2`03001h2gP;01Eh2`il2PEl1Rmoo`03001oogoo02Qoo`00;Goo00<007ooOol0
87oo20`84T0;6E@;00<005`;G0/07E`;8VP;7f`;00<007P;N0/05GP;3W`:1G`6;goo00<007ooOol0
:7oo001@Ool830PB@0/JE0/OG0/RJ0/OK0/00`00N0]h2`0EN0/>O0X5O0H_Ool00`00Oomoo`0XOol0
051oo`P<21902aYD2amL2b9X2am/2`03001h2gP;01Eh2`il2PEl1Rmoo`03001oogoo02Qoo`00;Goo
00<007ooOol087oo20`84T0;6U@;7e`;8VP;7f`;00<007P;N0/05GP;3W`:1G`6;goo00<007ooOol0
:7oo000]Ool00`00Oomoo`0POol830PB@0/IE0/00`00G0]L2`0MG0/RJ0/OK0/00`00N0]h2`0EN0/>
O0X5O0H_Ool00`00Oomoo`0XOol002eoo`03001oogoo021oo`L<21=02aUD2`03001L2e`;01eL2b9X
2am/2`03001h2gP;01Eh2`il2PEl1Rioo`8002Yoo`00;Goo00<007ooOol087oo1``84T0;6U@;00<0
05`;G0/07E`;8fP;7V`;00<007P;N0/05GP;3W`:1G`6;goo00<007ooOol0:7oo000]Ool00`00Oomo
o`0POol730PB@0/JE0/00`00G0]L2`0MG0/SJ0/NK0/00`00N0]h2`0EN0/?O0X4O0H_Ool00`00Oomo
o`0XOol0051oo`L<21902a]D2amL2b=X2ai/2`03001h2gP;01Eh2`ml2PAl1Rmoo`03001oogoo02Qo
o`00D7oo1``84T0;6e@;7e`;8fP;7V`;00<007P;N0/05GP;3g`:17`6<7oo00<007ooOol09goo000]
Ool00`00Oomoo`0POol730PB@0/KE0/OG0/SJ0/NK0/00`00N0]h2`0EN0/?O0X4O0H`Ool00`00Oomo
o`0WOol002eoo`03001oogoo021oo`L<21902aUD2`03001D2e`;01iL2b=X2ai/2`03001h2gP;01Eh
2`ml2PAl1S1oo`03001oogoo02Moo`00;Goo00<007ooOol087oo1``84T0;6E@;00<005@;G0/07U`;
8fP;7V`;00<007P;N0/05GP;3g`:17`6<7oo00<007ooOol09goo000/Ool00`00Oomoo`0QOol730PB
@0/IE0/00`00E0]L2`0NG0/SJ0/NK0/00`00N0]h2`0EN0/?O0X4O0H_Ool2000YOol002aoo`03001o
ogoo021oo`P<21902aUD2`03001D2e`;01iL2b=X2ai/2`03001h2gP;01Eh2`ml2PAl1S1oo`03001o
ogoo02Moo`00Cgoo20`84T0;6E@;00<005@;G0/07U`;8fP;7V`;00<007P;N0/05GP;3g`:17`6<7oo
00<007ooOol09goo001?Ool830PB@0/KE0/OG0/SJ0/NK0/00`00N0]h2`0FN0/>O0X4O0H`Ool00`00
Oomoo`0WOol002aoo`03001oogoo021oo`P<21902a]D2amL2b=X2ai/2`03001h2gP;01Ih2`il2PEl
1Rmoo`03001oogoo02Moo`00;7oo00<007ooOol087oo20`84T0;6E@;00<005@;G0/07U`;8fP;7V`;
00<007P;N0/05WP;3W`:1G`6;goo00<007ooOol09goo000/Ool00`00Oomoo`0POol830PB@0/IE0/0
0`00E0]L2`0NG0/SJ0/NK0/00`00N0]h2`0FN0/>O0X5O0H_Ool00`00Oomoo`0WOol002aoo`03001o
ogoo021oo`P<21902aUD2`03001D2e`;01iL2b=X2ai/2`03001h2gP;01Ih2`il2PEl1Rmoo`03001o
ogoo02Moo`00;7oo00<007ooOol087oo20`84T0;6E@;00<005@;G0/07U`;8fP;7V`;00<007P;N0/0
5WP;3W`:1G`6;goo00<007ooOol09goo001?Ool830PB@0/IE0/00`00E0]L2`0NG0/SJ0/NK0/00`00
N0]h2`0FN0/>O0X5O0H]Ool30006Ool5000NOol004moo`P<21902a]D2amL2b=X2ai/2`03001h2gP;
01Ih2`il2PEl1Rmoo`8000Yoo`03001oogoo01]oo`00;7oo00<007ooOol087oo20`84T0;6U@;85`;
8fP;7V`;00<007P;N0/05WP;3W`:1G`6;goo0P002goo00<007ooOol06Woo000/Ool00`00Oomoo`0P
Ool830PB@0/IE0/00`00G0]L2`0NG0/SJ0/NK0/00`00N0]h2`0FN0/>O0X5O0H`Ool00`00Oomoo`09
Ool00`00Oomoo`0JOol002aoo`03001oogoo021oo`P<21902aUD2`03001L2e`;01iL2b=X2ai/2`03
001h2gP;01Ih2`il2PEl1S1oo`03001oogoo00Uoo`03001oogoo01Yoo`00;7oo00<007ooOol087oo
20`84T0;6E@;00<005`;G0/07U`;8fP;7V`;00<007P;N0/05WP;3W`:1G`6<7oo00<007ooOol027oo
00<007ooOol06goo000/Ool00`00Oomoo`0POol830PB@0/IE0/00`00G0]L2`0NG0/SJ0/NK0/00`00
N0]h2`0FN0/>O0X5O0H`Ool00`00Oomoo`04Ool4000NOol004moo`L<21=02aUD2`03001L2e`;01iL
2b=X2ai/2`03001h2gP;01Ih2`il2PEl1S1oo`03001oogoo00Aoo`03001oogoo01moo`00Cgoo1``8
4d0;6U@;85`;8fP;7V`;00<007P;N0/05WP;3W`:1G`6<7oo00<007ooOol01Goo00<007ooOol07Woo
000[Ool00`00Oomoo`0QOol730PC@0/JE0/PG0/SJ0/NK0/00`00N0]h2`0FN0/?O0X4O0H_Ool20007
Ool5000LOol002]oo`03001oogoo025oo`L<21=02aUD2`03001L2e`;01iL2b=X2am/2`03001h2gP;
01Eh2`ml2PAl1S1oo`03001oogoo02Ioo`00:goo00<007ooOol08Goo1``84d0;6E@;00<005`;G0/0
7U`;8fP;7f`;00<007P;N0/05GP;3g`:17`6<7oo00<007ooOol09Woo000[Ool00`00Oomoo`0QOol7
30PC@0/IE0/00`00G0]L2`0NG0/SJ0/OK0/00`00N0]h2`0EN0/?O0X4O0H`Ool00`00Oomoo`0VOol0
02]oo`03001oogoo025oo`L<21=02aUD2`03001L2e`;01iL2b=X2am/2`03001h2gP;01Eh2`ml2PAl
1S1oo`03001oogoo02Ioo`00Cgoo1``84d0;6E@;00<005`;G0/07U`;8fP;7f`;00<007P;N0/05GP;
3g`:17`6<7oo00<007ooOol09Woo001?Ool730PC@0/JE0/PG0/SJ0/OK0/00`00N0]h2`0EN0/?O0X4
O0H`Ool00`00Oomoo`0VOol002]oo`03001oogoo021oo`P<21=02aYD2b1L2b=X2am/2`03001h2gP;
01Eh2`ml2PAl1S1oo`03001oogoo02Ioo`00:goo00<007ooOol087oo20`84d0;6E@;00<005`;G0/0
7U`;8fP;7f`;00<007P;N0/05GP;3g`:17`6;goo0P00:7oo000[Ool00`00Oomoo`0POol830PC@0/I
E0/00`00G0]L2`0NG0/SJ0/OK0/00`00N0]h2`0EN0/?O0X5O0H_Ool2000WOol002]oo`03001oogoo
021oo`P<21902aYD2`03001L2e`;01iL2b=X2am/2`03001h2gP;01Eh2`ml2PEl1S1oo`03001oogoo
02Eoo`00:goo00<007ooOol087oo20`84T0;6U@;00<005`;G0/07U`;8fP;7f`;00<007P;N0/05GP;
3g`:1G`6<7oo00<007ooOol09Goo001>Ool830PB@0/JE0/00`00G0]L2`0NG0/SJ0/OK0/00`00N0]h
2`0EN0/?O0X5O0H`Ool00`00Oomoo`0UOol004ioo`P<21902a]D2b1L2b=X2am/2`03001h2gP;01Eh
2`ml2PEl1S1oo`03001oogoo02Eoo`00:goo00<007ooOol087oo20`84T0;6e@;85`;8fP;7f`;00<0
07P;N0/05WP;3W`:1G`6<7oo00<007ooOol09Goo000[Ool00`00Oomoo`0POol830PB@0/JE0/00`00
G0]L2`0NG0/SJ0/OK0/00`00N0]h2`0FN0/>O0X5O0H`Ool00`00Oomoo`0UOol002]oo`03001oogoo
021oo`P<21902aYD2`03001L2e`;01iL2b=X2am/2`03001h2gP;01Ih2`il2PEl1S1oo`03001oogoo
02Eoo`00:Woo00<007ooOol08Goo20`84T0;6U@;00<005`;G0/07U`;8fP;7f`;00<007P;N0/05WP;
3W`:1G`6;goo0P009goo000ZOol00`00Oomoo`0QOol830PB@0/JE0/00`00G0]L2`0FG0/`000JK0/0
0`00N0]h2`0FN0/>O0X5O0H`Ool00`00Oomoo`0UOol004ioo`P<21902aQD2`<00004G0/000000004
G0/@000`D148000BK0/00`00N0]h2`0FN0/>O0X5O0H`Ool00`00Oomoo`0UOol004ioo`P<21902aMD
2`l001=@4A@001i@4@L000]/2`03001h2gP;01Ih2`il2PEl1S1oo`03001oogoo02Eoo`00:Woo00<0
07ooOol08Goo20`84T0;4e@;1@003U0A00@0050AD15@4@<000E@4@L001@1H1@0015@4@P000=/2`03
001h2gP;01Ih2`il2PEl1S1oo`03001oogoo02Eoo`00:Woo00<007ooOol08Goo1``84d0;3E@;1`00
4U0A00=L2`0000002`008@5P00<0005P0F002@5P2P003e0A1`005GP;3W`:1G`6<7oo00<007ooOol0
9Goo000ZOol00`00Oomoo`0QOol730PC@0/8E0/50004D1400`00D15@4@08D14;000708000`000F01
H0030F0010000F01H05P0`006P5P00<0005P0F004`5P2@001E0A0`001E0A1@0047P;3W`:1G`6<7oo
00<007ooOol09Goo000ZOol00`00Oomoo`0QOol730PC@0/3E0/50008D1400`00D15@4@03D146000B
08000`000F01H00:0F000`000F01H00G0F000`000F01H00L0F07000;D145000;N0/?O0X4O0H`Ool2
000VOol002Yoo`03001oogoo025oo`L<21902`@000e@4@H000<0P0030000P0200180P0030001H05P
00h1H0@00181H0030001H05P02<1H0D000]@4@D000Ih2`ml2PAl1S1oo`8002Ioo`00CWoo1``83d0;
0`002e0A1P002@2000<0002008004P2000<0005P0F005@5P10002`5P00<0005P0F008`5P00<0005P
0F000P5P1000350A1@0000=h2g`:O0X03G`:17`6;goo0`009Woo001>Ool730P<@0/3000:D1440000
0`200000P00<08000`000800P00B08000`000F01H00L0F0400040F000`000F01H00S0F000`000F01
H0060F04000=D143000=O0X4O0HaOol00`00Oomoo`0TOol002Yoo`03001oogoo025oo`L<20U02`<0
00Y@4@@000<0P0030000P02000`0P0030000P0200180P0030001H05P02<1H0@002<1H0030001H05P
00X1H0D000]@4@8000]l2PAl1S5oo`03001oogoo02Aoo`00:Woo00<007ooOol08Goo1``81d0;0P00
2e0A0P000`200P004@2000<0002008004P2000<0005P0F00905P00<0005P0F000`5P0`007@5P00<0
005P0F003`5P0`002U0A0P002G`:17`6<Goo00<007ooOol097oo000ZOol00`00Oomoo`0POol830P4
@0/3000:D14300030803000B08000`000800P00B08000`000F01H00T0F000`000F01H0060F000`00
0F01H003000G0F000`000F01H00B0F02000:D1420007O0X4O0HaOol00`00Oomoo`0TOol002Yoo`03
001oogoo021oo`P<2004@0/00000000;D1420005080010000800P0004P2000<0002008004@201@00
8`5P00<0005P0F00305P0P000P5P0`00405P00<0005P0F00505P0P002U0A00<007`:O0X017`:17`6
<Goo00<007ooOol097oo000ZOol00`00Oomoo`0POol830P00`00D15@4@0:D142000:08000`000800
P00@08000`000800P00?080200050L07000L0F000`000F01H00C0F0200020F0300090F000`000F01
H00F0F020009D1420004O0X5O0H`Ool00`00Oomoo`0TOol004eoo`L<2003001@4E0A00Q@4@<000D0
P08000D0P0030000P0200100P0030000P02000d0P08000h1`0L001D1H0030001H05P01X1H0800081
H0<00081H0030001H05P01P1H08000U@4@80009l2PEl1S1oo`03001oogoo02Aoo`00CGoo1P`800<0
050AD1401e0A0P001P200P001`2000<000200800402000<0002008002`200P005`701P003`5P00<0
005P0F008@5P0`00705P0P002E0A0P001G`6<7oo00<007ooOol097oo000YOol00`00Oomoo`0QOol5
30P00`00D15@4@07D1400`000800P00?08000`000800P00@08000`000800P0090802000O0L070008
0F000`000F01H00S0F000`000F000004000H0F020009D1400`00O0Il1P02O0H^Ool30008Ool30005
Ool3000COol002Uoo`03001oogoo025oo`@<2003001@4E0A00M@4@03001l2P2000<0P08000/0P003
0000P0200100P0030000P02000L0P08002P1`0L000030F00005P02@1H0030001H05P00H1H0D001<1
H003001@4E0A00I@4@03001l1W`6009l1S1oo`03001oogoo00Moo`03001oogoo00=oo`05001oogoo
Ool0000BOol002Uoo`03001oogoo025oo`<<2003001@4E0A00M@4@03001l2W`:00<0P0030000P020
00/0P0030000P0200100P0030000P02000D0P0800341`0H00241H0030001H05P00d1H0D000`1H003
001@4E0A00M@4@04001l1W`6O0H`Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`0?Ool002Uoo`03001oogoo025oo`8<2003001@4E0A00M@4@04001l2W`:O0X208000`00
0800P00<08000`000800P00@08000`000800P0030802000a0L0200060L07000J0F000`000F01H00D
0F0500060F000`00D15@4@06D14010`7001l1W`6<7oo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol03goo000YOol00`00Oomoo`0QOol00``8001@4@08D1400`00O0Yl2P02
000A08000`000800P00@080010000800P0200P00<@700P003`701`004`5P00<0005P0F006`5P1P00
250A00<007`6O0H0<7oo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
3goo001=Ool00`00D15@4@07D1401@00O0Yl2P00O0X04P2000<000200800402000@0002000000301
`0<001P1`0H000d1H0030001H05P0241H0@000E@4@03001l1Woo02moo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo00moo`00CGoo00<0050AD1401U0A00@007P4O0X0009l
2Q80P0030000P0200100P0@002h1`0800241`0L000H1H0030001H05P0241H005001@4E0AD1400003
D143000`Ool20008Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool002Uoo`03001o
ogoo025oo`03001@4E0A00I@4@03001h17`:00=l2Q80P0030000P02000h0P08000@1`0L002D1`080
02X1`0L002<1H08000Q@4@8000=oo`<002Yoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo00moo`00:Goo00<007ooOol08Woo00<0050AD140150A0P0000=h17`:O0X00W`:
4P2000<00020080030200P003@701P007@700P00<@7020007@5P00<000`70000250A00<007ooOol0
17oo00@007ooOomoo`<002=oo`03001oogoo00Eoo`8000Eoo`05001oogooOol0000BOol002Uoo`03
001oogoo029oo`03001@4E0A009@4@80009@4@03001l2W`:009l2Q80P0030000P02000X0P08001D1
`0L001@1`0800301`0<000P1`0L001H1H003000<1`0000Q@4@03001oogoo00]oo`04001oogooOol3
000JOol30008Ool00`00Oomoo`04Ool3000COol002Uoo`03001oogoo029oo`03001@4E0A00I@4@03
001l2W`:009l2Q80P0030000P02000P0P08001h1`0H000/1`0<00301`0800181`0H00101H08000Q@
4@03001oogoo01=oo`03001oogoo01Uoo`03001oogoo02=oo`00:Goo00<007ooOol08Woo0`001U0A
00<007`:O0X00W`:4P2000<0002008001P200P009P701`000P700P00<0700`006P701`002@5P0P00
1e0A00<007ooOol067oo100057oo00<007ooOol08goo001>Ool20008D1401000O0Yl2W`:4P2000<0
0020080010200P00;`701P00;0700P0090701`000P5P00<0050AD1401U0A00<007ooOol07goo1000
3Goo00<007ooOol08goo001=Ool01000Ool000001e0A0P000W`:4P2000<0002008000P200P00;`70
0P001P701`008P700`00;@700`001e0A00<007ooOol09goo10001Woo00<007ooOol08goo000YOol0
0`00Oomoo`0UOol00`00D15@4@06D1400`00O0X0P00A08000`000800P002000_0L02000?0L06000J
0L02000^0L040008D1400`00Oomoo`0^Ool4000UOol002Uoo`03001oogoo01aoo`<000Moo`03001@
4E0A00I@4@030000P0200100P0<002l1`08001L1`0H00181`08002h1`0800003=0/0000000Q@4@03
001oogoo02Uoo`03001oogoo009oo`<002Moo`00:Goo00<007ooOol06Woo0P002goo0P001e0A00<0
002008003P201P00:P700`007`701`0020700`00;@700`0000<d2`000000250A0P00;7oo00<007oo
00000P0000=oo`00Ool09goo000XOol00`00Oomoo`0ZOol00`00D15@4@04D1400`000800P00<0802
00060L07000Q0L02000Y0L08000^0L020003=0/00`00D15@4@06D142000]Ool4000/Ool002Qoo`03
001oogoo01Moo`80019oo`8000A@4@030000P02000X0P08000l1`0L001P1`08002h1`0X002H1`0<0
00<d2`8000M@4@8002Yoo`03001oo`0000@002ioo`00@Goo00<007ooOol04goo00=@4@00D1400U0A
00<00020080020200P0060701`003`700P00;P700P002P701P007@700`0013@;0P001e0A0P00:goo
1000<Woo0010Ool00`00Oomoo`0FOol01000D15@4@0020200P008@701`001P700P00;@700`004P70
1`0050700P000d`;0c@;00<0050AD1401U0A00<007ooOol09Woo00<007oo00001000=7oo000XOol0
0`00Oomoo`0AOol2000LOol300060802000Z0L07000/0L02000L0L06000;0L030005C0/00c@;0000
0007D142000YOol2000iOol002Qoo`03001oogoo011oo`03001oogoo01ioo`030000P0200080P080
02d1`0<000<1`0L00281`0<002@1`0L00081`08000I<2`<000M@4@8002Ioo`03001oo`0000800003
Ool007oo03Qoo`00:7oo00<007ooOol03goo00<007ooOol07goo00<0002008000P00;@700P003@70
200060700P00;@70100014`;0`001e0A0`009goo0`00?Woo000XOol00`00Oomoo`0aOol3000]0L02
000G0L07000>0L03000]0L020004C0/40006D144000UOol00`00Ool000030010Ool002Qoo`03001o
ogoo00]oo`8002Aoo`030001`07002/1`0800201`0L000D1`08002d1`0<0009<2`@000I@4@@002Ao
o`04001oogooOol50012Ool003Aoo`8002]oo`L00201`08002T1`0L002/1`080009<2`<000M@4@<0
02Qoo`D004Ioo`00J7oo20005@700`00:`700P001@701`008@701`001U0A1000:Woo0`00BGoo000X
Ool00`00Oomoo`05Ool2000nOol7000<0L02000/0L02000>0L07000H0L0200000eP;D15@4@05D145
000ZOol4000HOol30005Ool3000YOol002Qoo`03001oogoo00Aoo`03001oogoo04Aoo`03D1400000
00H00081`08002/1`0<001L1`0L000h1`0<000=@4@L002Yoo`03001oogoo00<001aoo`03001oogoo
00=oo`05001oogooOol0000XOol002Qoo`03001oogoo00=oo`03001oogoo04Yoo`/002H1`0800241
`0L000D1`0P00003D15oogoo02ioo`<001moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
02Eoo`00:7oo00@007oo000005Eoo`d001/1`0<002X1`0L0039oo`03001oo`0000<0025oo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo02Eoo`00:7oo0P00HGoo2P004P700P00;0700`00=Woo
100097oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol09Goo000XOol3001ZOol800070L03
000/0L02000dOol00`00Ool00004000VOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0U
Ool002]oo`04001oogooOol4001ZOol8000[0L03000bOol01000Oomoogoo1000:Goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol09Goo000fOol4001ZOol8000R0L02000eOol4000]Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0UOol003eoo`@006]oo`L001P1`0<000=oo`03001o
ogoo02aoo`03001oogoo00<002moo`8000Eoo`05001oogooOol0000XOol004Aoo`@000=oo`<006Eo
o`P000h1`08000Ioo`03001oogoo02aoo`<003=oo`03001oogoo00Aoo`<002Uoo`00CWoo00@007oo
Oomoo`<006Ioo`L000@1`0<000Qoo`03001oogoo02Moo`03001oo`0000<001Yoo`D004Uoo`00EGoo
00@007ooOomoo`<006Ioo`@000]oo`03001oogoo02Ioo`@0029oo`03001oogoo04Ioo`00G7oo00<0
07ooOol01@00KGoo00<007ooOol08Woo1@009Woo00<007ooOol0AGoo001VOol50027Ool00`00Oomo
o`04000XOol00`00Oomoo`15Ool006eoo`D007]oo`03001oogoo009oo`<002aoo`03001oogoo04Eo
o`00M7oo1@000Woo0`00Dgoo00<007ooOol06Goo00<007oo00000`00;Goo00<007ooOol0AWoo001n
Ool20002Ool3001<Ool00`00Oomoo`0DOol00`00Oomoo`04000]Ool40019Ool008Eoo`80009oo`<0
04Eoo`03001oogoo01Aoo`@0031oo`03001oogoo04Yoo`00S7oo0P000Woo1@00?7oo00<007ooOol0
47oo00<007oo00000`006Goo0`005goo00<007ooOol0BGoo002GOol5000eOol00`00Oomoo`0<Ool0
1000Oomoogoo0`006goo00D007ooOomoo`0001Ioo`D004Moo`00WWoo1@00?Goo1@0077oo00<007oo
Ool00goo00<007ooOol0Ggoo002UOol50002Ool3000XOol01@00Oomoogoo00000Woo0`0087oo00<0
07ooOol00goo00<007ooOol0Ggoo002_Ool20002Ool3000KOol00`00Oomoo`03Ool01000Oomoogoo
0`008goo00<007ooOol00goo00<007ooOol0Ggoo002fOol20002Ool3000DOol00`00Oomoo`03Ool4
000VOol00`00Oomoo`03Ool00`00Oomoo`1OOol00;eoo`80009oo`D000]oo`04001oo`00Ool3000Y
Ool00`00Oomoo`03Ool00`00Oomoo`1OOol00<Qoo`D000Aoo`@002aoo`03001oogoo00=oo`03001o
ogoo05moo`00cgoo0`00<7oo00D007ooOomoo`00069oo`00kgoo1@003goo0`00Hgoo003dOol00`00
Oomoo`1bOol00?Eoo`03001oogoo075oo`00iWoo20001goo00<007ooOol0LGoo003eOol00`00Oomo
o`1aOol00?Aoo`03001oogoo079oo`00l7oo1000MGoo003GOol30005Ool3000>Ool00`00Oomoo`1f
Ool00=Qoo`03001oogoo00=oo`05001oogooOol0000>Ool00`00Oomoo`1eOol00=Qoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00]oo`D007=oo`00c7oo200017oo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol0Pgoo003HOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`23
Ool00=Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo08=oo`00f7oo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol06Goo0`000goo1000H7oo003HOol00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`0JOol00`00Oomoo`03Ool00`00Oomoo`1POol00=Moo`8000Eoo`05001oogoo
Ool0000NOol01@00Oomoogoo0000Hgoo003HOol00`00Oomoo`04Ool3000POol00`00Ool0001TOol0
0?moo`Aoo`8006Aoo`00ogoo17oo0P00I7oo003oOol3Ool01000Oomoo`00Hgoo003oOol3Ool01000
Oomoo`00Hgoo003oOol2Ool00`00Oomoo`02Ool00`00Oomoo`1POol00?moo`@0009oo`@0061oo`00
ogooJWoo003oOomZOol00?moofYoo`00ogooJWoo003oOomZOol00?moofYoo`00ogooJWoo003oOomZ
Ool00?moofYoo`00ogooJWoo003oOomZOol00?moofYoo`00ogooJWoo003oOomZOol00?moofYoo`00
ogooJWoo003oOomZOol00?moofYoo`00ogooJWoo003oOomZOol00?moofYoo`00ogooJWoo003oOomZ
Ool00?moofYoo`00ogooJWoo003oOomZOol00?moofYoo`00ogooJWoo003oOomZOol00?moofYoo`00
\
\>"],
  ImageRangeCache->{{{0, 360.938}, {360.938, 0}} -> {-4.87615*^-6, -0.013045, 
  0.00355356, 0.00355356}}]
}, Open  ]],

Cell[BoxData[
    \(\(radObjDrwQD3D[t]; \)\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
WindowSize->{831, 654},
WindowMargins->{{Automatic, 145}, {Automatic, 66}},
ShowCellLabel->False,
Magnification->1.5,
StyleDefinitions -> "Classroom.nb",
MacintoshSystemPageSetup->"\<\
00P0001804P000000]/2@?oWonh2o`9B7`<5:0?l0040004/0B`000002nL9H04/
02d5X5k/02H20@4101P00BL?00400@0000000000000000010000000000000000
0000000000000002000000@210D00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 33, 0, 75, "Title"],
Cell[1745, 51, 58, 4, 111, "Text"],

Cell[CellGroupData[{
Cell[1828, 59, 31, 0, 83, "Section"],
Cell[1862, 61, 1618, 22, 375, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3517, 88, 33, 0, 83, "Section"],

Cell[CellGroupData[{
Cell[3575, 92, 42, 1, 69, "Input"],
Cell[3620, 95, 358, 7, 32, "Print"],
Cell[3981, 104, 126, 2, 53, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4156, 112, 32, 0, 83, "Section"],
Cell[4191, 114, 1172, 18, 598, "Input"],

Cell[CellGroupData[{
Cell[5388, 136, 345, 9, 115, "Input"],
Cell[5736, 147, 75829, 2658, 444, 53824, 2382, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[81580, 2808, 55, 1, 69, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81672, 2814, 45, 0, 83, "Section"],
Cell[81720, 2816, 943, 14, 231, "Text"],

Cell[CellGroupData[{
Cell[82688, 2834, 697, 11, 345, "Input"],
Cell[83388, 2847, 605, 13, 32, "Print"],
Cell[83996, 2862, 606, 13, 32, "Print"],
Cell[84605, 2877, 612, 13, 36, "Print"],
Cell[85220, 2892, 362, 7, 32, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[85631, 2905, 34, 0, 83, "Section"],
Cell[85668, 2907, 505, 8, 135, "Text"],

Cell[CellGroupData[{
Cell[86198, 2919, 963, 16, 667, "Input"],
Cell[87164, 2937, 337, 7, 32, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87538, 2949, 422, 10, 138, "Input"],
Cell[87963, 2961, 84943, 2817, 447, 52529, 2412, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[172921, 5781, 55, 1, 69, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

